@keyframes ripple {
  to {
    background-size: 1000% 1000%;
  }
}

@keyframes ripple-on-slider {
  to {
    background-size: auto, 1000% 1000%;
  }
}

@keyframes ripple-on-headerbar {
  from {
    background-image: radial-gradient(circle, #1A73E8 0%, transparent 0%);
  }
  to {
    background-image: radial-gradient(circle, #1A73E8 100%, transparent 0%);
  }
}

* {
  background-clip: padding-box;
  -GtkToolButton-icon-spacing: 0;
  -GtkTextView-error-underline-color: #E53935;
  -GtkScrolledWindow-scrollbar-spacing: 0;
  -GtkToolItemGroup-expander-size: 11;
  -GtkWidget-text-handle-width: 24;
  -GtkWidget-text-handle-height: 24;
  -GtkDialog-button-spacing: 6;
  -GtkDialog-action-area-border: 6;
  outline-style: solid;
  outline-width: 2px;
  outline-color: transparent;
  outline-offset: -4px;
  -gtk-outline-radius: 12px;
  -gtk-secondary-caret-color: #1A73E8;
}

*:focus {
  outline-color: alpha(currentColor, 0.1);
}

calendar.raven-calendar:selected, .budgie-popover.budgie-menu row.activatable > button.flat:checked, box.vertical > widget > widget:selected, row:selected, treeview.view:selected, modelbutton.flat:selected,
.menuitem.button.flat:selected {
  color: rgba(0, 0, 0, 0.87);
  background-color: rgba(235, 235, 235, 0.987);
}

.nemo-window .view selection, .nemo-window .view:selected, .nautilus-window notebook .view:not(treeview) selection, .nautilus-window notebook .view:not(treeview):selected, .nautilus-window flowboxchild:selected .icon-item-background, flowbox flowboxchild:selected, .background.csd .view:selected {
  color: #1A73E8;
  background-color: rgba(26, 115, 232, 0.2);
}

.nemo-window .nemo-window-pane widget.entry:selected, XfdesktopIconView.view:active, XfdesktopIconView.view:selected, XfdesktopIconView.view:checked, window.background.csd evview.view.content-view:selected, window.background.csd evview.view.content-view:selected:backdrop, statuspage.search-view entry.search > window.background treeview.view:selected, calendar:selected, spinbutton.vertical selection, spinbutton:not(.vertical) selection,
entry selection, label selection, textview text selection:focus, textview text selection, .view:selected {
  color: white;
  background-color: #1A73E8;
}

.linked:not(.vertical) > button, .linked:not(.vertical) > spinbutton.vertical, .linked:not(.vertical) > spinbutton:not(.vertical), .linked:not(.vertical) > entry {
  border-radius: 0;
}

.linked:not(.vertical) > button:first-child, .linked:not(.vertical) > spinbutton.vertical:first-child, .linked:not(.vertical) > spinbutton:first-child:not(.vertical), .linked:not(.vertical) > entry:first-child {
  border-top-left-radius: 12px;
  border-bottom-left-radius: 12px;
}

.linked:not(.vertical) > button:last-child, .linked:not(.vertical) > spinbutton.vertical:last-child, .linked:not(.vertical) > spinbutton:last-child:not(.vertical), .linked:not(.vertical) > entry:last-child {
  border-top-right-radius: 12px;
  border-bottom-right-radius: 12px;
}

.linked:not(.vertical) > button:only-child, .linked:not(.vertical) > spinbutton.vertical:only-child, .linked:not(.vertical) > spinbutton:only-child:not(.vertical), .linked:not(.vertical) > entry:only-child {
  border-radius: 12px;
}

.linked.vertical > button, .linked.vertical > spinbutton.vertical, .linked.vertical > spinbutton:not(.vertical), .linked.vertical > entry {
  border-radius: 0;
}

.linked.vertical > button:first-child, .linked.vertical > spinbutton.vertical:first-child, .linked.vertical > spinbutton:first-child:not(.vertical), .linked.vertical > entry:first-child {
  border-top-left-radius: 12px;
  border-top-right-radius: 12px;
}

.linked.vertical > button:last-child, .linked.vertical > spinbutton.vertical:last-child, .linked.vertical > spinbutton:last-child:not(.vertical), .linked.vertical > entry:last-child {
  border-bottom-left-radius: 12px;
  border-bottom-right-radius: 12px;
}

.linked.vertical > button:only-child, .linked.vertical > spinbutton.vertical:only-child, .linked.vertical > spinbutton:only-child:not(.vertical), .linked.vertical > entry:only-child {
  border-radius: 12px;
}

/***************
 * Base States *
 ***************/
.background {
  background-color: #F2F2F2;
  color: rgba(0, 0, 0, 0.87);
}

.background.csd {
  border-radius: 0 0 18px 18px;
}

.background.maximized, .background.solid-csd {
  border-radius: 0;
}

*:disabled {
  -gtk-icon-effect: dim;
}

.gtkstyle-fallback {
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.87);
}

.gtkstyle-fallback:hover {
  background-color: #f2f2f2;
  color: rgba(0, 0, 0, 0.87);
}

.gtkstyle-fallback:active {
  background-color: #e6e6e6;
  color: rgba(0, 0, 0, 0.87);
}

.gtkstyle-fallback:disabled {
  background-color: #FAFAFA;
  color: rgba(0, 0, 0, 0.38);
}

.gtkstyle-fallback:selected {
  background-color: #1A73E8;
  color: white;
}

.view {
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.87);
}

.view:hover {
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
}

.view:disabled {
  color: rgba(0, 0, 0, 0.38);
}

.view:selected:hover {
  box-shadow: none;
}

textview text {
  background-color: #FFFFFF;
}

textview border {
  background-color: #FAFAFA;
  color: rgba(0, 0, 0, 0.6);
}

iconview {
  border-radius: 12px;
}

.rubberband,
rubberband,
XfdesktopIconView.view .rubberband,
.content-view rubberband,
.content-view treeview.view rubberband,
treeview.view .content-view rubberband,
.content-view .rubberband,
treeview.view rubberband,
treeview.view .content-view .rubberband,
.content-view treeview.view .rubberband,
treeview.view flowbox rubberband,
flowbox treeview.view rubberband,
flowbox rubberband,
flowbox treeview.view rubberband,
treeview.view flowbox rubberband {
  border: 1px solid #1A73E8;
  background-color: rgba(26, 115, 232, 0.3);
}

flowbox flowboxchild {
  padding: 4px;
  border-radius: 12px;
}

.content-view .tile:selected {
  background-color: transparent;
}

label {
  caret-color: currentColor;
}

label.separator {
  color: rgba(0, 0, 0, 0.6);
}

label:disabled {
  color: rgba(0, 0, 0, 0.38);
}

headerbar label:disabled, tab label:disabled, button label:disabled {
  color: inherit;
}

label.osd {
  border-radius: 12px;
  background-color: rgba(52, 52, 52, 0.9);
  color: white;
}

.dim-label {
  color: rgba(0, 0, 0, 0.6);
}

assistant .sidebar {
  padding: 4px 0;
}

assistant .sidebar label {
  min-height: 36px;
  padding: 0 12px;
  color: rgba(0, 0, 0, 0.38);
  font-weight: 500;
}

assistant .sidebar label.highlight {
  color: rgba(0, 0, 0, 0.87);
}

/*********************
 * Spinner Animation *
 *********************/
@keyframes spin {
  to {
    -gtk-icon-transform: rotate(1turn);
  }
}

spinner {
  background: none;
  opacity: 0;
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
}

spinner:checked {
  opacity: 1;
  animation: spin 1s linear infinite;
}

spinner:checked:disabled {
  opacity: 0.5;
}

/****************
 * Text Entries *
 ****************/
spinbutton.vertical, spinbutton:not(.vertical),
entry {
  min-height: 36px;
  padding: 0 8px;
  border-radius: 12px;
  caret-color: currentColor;
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), box-shadow 300ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 0 0 2px transparent;
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.87);
}

spinbutton.vertical:focus, spinbutton:focus:not(.vertical),
entry:focus {
  background-color: alpha(currentColor, 0.05);
  box-shadow: inset 0 0 0 2px #1A73E8;
}

spinbutton.vertical:drop(active), spinbutton:drop(active):not(.vertical),
entry:drop(active) {
  background-color: alpha(currentColor, 0.08);
  box-shadow: inset 0 0 0 2px alpha(currentColor, 0.08);
}

spinbutton.vertical:disabled, spinbutton:disabled:not(.vertical),
entry:disabled {
  box-shadow: inset 0 0 0 2px transparent;
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.38);
}

spinbutton.flat.vertical, spinbutton.flat:not(.vertical),
entry.flat {
  min-height: 0;
  padding: 2px;
  border-radius: 0;
  background-color: transparent;
}

spinbutton.vertical image, spinbutton:not(.vertical) image,
entry image {
  color: rgba(0, 0, 0, 0.6);
}

spinbutton.vertical image:hover, spinbutton:not(.vertical) image:hover, spinbutton.vertical image:active, spinbutton:not(.vertical) image:active,
entry image:hover,
entry image:active {
  color: rgba(0, 0, 0, 0.87);
}

spinbutton.vertical image:disabled, spinbutton:not(.vertical) image:disabled,
entry image:disabled {
  color: rgba(0, 0, 0, 0.38);
}

spinbutton.vertical image.left, spinbutton:not(.vertical) image.left,
entry image.left {
  margin-left: 2px;
  margin-right: 6px;
}

spinbutton.vertical image.right, spinbutton:not(.vertical) image.right,
entry image.right {
  margin-left: 6px;
  margin-right: 2px;
}

spinbutton.vertical undershoot.left, spinbutton:not(.vertical) undershoot.left,
entry undershoot.left {
  background-color: transparent;
  background-image: linear-gradient(to top, transparent 50%, rgba(0, 0, 0, 0.26) 50%);
  padding-left: 1px;
  background-size: 1px 12px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: left top;
  margin: 0 4px;
  margin: 4px 0;
}

spinbutton.vertical undershoot.right, spinbutton:not(.vertical) undershoot.right,
entry undershoot.right {
  background-color: transparent;
  background-image: linear-gradient(to top, transparent 50%, rgba(0, 0, 0, 0.26) 50%);
  padding-right: 1px;
  background-size: 1px 12px;
  background-repeat: repeat-y;
  background-origin: content-box;
  background-position: right top;
  margin: 0 4px;
  margin: 4px 0;
}

spinbutton.error.vertical, spinbutton.error:not(.vertical),
entry.error {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), box-shadow 300ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 0 0 2px transparent;
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.87);
}

spinbutton.error.vertical:focus, spinbutton.error:focus:not(.vertical),
entry.error:focus {
  background-color: alpha(currentColor, 0.05);
  box-shadow: inset 0 0 0 2px #E53935;
}

spinbutton.error.vertical:disabled, spinbutton.error:disabled:not(.vertical),
entry.error:disabled {
  box-shadow: inset 0 0 0 2px transparent;
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.38);
}

spinbutton.warning.vertical, spinbutton.warning:not(.vertical),
entry.warning {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), box-shadow 300ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 0 0 2px transparent;
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.87);
}

spinbutton.warning.vertical:focus, spinbutton.warning:focus:not(.vertical),
entry.warning:focus {
  background-color: alpha(currentColor, 0.05);
  box-shadow: inset 0 0 0 2px #FFD600;
}

spinbutton.warning.vertical:disabled, spinbutton.warning:disabled:not(.vertical),
entry.warning:disabled {
  box-shadow: inset 0 0 0 2px transparent;
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.38);
}

spinbutton.vertical progress, spinbutton:not(.vertical) progress,
entry progress {
  margin: 2px -8px;
  border-bottom: 2px solid #1A73E8;
  background-color: transparent;
}

.gedit-search-slider .linked:not(.vertical) > entry {
  border-radius: 12px;
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), box-shadow 300ms cubic-bezier(0, 0, 0.2, 1);
  border-image: none;
  box-shadow: inset 0 0 0 2px transparent;
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.87);
}

.gedit-search-slider .linked:not(.vertical) > entry:focus {
  border-image: none;
  box-shadow: inset 0 0 0 2px #1A73E8;
}

.gedit-search-slider .linked:not(.vertical) > entry:drop(active) {
  box-shadow: inset 0 0 0 2px alpha(currentColor, 0.08);
}

.gedit-search-slider .linked:not(.vertical) > entry:disabled {
  box-shadow: inset 0 0 0 2px transparent;
  background-color: #FAFAFA;
  color: rgba(0, 0, 0, 0.38);
}

.gedit-search-slider .linked:not(.vertical) > entry.error {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), box-shadow 300ms cubic-bezier(0, 0, 0.2, 1);
  border-image: none;
  box-shadow: inset 0 0 0 2px transparent;
  background-color: #E53935;
  color: white;
}

.gedit-search-slider .linked:not(.vertical) > entry.error:focus {
  border-image: none;
  box-shadow: inset 0 0 0 2px #E53935;
}

.gedit-search-slider .linked:not(.vertical) > entry.error:disabled {
  box-shadow: inset 0 0 0 2px transparent;
  background-color: #FAFAFA;
  color: rgba(0, 0, 0, 0.38);
}

.gedit-search-slider .linked:not(.vertical) > entry.error image {
  color: rgba(255, 255, 255, 0.7);
}

.gedit-search-slider .linked:not(.vertical) > entry.error image:hover, .gedit-search-slider .linked:not(.vertical) > entry.error image:active {
  color: white;
}

.gedit-search-slider .linked:not(.vertical) > entry.error image:disabled {
  color: rgba(255, 255, 255, 0.5);
}

.gedit-search-slider .linked:not(.vertical) > entry.warning {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), box-shadow 300ms cubic-bezier(0, 0, 0.2, 1);
  border-image: none;
  box-shadow: inset 0 0 0 2px transparent;
  background-color: #FFD600;
  color: rgba(0, 0, 0, 0.87);
}

.gedit-search-slider .linked:not(.vertical) > entry.warning:focus {
  border-image: none;
  box-shadow: inset 0 0 0 2px #FFD600;
}

.gedit-search-slider .linked:not(.vertical) > entry.warning:disabled {
  box-shadow: inset 0 0 0 2px transparent;
  background-color: #FAFAFA;
  color: rgba(0, 0, 0, 0.38);
}

.gedit-search-slider .linked:not(.vertical) > entry.warning image {
  color: rgba(0, 0, 0, 0.6);
}

.gedit-search-slider .linked:not(.vertical) > entry.warning image:hover, .gedit-search-slider .linked:not(.vertical) > entry.warning image:active {
  color: rgba(0, 0, 0, 0.87);
}

.gedit-search-slider .linked:not(.vertical) > entry.warning image:disabled {
  color: rgba(0, 0, 0, 0.38);
}

treeview entry.flat, treeview entry {
  background-color: #FFFFFF;
}

treeview entry.flat, treeview entry.flat:focus, treeview entry, treeview entry:focus {
  border-image: none;
  box-shadow: none;
}

.entry-tag, .photos-entry-tag, .documents-entry-tag {
  margin: 2px;
  border-radius: 9999px;
  box-shadow: none;
  background-color: rgba(0, 0, 0, 0.15);
  color: rgba(0, 0, 0, 0.87);
}

.entry-tag:hover, .photos-entry-tag:hover, .documents-entry-tag:hover {
  background-image: image(alpha(currentColor, 0.08));
}

:dir(ltr) .entry-tag, :dir(ltr) .photos-entry-tag, :dir(ltr) .documents-entry-tag {
  margin-left: 4px;
  margin-right: 0;
  padding-left: 12px;
  padding-right: 8px;
}

:dir(rtl) .entry-tag, :dir(rtl) .photos-entry-tag, :dir(rtl) .documents-entry-tag {
  margin-left: 0;
  margin-right: 4px;
  padding-left: 8px;
  padding-right: 12px;
}

.entry-tag.button, .button.photos-entry-tag, .button.documents-entry-tag {
  box-shadow: none;
  background-color: transparent;
}

.entry-tag.button:not(:hover):not(:active), .button.photos-entry-tag:not(:hover):not(:active), .button.documents-entry-tag:not(:hover):not(:active) {
  color: rgba(0, 0, 0, 0.6);
}

/***********
 * Buttons *
 ***********/
@keyframes needs-attention {
  from {
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.001, to(#1A73E8), to(transparent));
  }
  to {
    background-image: -gtk-gradient(radial, center center, 0, center center, 0.5, to(#1A73E8), to(transparent));
  }
}

#XfceNotifyWindow button, .xfce4-panel.background button, .xfce4-panel.background button.flat, .budgie-osd-window .drop-shadow button, .raven-mpris button.image-button, .mate-panel-menu-bar button, infobar.warning > revealer > box button, infobar.warning:backdrop > revealer > box button {
  color: rgba(255, 255, 255, 0.7);
}

#XfceNotifyWindow button:focus, .xfce4-panel.background button:focus, .budgie-osd-window .drop-shadow button:focus, .raven-mpris button.image-button:focus, .mate-panel-menu-bar button:focus, infobar.warning > revealer > box button:focus, #XfceNotifyWindow button:hover, .xfce4-panel.background button:hover, .budgie-osd-window .drop-shadow button:hover, .raven-mpris button.image-button:hover, .mate-panel-menu-bar button:hover, infobar.warning > revealer > box button:hover, #XfceNotifyWindow button:active, .xfce4-panel.background button:active, .budgie-osd-window .drop-shadow button:active, .raven-mpris button.image-button:active, .mate-panel-menu-bar button:active, infobar.warning > revealer > box button:active, #XfceNotifyWindow button:checked, .xfce4-panel.background button:checked, .budgie-osd-window .drop-shadow button:checked, .raven-mpris button.image-button:checked, .mate-panel-menu-bar button:checked, infobar.warning > revealer > box button:checked {
  color: white;
}

#XfceNotifyWindow button:disabled, .xfce4-panel.background button:disabled, .budgie-osd-window .drop-shadow button:disabled, .raven-mpris button.image-button:disabled, .mate-panel-menu-bar button:disabled, infobar.warning > revealer > box button:disabled {
  color: rgba(255, 255, 255, 0.3);
}

#XfceNotifyWindow button:checked:disabled, .xfce4-panel.background button:checked:disabled, .budgie-osd-window .drop-shadow button:checked:disabled, .raven-mpris button.image-button:checked:disabled, .mate-panel-menu-bar button:checked:disabled, infobar.warning > revealer > box button:checked:disabled {
  color: rgba(255, 255, 255, 0.5);
}

actionbar > revealer > box .linked > button:not(.suggested-action):not(.destructive-action), button {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 300ms cubic-bezier(0, 0, 0.2, 1), background-image 1200ms cubic-bezier(0, 0, 0.2, 1);
  outline: none;
  box-shadow: inset 0 0 0 9999px transparent;
  background-color: alpha(currentColor, 0.05);
  background-image: radial-gradient(circle, transparent 10%, transparent 0%);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 1000% 1000%;
  color: rgba(0, 0, 0, 0.87);
}

actionbar > revealer > box .linked > button:focus:not(.suggested-action):not(.destructive-action), button:focus {
  box-shadow: inset 0 0 0 2px alpha(currentColor, 0.08);
}

actionbar > revealer > box .linked > button:hover:not(.suggested-action):not(.destructive-action), button:hover {
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
}

actionbar > revealer > box .linked > button:active:not(.suggested-action):not(.destructive-action), button:active {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms, border 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
  background-image: radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
  background-size: 0% 0%;
}

actionbar > revealer > box .linked > button:disabled:not(.suggested-action):not(.destructive-action), button:disabled {
  box-shadow: none;
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.38);
}

actionbar > revealer > box .linked > button:checked:not(.suggested-action):not(.destructive-action), button:checked {
  box-shadow: none;
  background-color: #1A73E8;
  color: white;
}

actionbar > revealer > box .linked > button:checked:hover:not(.suggested-action):not(.destructive-action), button:checked:hover {
  box-shadow: inset 0 0 0 9999px transparent;
}

actionbar > revealer > box .linked > button:checked:disabled:not(.suggested-action):not(.destructive-action), button:checked:disabled {
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.38);
}

.budgie-notification-window .linked > button, .budgie-notification-window .linked > button:first-child, .budgie-notification-window .linked > button:last-child, .raven-notifications-group list > row button.flat, .raven .expander-button, window.background > box.vertical > toolbar.primary-toolbar > toolitem > box.horizontal:not(.linked) > button.toggle,
window.background > box.vertical > toolbar.primary-toolbar > toolitem > .linked > button:not(.toggle):not(.raised):not(.flat), window.background > box.vertical > toolbar.primary-toolbar > toolitem button.flat.scale, window.background > box.vertical > toolbar.primary-toolbar > toolitem > .linked > button.image-button.raised, window.csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > .linked > button,
window.csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > box.horizontal > button,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > .linked > button,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > box.horizontal > button, .nautilus-window headerbar revealer > button, .linked:not(.vertical) > button.disclosure-button:not(.suggested-action):not(.destructive-action):not(:only-child), filechooser #pathbarbox > stack > box > button, check,
radio, headerbar button.titlebutton, button.close, button.circular, .inline-toolbar button.image-button, button.image-button {
  border-radius: 9999px;
}

.budgie-notification-window .linked > button label, .budgie-notification-window .linked > button:first-child label, .budgie-notification-window .linked > button:last-child label, .raven-notifications-group list > row button.flat label, .raven .expander-button label, window.background > box.vertical > toolbar.primary-toolbar > toolitem > box.horizontal:not(.linked) > button.toggle label,
window.background > box.vertical > toolbar.primary-toolbar > toolitem > .linked > button:not(.toggle):not(.raised):not(.flat) label, window.background > box.vertical > toolbar.primary-toolbar > toolitem button.flat.scale label, window.background > box.vertical > toolbar.primary-toolbar > toolitem > .linked > button.image-button.raised label, window.csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > .linked > button label,
window.csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > box.horizontal > button label,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > .linked > button label,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > box.horizontal > button label, .nautilus-window headerbar revealer > button label, .linked:not(.vertical) > button.disclosure-button:not(.suggested-action):not(.destructive-action):not(:only-child) label, filechooser #pathbarbox > stack > box > button label, check label,
radio label, headerbar button.titlebutton label, button.close label, button.circular label, .inline-toolbar button.image-button label, button.image-button label {
  padding: 0;
}

.pluma-window paned.horizontal box.vertical box.horizontal button.flat, .gedit-search-slider .linked > button, .gedit-document-panel row button.flat, .nautilus-window .floating-bar button, placessidebar.sidebar row button.sidebar-button, notebook > header tab button.flat, spinbutton.vertical button, spinbutton:not(.vertical) button {
  min-height: 24px;
  min-width: 24px;
  padding: 0;
  border-radius: 9999px;
}

button {
  min-height: 24px;
  min-width: 16px;
  padding: 6px 10px;
  border-radius: 12px;
}

button:drop(active) {
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
}

.budgie-settings-window buttonbox.inline-toolbar button, .budgie-session-dialog .linked.horizontal > button,
.budgie-polkit-dialog .linked.horizontal > button,
.budgie-run-dialog .linked.horizontal > button, .drop-shadow button, .budgie-panel button, .budgie-popover row button, #mate-menu button, #MatePanelPopupWindow button, popover.messagepopover .popover-action-area button, tabbox > tab button, .gedit-search-slider .linked > button, .nautilus-window.background.csd notebook > header tab button.flat, .nautilus-window.background.csd notebook > header tab:checked button.flat, .nautilus-window.background.csd notebook > header tab:active button.flat, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:selected button.sidebar-button, placessidebar.sidebar row button.sidebar-button, calendar.button, row button.circular, check,
radio, scrollbar button, notebook > header > tabs > arrow, spinbutton.vertical button, spinbutton:not(.vertical) button, modelbutton.flat,
.menuitem.button.flat, .nemo-window .toolbar button, #buttonbox_frame button, .xfce4-panel.background button, .xfce4-panel.background button.flat, .raven stackswitcher.linked > button, .lock-dialog button, .mate-panel-menu-bar button, window.background.csd.geary-main-window stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button,
window#GearyMainWindow.background.csd stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button, layouttabbar button, filechooser #pathbarbox > stack > box > button, messagedialog.csd .dialog-action-box button, .app-notification button, actionbar > revealer > box button:not(.suggested-action):not(.destructive-action), .caja-pathbar button,
.path-bar.linked:not(.vertical) > button, .nemo-window .primary-toolbar button:not(.text-button), headerbar button:not(.suggested-action):not(.destructive-action), toolbar button, combobox > .linked:not(.vertical) > button:not(:only-child), .inline-toolbar button, button.flat {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), border-image 225ms cubic-bezier(0, 0, 0.2, 1), background-size 300ms cubic-bezier(0, 0, 0.2, 1), background-image 1200ms cubic-bezier(0, 0, 0.2, 1);
  outline: none;
  box-shadow: inset 0 0 0 9999px transparent;
  background-color: transparent;
  background-image: radial-gradient(circle, transparent 10%, transparent 0%);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 1000% 1000%;
  color: rgba(0, 0, 0, 0.6);
}

.budgie-settings-window buttonbox.inline-toolbar button:focus, .budgie-session-dialog .linked.horizontal > button:focus,
.budgie-polkit-dialog .linked.horizontal > button:focus,
.budgie-run-dialog .linked.horizontal > button:focus, .drop-shadow button:focus, .budgie-panel button:focus, .budgie-popover row button:focus, #mate-menu button:focus, #MatePanelPopupWindow button:focus, popover.messagepopover .popover-action-area button:focus, tabbox > tab button:focus, .gedit-search-slider .linked > button:focus, .nautilus-window.background.csd notebook > header tab button.flat:focus, .nautilus-window.background.csd notebook > header tab:checked button.flat:focus, .nautilus-window.background.csd notebook > header tab:active button.flat:focus, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:selected button.sidebar-button:focus, placessidebar.sidebar row button.sidebar-button:focus, calendar.button:focus, row button.circular:focus, check:focus,
radio:focus, scrollbar button:focus, notebook > header > tabs > arrow:focus, spinbutton.vertical button:focus, spinbutton:not(.vertical) button:focus, modelbutton.flat:focus,
.menuitem.button.flat:focus, .nemo-window .toolbar button:focus, #buttonbox_frame button:focus, .xfce4-panel.background button:focus, .raven stackswitcher.linked > button:focus, .lock-dialog button:focus, .mate-panel-menu-bar button:focus, window.background.csd.geary-main-window stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:focus,
window#GearyMainWindow.background.csd stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:focus, layouttabbar button:focus, filechooser #pathbarbox > stack > box > button:focus, messagedialog.csd .dialog-action-box button:focus, .app-notification button:focus, actionbar > revealer > box button:focus:not(.suggested-action):not(.destructive-action), .caja-pathbar button:focus,
.path-bar.linked:not(.vertical) > button:focus, .nemo-window .primary-toolbar button:focus:not(.text-button), headerbar button:focus:not(.suggested-action):not(.destructive-action), toolbar button:focus, combobox > .linked:not(.vertical) > button:focus:not(:only-child), .inline-toolbar button:focus, button.flat:focus {
  box-shadow: inset 0 0 0 2px alpha(currentColor, 0.08);
  color: rgba(0, 0, 0, 0.87);
}

.budgie-settings-window buttonbox.inline-toolbar button:hover, .budgie-session-dialog .linked.horizontal > button:hover,
.budgie-polkit-dialog .linked.horizontal > button:hover,
.budgie-run-dialog .linked.horizontal > button:hover, .drop-shadow button:hover, .budgie-panel button:hover, .budgie-popover row button:hover, #mate-menu button:hover, #MatePanelPopupWindow button:hover, popover.messagepopover .popover-action-area button:hover, tabbox > tab button:hover, .gedit-search-slider .linked > button:hover, .nautilus-window.background.csd notebook > header tab button.flat:hover, .nautilus-window.background.csd notebook > header tab:checked button.flat:hover, .nautilus-window.background.csd notebook > header tab:active button.flat:hover, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:selected button.sidebar-button:hover, placessidebar.sidebar row button.sidebar-button:hover, calendar.button:hover, row button.circular:hover, check:hover,
radio:hover, scrollbar button:hover, notebook > header > tabs > arrow:hover, spinbutton.vertical button:hover, spinbutton:not(.vertical) button:hover, modelbutton.flat:hover,
.menuitem.button.flat:hover, .nemo-window .toolbar button:hover, #buttonbox_frame button:hover, .xfce4-panel.background button:hover, .raven stackswitcher.linked > button:hover, .lock-dialog button:hover, .mate-panel-menu-bar button:hover, window.background.csd.geary-main-window stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:hover,
window#GearyMainWindow.background.csd stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:hover, layouttabbar button:hover, filechooser #pathbarbox > stack > box > button:hover, messagedialog.csd .dialog-action-box button:hover, .app-notification button:hover, actionbar > revealer > box button:hover:not(.suggested-action):not(.destructive-action), .caja-pathbar button:hover,
.path-bar.linked:not(.vertical) > button:hover, .nemo-window .primary-toolbar button:hover:not(.text-button), headerbar button:hover:not(.suggested-action):not(.destructive-action), toolbar button:hover, combobox > .linked:not(.vertical) > button:hover:not(:only-child), .inline-toolbar button:hover, button.flat:hover {
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
  color: rgba(0, 0, 0, 0.87);
}

.budgie-settings-window buttonbox.inline-toolbar button:active, .budgie-session-dialog .linked.horizontal > button:active,
.budgie-polkit-dialog .linked.horizontal > button:active,
.budgie-run-dialog .linked.horizontal > button:active, .drop-shadow button:active, .budgie-panel button:active, .budgie-popover row button:active, #mate-menu button:active, #MatePanelPopupWindow button:active, popover.messagepopover .popover-action-area button:active, tabbox > tab button:active, .gedit-search-slider .linked > button:active, .nautilus-window.background.csd notebook > header tab button.flat:active, .nautilus-window.background.csd notebook > header tab:checked button.flat:active, .nautilus-window.background.csd notebook > header tab:active button.flat:active, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:selected button.sidebar-button:active, placessidebar.sidebar row button.sidebar-button:active, calendar.button:active, row button.circular:active, check:active,
radio:active, scrollbar button:active, notebook > header > tabs > arrow:active, spinbutton.vertical button:active, spinbutton:not(.vertical) button:active, modelbutton.flat:active,
.menuitem.button.flat:active, .nemo-window .toolbar button:active, #buttonbox_frame button:active, .xfce4-panel.background button:active, .raven stackswitcher.linked > button:active, .lock-dialog button:active, .mate-panel-menu-bar button:active, window.background.csd.geary-main-window stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:active,
window#GearyMainWindow.background.csd stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:active, layouttabbar button:active, filechooser #pathbarbox > stack > box > button:active, messagedialog.csd .dialog-action-box button:active, .app-notification button:active, actionbar > revealer > box button:active:not(.suggested-action):not(.destructive-action), .caja-pathbar button:active,
.path-bar.linked:not(.vertical) > button:active, .nemo-window .primary-toolbar button:active:not(.text-button), headerbar button:active:not(.suggested-action):not(.destructive-action), toolbar button:active, combobox > .linked:not(.vertical) > button:active:not(:only-child), .inline-toolbar button:active, button.flat:active {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), border-image 225ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
  background-image: radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
  background-size: 0% 0%;
  color: rgba(0, 0, 0, 0.87);
}

.budgie-settings-window buttonbox.inline-toolbar button:disabled, .budgie-session-dialog .linked.horizontal > button:disabled,
.budgie-polkit-dialog .linked.horizontal > button:disabled,
.budgie-run-dialog .linked.horizontal > button:disabled, .drop-shadow button:disabled, .budgie-panel button:disabled, .budgie-popover row button:disabled, #mate-menu button:disabled, #MatePanelPopupWindow button:disabled, popover.messagepopover .popover-action-area button:disabled, tabbox > tab button:disabled, .gedit-search-slider .linked > button:disabled, .nautilus-window.background.csd notebook > header tab button.flat:disabled, .nautilus-window.background.csd notebook > header tab:checked button.flat:disabled, .nautilus-window.background.csd notebook > header tab:active button.flat:disabled, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:selected button.sidebar-button:disabled, placessidebar.sidebar row button.sidebar-button:disabled, calendar.button:disabled, row button.circular:disabled, check:disabled,
radio:disabled, scrollbar button:disabled, notebook > header > tabs > arrow:disabled, spinbutton.vertical button:disabled, spinbutton:not(.vertical) button:disabled, modelbutton.flat:disabled,
.menuitem.button.flat:disabled, .nemo-window .toolbar button:disabled, #buttonbox_frame button:disabled, .xfce4-panel.background button:disabled, .raven stackswitcher.linked > button:disabled, .lock-dialog button:disabled, .mate-panel-menu-bar button:disabled, window.background.csd.geary-main-window stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:disabled,
window#GearyMainWindow.background.csd stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:disabled, layouttabbar button:disabled, filechooser #pathbarbox > stack > box > button:disabled, messagedialog.csd .dialog-action-box button:disabled, .app-notification button:disabled, actionbar > revealer > box button:disabled:not(.suggested-action):not(.destructive-action), .caja-pathbar button:disabled,
.path-bar.linked:not(.vertical) > button:disabled, .nemo-window .primary-toolbar button:disabled:not(.text-button), headerbar button:disabled:not(.suggested-action):not(.destructive-action), toolbar button:disabled, combobox > .linked:not(.vertical) > button:disabled:not(:only-child), .inline-toolbar button:disabled, button.flat:disabled {
  box-shadow: none;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.26);
}

.nemo-window .toolbar button:checked, #buttonbox_frame button:checked, .xfce4-panel.background button:checked, .raven stackswitcher.linked > button:checked, .lock-dialog button:checked, .mate-panel-menu-bar button:checked, window.background.csd.geary-main-window stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:checked,
window#GearyMainWindow.background.csd stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:checked, layouttabbar button:checked, filechooser #pathbarbox > stack > box > button:checked, messagedialog.csd .dialog-action-box button:checked, .app-notification button:checked, actionbar > revealer > box button:checked:not(.suggested-action):not(.destructive-action), .caja-pathbar button:checked,
.path-bar.linked:not(.vertical) > button:checked, .nemo-window .primary-toolbar button:checked:not(.text-button), headerbar button:checked:not(.suggested-action):not(.destructive-action), toolbar button:checked, combobox > .linked:not(.vertical) > button:checked:not(:only-child), .inline-toolbar button:checked, button.flat:checked, button.flat:checked:hover {
  background-color: alpha(currentColor, 0.1);
  color: rgba(0, 0, 0, 0.87);
}

.nemo-window .toolbar button:checked:disabled, #buttonbox_frame button:checked:disabled, .xfce4-panel.background button:checked:disabled, .raven stackswitcher.linked > button:checked:disabled, .lock-dialog button:checked:disabled, .mate-panel-menu-bar button:checked:disabled, window.background.csd.geary-main-window stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:checked:disabled,
window#GearyMainWindow.background.csd stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar button:checked:disabled, layouttabbar button:checked:disabled, filechooser #pathbarbox > stack > box > button:checked:disabled, messagedialog.csd .dialog-action-box button:checked:disabled, .app-notification button:checked:disabled, actionbar > revealer > box button:checked:disabled:not(.suggested-action):not(.destructive-action), .caja-pathbar button:checked:disabled,
.path-bar.linked:not(.vertical) > button:checked:disabled, .nemo-window .primary-toolbar button:checked:disabled:not(.text-button), headerbar button:checked:disabled:not(.suggested-action):not(.destructive-action), toolbar button:checked:disabled, combobox > .linked:not(.vertical) > button:checked:disabled:not(:only-child), .inline-toolbar button:checked:disabled, button.flat:checked:disabled {
  background-color: alpha(currentColor, 0.1);
  color: rgba(0, 0, 0, 0.38);
}

button.text-button {
  min-width: 32px;
  padding-left: 16px;
  padding-right: 16px;
}

button.image-button {
  min-width: 24px;
  padding: 6px;
}

button.text-button.image-button {
  min-width: 24px;
  padding: 6px;
  border-radius: 12px;
}

button.text-button.image-button label:first-child {
  margin-left: 10px;
}

button.text-button.image-button label:last-child {
  margin-right: 10px;
}

button.text-button.image-button.flat label:first-child {
  margin-left: 6px;
}

button.text-button.image-button.flat label:last-child {
  margin-right: 6px;
}

button.text-button.image-button image:not(:only-child) {
  margin: 0 4px;
}

.linked:not(.vertical) > button.flat:not(:only-child), .linked.vertical > button.flat:not(:only-child) {
  border-radius: 12px;
}

.linked:not(.vertical) > button.flat:not(:only-child).image-button:not(.text-button), .linked.vertical > button.flat:not(:only-child).image-button:not(.text-button) {
  border-radius: 9999px;
}

.linked:not(.vertical) > button.flat:focus, .linked.vertical > button.flat:focus {
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
}

button.osd {
  min-width: 24px;
  min-width: 24px;
  padding: 6px;
  background-color: #212121;
  color: white;
}

button.osd:focus {
  box-shadow: none;
}

button.osd:hover {
  background-color: #424242;
  color: white;
}

button.osd:active {
  background-color: #595959;
  color: white;
}

button.osd:disabled {
  opacity: 0;
}

button.osd.image-button, button.osd.circular {
  padding: 12px;
}

button.osd.image-button > image, button.osd.circular > image {
  padding: 0;
}

button.suggested-action {
  background-color: #1A73E8;
  color: white;
  box-shadow: none;
}

button.suggested-action:disabled {
  box-shadow: none;
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.38);
}

button.suggested-action:hover {
  box-shadow: inset 0 0 0 9999px transparent, 0 2px 2.4px -1px rgba(26, 115, 232, 0.2), 0 4px 3px 0 rgba(26, 115, 232, 0.14), 0 1px 6px 0 rgba(26, 115, 232, 0.12);
}

button.suggested-action:checked {
  background-color: #5f9def;
}

button.suggested-action:checked:hover {
  box-shadow: inset 0 0 0 9999px transparent, 0 3px 3px -3px rgba(26, 115, 232, 0.3), 0 2px 3px -1px rgba(26, 115, 232, 0.24), 0 2px 5px 0 rgba(26, 115, 232, 0.12);
}

button.suggested-action:focus {
  box-shadow: 0 0 0 2px rgba(26, 115, 232, 0.35);
}

button.suggested-action.flat {
  background-color: transparent;
  color: #1A73E8;
}

button.suggested-action.flat:disabled {
  box-shadow: none;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.26);
}

button.suggested-action.flat:checked {
  background-color: rgba(26, 115, 232, 0.3);
}

button.destructive-action {
  background-color: #E53935;
  color: white;
  box-shadow: none;
}

button.destructive-action:disabled {
  box-shadow: none;
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.38);
}

button.destructive-action:hover {
  box-shadow: inset 0 0 0 9999px transparent, 0 2px 2.4px -1px rgba(229, 57, 53, 0.2), 0 4px 3px 0 rgba(229, 57, 53, 0.14), 0 1px 6px 0 rgba(229, 57, 53, 0.12);
}

button.destructive-action:checked {
  background-color: #ed7472;
}

button.destructive-action:checked:hover {
  box-shadow: inset 0 0 0 9999px transparent, 0 3px 3px -3px rgba(229, 57, 53, 0.3), 0 2px 3px -1px rgba(229, 57, 53, 0.24), 0 2px 5px 0 rgba(229, 57, 53, 0.12);
}

button.destructive-action:focus {
  box-shadow: 0 0 0 2px rgba(229, 57, 53, 0.35);
}

button.destructive-action.flat {
  background-color: transparent;
  color: #E53935;
}

button.destructive-action.flat:disabled {
  box-shadow: none;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.26);
}

button.destructive-action.flat:checked {
  background-color: rgba(229, 57, 53, 0.3);
}

.stack-switcher > button > label {
  margin: 0 -6px;
  padding: 0 6px;
}

.stack-switcher > button > image {
  margin: -3px -6px;
  padding: 3px 6px;
}

.stack-switcher > button.needs-attention:checked > label,
.stack-switcher > button.needs-attention:checked > image {
  animation: none;
  background-image: none;
}

.primary-toolbar button {
  -gtk-icon-shadow: none;
}

stacksidebar.sidebar row.needs-attention > label, .stack-switcher > button.needs-attention > label,
.stack-switcher > button.needs-attention > image {
  animation: needs-attention 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-repeat: no-repeat;
  background-position: right 3px;
  background-size: 6px 6px;
}

stacksidebar.sidebar row.needs-attention > label:dir(rtl), .stack-switcher > button.needs-attention > label:dir(rtl),
.stack-switcher > button.needs-attention > image:dir(rtl) {
  background-position: left 3px;
}

modelbutton.flat,
.menuitem.button.flat {
  min-height: 28px;
  padding: 0 8px;
  border-radius: 5px;
  color: rgba(0, 0, 0, 0.87);
}

modelbutton.flat arrow.left {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

modelbutton.flat arrow.right {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

button.color {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
}

/*********
 * Links *
 *********/
*:link {
  color: #1A73E8;
}

*:visited {
  color: #AB47BC;
}

button.link:link, button.link:link:focus, button.link:link:hover, button.link:link:active {
  color: #1A73E8;
}

button.link:visited, button.link:visited:focus, button.link:visited:hover, button.link:visited:active {
  color: #AB47BC;
}

button.link > label {
  text-decoration-line: underline;
}

/*****************
 * GtkSpinButton *
 *****************/
spinbutton:not(.vertical) {
  padding: 0;
}

spinbutton:not(.vertical) entry {
  min-width: 32px;
  margin: 0;
  border-image: none;
  border-radius: 0;
  box-shadow: none;
  background-color: transparent;
}

spinbutton:not(.vertical) button {
  border: solid 6px transparent;
}

spinbutton:not(.vertical) button:focus:not(:hover):not(:active):not(:disabled) {
  box-shadow: inset 0 0 0 9999px transparent;
  color: rgba(0, 0, 0, 0.6);
}

spinbutton:not(.vertical) button.up:dir(ltr), spinbutton:not(.vertical) button.down:dir(rtl) {
  margin-left: -3px;
}

spinbutton:not(.vertical) button.up:dir(rtl), spinbutton:not(.vertical) button.down:dir(ltr) {
  margin-right: -3px;
}

spinbutton.vertical {
  padding: 0;
}

spinbutton.vertical:disabled {
  color: rgba(0, 0, 0, 0.38);
}

spinbutton.vertical entry {
  margin: 0;
  border-image: none;
  border-radius: 0;
  box-shadow: none;
  background-color: transparent;
  min-height: 36px;
  min-width: 42px;
  padding: 0;
}

spinbutton.vertical button {
  padding: 0;
  border: solid 6px transparent;
}

spinbutton.vertical button:focus:not(:hover):not(:active) {
  box-shadow: inset 0 0 0 9999px transparent;
  color: rgba(0, 0, 0, 0.6);
}

spinbutton.vertical button.up {
  margin: 0 3px;
}

spinbutton.vertical button.down {
  margin: 0 3px;
}

treeview spinbutton:not(.vertical) {
  min-height: 0;
  border-style: none;
  border-radius: 0;
}

treeview spinbutton:not(.vertical) entry {
  min-height: 0;
  padding: 1px 2px;
}

/**************
 * ComboBoxes *
 **************/
combobox arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  min-height: 16px;
  min-width: 16px;
}

combobox decoration {
  transition: none;
}

combobox button.combo cellview:dir(ltr) {
  margin-left: -2px;
}

combobox button.combo cellview:dir(rtl) {
  margin-right: -2px;
}

combobox menu menuitem {
  min-height: 20px;
  min-width: 40px;
  padding: 3px 9px;
}

combobox.linked button:nth-child(2):dir(ltr) {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

combobox.linked button:nth-child(2):dir(rtl) {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

combobox > .linked:not(.vertical) > entry:not(:only-child) {
  border-radius: 12px;
}

combobox > .linked:not(.vertical) > entry:not(:only-child):first-child {
  margin-right: -36px;
  padding-right: 36px;
}

combobox > .linked:not(.vertical) > entry:not(:only-child):last-child {
  margin-left: -36px;
  padding-left: 36px;
}

combobox > .linked:not(.vertical) > button:not(:only-child) {
  min-height: 16px;
  min-width: 16px;
  margin: 6px;
  padding: 4px;
  border-radius: 12px;
}

.linked:not(.vertical) > combobox:not(:first-child) > box > button.combo {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}

.linked:not(.vertical) > combobox:not(:last-child) > box > button.combo {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0;
}

.linked.vertical > combobox:not(:first-child) > box > button.combo {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}

.linked.vertical > combobox:not(:last-child) > box > button.combo {
  border-bottom-left-radius: 0;
  border-bottom-right-radius: 0;
}

button.combo:only-child {
  border-radius: 12px;
  font-weight: normal;
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), box-shadow 300ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 0 0 2px transparent;
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.87);
}

button.combo:only-child:focus {
  background-color: alpha(currentColor, 0.08);
  box-shadow: inset 0 0 0 2px rgba(0, 0, 0, 0.26);
}

button.combo:only-child:hover {
  background-color: alpha(currentColor, 0.08);
  box-shadow: inset 0 0 0 2px alpha(currentColor, 0.08);
}

button.combo:only-child:checked {
  background-color: alpha(currentColor, 0.05);
  box-shadow: inset 0 0 0 2px #1A73E8;
}

button.combo:only-child:disabled {
  box-shadow: inset 0 0 0 2px transparent;
  background-color: alpha(currentColor, 0.05);
  color: rgba(0, 0, 0, 0.38);
}

/************
 * Toolbars *
 ************/
toolbar {
  -GtkWidget-window-dragging: true;
  padding: 6px;
  background-color: #F2F2F2;
}

.osd toolbar {
  background-color: transparent;
}

frame.documents-dropdown, .app-notification, toolbar.osd {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  padding: 6px;
  border-radius: 12px;
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

frame.documents-dropdown:backdrop, .app-notification:backdrop, toolbar.osd:backdrop {
  box-shadow: 0 3px 2px -3px rgba(0, 0, 0, 0.3), 0 2px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 3px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
}

frame.left.documents-dropdown, .left.app-notification, frame.right.documents-dropdown, .right.app-notification, frame.top.documents-dropdown, .top.app-notification, frame.bottom.documents-dropdown, .bottom.app-notification, toolbar.osd.left, toolbar.osd.right, toolbar.osd.top, toolbar.osd.bottom {
  border-radius: 0;
}

frame.bottom.documents-dropdown, .bottom.app-notification, toolbar.osd.bottom {
  box-shadow: none;
  background-color: transparent;
  background-image: linear-gradient(to bottom, transparent, rgba(0, 0, 0, 0.1) 30%, rgba(0, 0, 0, 0.2) 50%, rgba(0, 0, 0, 0.4));
}

toolbar.horizontal > separator {
  margin: 2px;
}

toolbar.vertical > separator {
  margin: 2px;
}

toolbar:not(.inline-toolbar):not(.osd) scale,
toolbar:not(.inline-toolbar):not(.osd) entry,
toolbar:not(.inline-toolbar):not(.osd) spinbutton,
toolbar:not(.inline-toolbar):not(.osd) button,
toolbar:not(.inline-toolbar):not(.osd) stackswitcher {
  margin: 2px;
}

toolbar:not(.inline-toolbar):not(.osd) .linked entry:not(:first-child),
toolbar:not(.inline-toolbar):not(.osd) .linked spinbutton:not(:first-child),
toolbar:not(.inline-toolbar):not(.osd) .linked button:not(:first-child) {
  margin-left: 0;
}

toolbar:not(.inline-toolbar):not(.osd) .linked entry:not(:last-child),
toolbar:not(.inline-toolbar):not(.osd) .linked spinbutton:not(:last-child),
toolbar:not(.inline-toolbar):not(.osd) .linked button:not(:last-child) {
  margin-right: 0;
}

toolbar:not(.inline-toolbar):not(.osd) spinbutton entry,
toolbar:not(.inline-toolbar):not(.osd) spinbutton button {
  margin: 0;
}

toolbar:not(.inline-toolbar):not(.osd) switch {
  margin: 8px 2px;
}

.inline-toolbar {
  padding: 6px;
  border-style: solid;
  border-width: 0 1px 1px;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #FAFAFA;
}

frame.view + .inline-toolbar {
  border-radius: 0 0 12px 12px;
}

searchbar > revealer > box,
.location-bar {
  padding: 6px;
  border-style: solid;
  border-width: 0 0 1px;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #F2F2F2;
  background-clip: border-box;
}

searchbar > revealer > box {
  margin: -6px;
}

/***************
 * Header bars *
 ***************/
.nemo-window .primary-toolbar button:not(.text-button), headerbar button:not(.suggested-action):not(.destructive-action) {
  color: rgba(0, 0, 0, 0.6);
}

.nemo-window .primary-toolbar .linked:not(.vertical) > button:not(.text-button), headerbar .linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action) {
  border-radius: 9999px;
}

.nemo-window .primary-toolbar button:focus:not(.text-button), headerbar button:focus:not(.suggested-action):not(.destructive-action), .nemo-window .primary-toolbar button:hover:not(.text-button), headerbar button:hover:not(.suggested-action):not(.destructive-action), .nemo-window .primary-toolbar button:active:not(.text-button), headerbar button:active:not(.suggested-action):not(.destructive-action), .nemo-window .primary-toolbar button:checked:not(.text-button), headerbar button:checked:not(.suggested-action):not(.destructive-action) {
  color: rgba(0, 0, 0, 0.87);
}

.nemo-window .primary-toolbar button:disabled:not(.text-button), headerbar button:disabled:not(.suggested-action):not(.destructive-action) {
  color: rgba(0, 0, 0, 0.26);
}

.nemo-window .primary-toolbar button:checked:disabled:not(.text-button), headerbar button:checked:disabled:not(.suggested-action):not(.destructive-action) {
  background-color: transparent;
  color: rgba(0, 0, 0, 0.38);
}

.nemo-window .primary-toolbar button:backdrop:not(.text-button), headerbar button:backdrop:not(.suggested-action):not(.destructive-action) {
  color: rgba(0, 0, 0, 0.38);
}

.nemo-window .primary-toolbar button:backdrop:focus:not(.text-button), headerbar button:backdrop:focus:not(.suggested-action):not(.destructive-action), .nemo-window .primary-toolbar button:backdrop:hover:not(.text-button), headerbar button:backdrop:hover:not(.suggested-action):not(.destructive-action), .nemo-window .primary-toolbar button:backdrop:active:not(.text-button), headerbar button:backdrop:active:not(.suggested-action):not(.destructive-action) {
  color: rgba(0, 0, 0, 0.6);
}

.nemo-window .primary-toolbar button:backdrop:disabled:not(.text-button), headerbar button:backdrop:disabled:not(.suggested-action):not(.destructive-action) {
  color: rgba(0, 0, 0, 0.26);
}

.nemo-window .primary-toolbar button:backdrop:checked:not(.text-button), headerbar button:backdrop:checked:not(.suggested-action):not(.destructive-action) {
  color: rgba(0, 0, 0, 0.6);
}

.nemo-window .primary-toolbar button:backdrop:checked:disabled:not(.text-button), headerbar button:backdrop:checked:disabled:not(.suggested-action):not(.destructive-action) {
  color: rgba(0, 0, 0, 0.26);
}

.nemo-window .primary-toolbar entry, .titlebar entry {
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.87);
}

.nemo-window .primary-toolbar entry:disabled, .titlebar entry:disabled {
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.38);
}

.nemo-window .primary-toolbar entry image, .titlebar entry image {
  color: rgba(0, 0, 0, 0.6);
}

.nemo-window .primary-toolbar entry image:hover, .titlebar entry image:hover, .nemo-window .primary-toolbar entry image:active, .titlebar entry image:active {
  color: rgba(0, 0, 0, 0.87);
}

.nemo-window .primary-toolbar entry image:disabled, .titlebar entry image:disabled {
  color: rgba(0, 0, 0, 0.38);
}

.titlebar {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1), color 75ms cubic-bezier(0, 0, 0.2, 1);
  border-radius: 18px 18px 0 0;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.87);
  padding: 0 6px;
}

.titlebar:disabled {
  color: rgba(0, 0, 0, 0.38);
}

.titlebar:backdrop {
  background-color: #FAFAFA;
  color: rgba(0, 0, 0, 0.6);
}

.titlebar:backdrop:disabled {
  color: rgba(0, 0, 0, 0.26);
}

.titlebar .title {
  padding: 0 12px;
  font-weight: bold;
}

.titlebar .subtitle {
  padding: 0 12px;
  font-size: smaller;
}

.titlebar .subtitle,
.titlebar .dim-label {
  transition: color 75ms cubic-bezier(0, 0, 0.2, 1);
  color: rgba(0, 0, 0, 0.6);
}

.titlebar .subtitle:backdrop,
.titlebar .dim-label:backdrop {
  color: rgba(0, 0, 0, 0.38);
}

.titlebar .titlebar {
  background-color: transparent;
  box-shadow: none;
}

.titlebar headerbar + separator {
  background-color: rgba(0, 0, 0, 0.12);
}

.titlebar .linked:not(.vertical) > entry {
  border-radius: 12px;
}

.titlebar .linked:not(.vertical) > entry.search + button {
  border-radius: 12px;
  margin-left: 3px;
}

.linked:not(.vertical) > .titlebar button.suggested-action, .linked:not(.vertical) > .titlebar button.destructive-action {
  border-radius: 12px;
}

.titlebar button.suggested-action:disabled, .titlebar button.destructive-action:disabled {
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.38);
}

.titlebar button.toggle {
  border-radius: 9999px;
}

.titlebar stackswitcher {
  border-radius: 9999px;
  margin: 6px 0;
}

.titlebar stackswitcher.linked:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button {
  border-radius: 9999px;
}

.titlebar .path-bar button:not(.suggested-action):not(.destructive-action).text-button {
  min-width: 0;
  padding-left: 6px;
  padding-right: 6px;
}

.titlebar.selection-mode {
  transition: background-color 0.1ms 225ms, color 75ms cubic-bezier(0, 0, 0.2, 1);
  animation: ripple-on-headerbar 225ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.2);
  background-color: #1A73E8;
  color: white;
}

.titlebar.selection-mode:backdrop {
  color: rgba(255, 255, 255, 0.7);
}

.titlebar.selection-mode .subtitle:link {
  color: white;
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action) {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 0%, transparent 0%) 0 0 0/0 0 0px;
  color: white;
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):disabled {
  color: rgba(255, 255, 255, 0.5);
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 100%, transparent 0%) 0 0 2/0 0 2px;
  color: white;
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):checked:disabled {
  color: rgba(255, 255, 255, 0.5);
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop {
  color: rgba(255, 255, 255, 0.7);
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop:checked {
  color: rgba(255, 255, 255, 0.7);
}

.titlebar.selection-mode button:not(.suggested-action):not(.destructive-action):backdrop:checked:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.titlebar.selection-mode .selection-menu {
  padding-left: 16px;
  padding-right: 16px;
}

.titlebar.selection-mode .selection-menu arrow {
  -GtkArrow-arrow-scaling: 1;
}

.titlebar.selection-mode .selection-menu .arrow {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

.titlebar .selection-mode {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.2);
  background-color: #1A73E8;
}

.tiled .titlebar, .tiled-top .titlebar, .tiled-right .titlebar, .tiled-bottom .titlebar, .tiled-left .titlebar, .maximized .titlebar, .fullscreen .titlebar {
  border-radius: 0;
}

.titlebar.default-decoration {
  min-height: 36px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  border-radius: 18px 18px 0 0;
  border: none;
  padding: 0 3px;
}

.tiled .titlebar.default-decoration, .maximized .titlebar.default-decoration, .fullscreen .titlebar.default-decoration {
  box-shadow: none;
  border-radius: 0;
}

.titlebar.default-decoration button.titlebutton {
  padding: 0;
  min-height: 24px;
  min-width: 24px;
  margin: 0 3px;
}

.background:not(.csd) .titlebar.default-decoration button.titlebutton:active {
  background-size: 1000% 1000%;
}

.solid-csd .titlebar, .solid-csd .titlebar:dir(rtl), .solid-csd .titlebar:dir(ltr) {
  border-radius: 0;
  box-shadow: none;
}

headerbar {
  min-height: 48px;
  padding: 0 6px;
}

headerbar:not(.titlebar) {
  box-shadow: none;
}

box.vertical headerbar {
  background-color: #FFFFFF;
}

headerbar entry,
headerbar spinbutton,
headerbar button {
  margin-top: 6px;
  margin-bottom: 6px;
}

headerbar separator.titlebutton {
  margin-top: 12px;
  margin-bottom: 12px;
  background-color: rgba(0, 0, 0, 0.12);
}

headerbar switch {
  margin-top: 12px;
  margin-bottom: 12px;
}

headerbar spinbutton button {
  margin-top: 0;
  margin-bottom: 0;
}

headerbar .entry-tag, headerbar .photos-entry-tag, headerbar .documents-entry-tag {
  margin-top: 5px;
  margin-bottom: 5px;
}

headerbar.windowhandle viewswitcher button:not(.titlebutton):not(.suggested-action):not(.destructive-action) {
  border-radius: 0;
  margin-top: 0;
  margin-bottom: 0;
  min-width: 120px;
  padding: 0;
}

headerbar.windowhandle viewswitcher button:not(.titlebutton):not(.suggested-action):not(.destructive-action) > stack > box {
  padding: 0 12px;
}

headerbar.windowhandle viewswitcher button:not(.titlebutton):not(.suggested-action):not(.destructive-action) > stack > box.narrow {
  font-size: 10px;
}

headerbar.windowhandle viewswitcher button:not(.titlebutton):not(.suggested-action):not(.destructive-action) > stack > box.narrow image {
  margin-top: 3px;
}

headerbar.windowhandle viewswitcher button:not(.titlebutton):not(.suggested-action):not(.destructive-action):focus {
  box-shadow: none;
}

headerbar.windowhandle viewswitchertitle > squeezer {
  margin-top: 0;
  margin-bottom: 0;
  background: none;
}

headerbar.windowhandle viewswitchertitle > squeezer > viewswitcher {
  margin: 0 0;
  background: none;
}

headerbar.windowhandle viewswitchertitle > squeezer > viewswitcher > box.horizontal > button.radio {
  margin: 0;
  padding: 0;
  border-radius: 0;
}

/************
 * Pathbars *
 ************/
.caja-pathbar button,
.path-bar.linked:not(.vertical) > button {
  padding-left: 6px;
  padding-right: 6px;
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #1A73E8 0%, transparent 0%) 0 0 0/0 0 0px;
  border-radius: 12px;
}

.caja-pathbar button:checked,
.path-bar.linked:not(.vertical) > button:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), #1A73E8 100%, transparent 0%) 0 0 2/0 0 2px;
}

.caja-pathbar button:checked,
.path-bar.linked:not(.vertical) > button:checked,
.path-bar.linked:not(.vertical) > button:checked:disabled {
  background-color: transparent;
}

.caja-pathbar button label, .caja-pathbar button image,
.path-bar.linked:not(.vertical) > button label,
.path-bar.linked:not(.vertical) > button image {
  margin-left: 2px;
  margin-right: 2px;
}

.caja-pathbar button.text-button,
.path-bar.linked:not(.vertical) > button.text-button {
  min-width: 0;
}

.caja-pathbar button.slider-button,
.path-bar.linked:not(.vertical) > button.slider-button {
  padding-left: 4px;
  padding-right: 4px;
}

/**************
 * Tree Views *
 **************/
treeview.view {
  border-left-color: rgba(0, 0, 0, 0.26);
  border-top-color: rgba(0, 0, 0, 0.12);
  -gtk-outline-radius: 3px;
}

* {
  -GtkTreeView-horizontal-separator: 4;
  -GtkTreeView-grid-line-width: 1;
  -GtkTreeView-grid-line-pattern: '';
  -GtkTreeView-tree-line-width: 1;
  -GtkTreeView-tree-line-pattern: '';
  -GtkTreeView-expander-size: 16;
}

treeview.view:selected {
  background-image: image(alpha(currentColor, 0.1));
}

treeview.view:hover, treeview.view:selected {
  border-radius: 0;
}

treeview.view.separator {
  min-height: 5px;
  color: rgba(0, 0, 0, 0.12);
}

treeview.view:drop(active) {
  border-style: solid none;
  border-width: 9999px;
  border-color: alpha(currentColor, 0.08);
}

treeview.view:drop(active).after {
  border-top-style: none;
}

treeview.view:drop(active).before {
  border-bottom-style: none;
}

treeview.view.expander {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  -gtk-icon-transform: rotate(-90deg);
  color: rgba(0, 0, 0, 0.6);
}

treeview.view.expander:dir(rtl) {
  -gtk-icon-transform: rotate(90deg);
}

treeview.view.expander:checked {
  -gtk-icon-transform: unset;
}

treeview.view.expander:hover, treeview.view.expander:active {
  color: rgba(0, 0, 0, 0.87);
}

treeview.view.expander:disabled {
  color: rgba(0, 0, 0, 0.26);
}

treeview.view.progressbar {
  border-bottom: 6px solid #1A73E8;
  box-shadow: none;
  background-color: transparent;
  background-image: none;
}

treeview.view.progressbar:selected:hover {
  box-shadow: none;
}

treeview.view.trough {
  border-bottom: 6px solid rgba(0, 0, 0, 0.15);
  box-shadow: none;
  background-color: transparent;
  background-image: none;
}

treeview.view.trough:selected:hover {
  box-shadow: none;
}

treeview.view header button {
  padding: 2px 6px;
  border-style: none solid solid none;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  border-radius: 0;
  background-clip: border-box;
}

treeview.view header button:not(:focus):not(:hover):not(:active) {
  color: rgba(0, 0, 0, 0.6);
}

treeview.view header button, treeview.view header button:disabled {
  background-color: #FFFFFF;
}

treeview.view header button:last-child {
  border-right-style: none;
}

treeview.view button.dnd,
treeview.view header.button.dnd {
  padding: 2px 6px;
  border-style: none solid solid;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  border-radius: 0;
  box-shadow: none;
  background-color: #FFFFFF;
  background-clip: border-box;
  color: #1A73E8;
}

treeview.view acceleditor > label {
  background-color: #1A73E8;
}

/*********
 * Menus *
 *********/
menubar,
.menubar {
  -GtkWidget-window-dragging: true;
  padding: 3px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.87);
}

menubar:backdrop,
.menubar:backdrop {
  background-color: #FAFAFA;
  color: rgba(0, 0, 0, 0.6);
}

menubar > menuitem,
.menubar > menuitem {
  transition: none;
  min-height: 20px;
  padding: 2px 8px;
  color: rgba(0, 0, 0, 0.6);
  border-radius: 5px;
}

menubar > menuitem:hover,
.menubar > menuitem:hover {
  transition: none;
  background-color: alpha(currentColor, 0.1);
  color: rgba(0, 0, 0, 0.87);
}

menubar > menuitem:disabled,
.menubar > menuitem:disabled {
  color: rgba(0, 0, 0, 0.26);
}

menubar > menuitem label:disabled,
.menubar > menuitem label:disabled {
  color: inherit;
}

.background.popup {
  background-color: transparent;
  background-image: none;
  border-radius: 12px;
}

menu {
  margin: 3px;
  padding: 6px;
  background-color: #FFFFFF;
  background-clip: border-box;
}

.background > menu {
  border-radius: 11px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
}

.background:not(.popup) > menu {
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-radius: 0;
  box-shadow: none;
}

.background.csd > menu {
  border: none;
  border-radius: 11px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
}

menu menuitem {
  transition: none;
  min-height: 20px;
  min-width: 40px;
  padding: 4px 9px;
  color: rgba(0, 0, 0, 0.87);
  font: initial;
  text-shadow: none;
  border-radius: 5px;
}

menu menuitem:hover {
  background-color: alpha(currentColor, 0.08);
  color: rgba(0, 0, 0, 0.87);
}

menu menuitem:disabled {
  color: rgba(0, 0, 0, 0.38);
}

menu menuitem arrow {
  min-height: 16px;
  min-width: 16px;
}

menu menuitem arrow:dir(ltr) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
  margin-left: 8px;
}

menu menuitem arrow:dir(rtl) {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic-rtl");
  margin-right: 8px;
}

menu menuitem label:dir(rtl), menu menuitem label:dir(ltr) {
  color: inherit;
}

menu .view:selected {
  background-color: rgba(235, 235, 235, 0.987);
}

menu > arrow {
  min-height: 16px;
  min-width: 16px;
  padding: 6px;
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.6);
  border-radius: 8px;
}

menu > arrow.top {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
  border-image: image(rgba(0, 0, 0, 0.12)) 0 0 1/0 0 1px;
}

menu > arrow.bottom {
  margin-top: 11px;
  margin-bottom: -12px;
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  border-image: image(rgba(0, 0, 0, 0.12)) 1 0 0/1px 0 0;
}

menu > arrow:hover {
  background-image: image(alpha(currentColor, 0.08));
  color: rgba(0, 0, 0, 0.87);
  border-image: none;
}

menu > arrow:disabled {
  border-color: transparent;
  background-color: transparent;
  color: transparent;
}

menu separator {
  margin: 3px 0;
}

menuitem accelerator {
  color: rgba(0, 0, 0, 0.6);
}

menuitem:disabled accelerator {
  color: rgba(0, 0, 0, 0.26);
}

/************
 * Popovers *
 ************/
popover.background {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  padding: 0;
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
}

popover.background:backdrop {
  box-shadow: 0 3px 2px -3px rgba(0, 0, 0, 0.3), 0 2px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 3px 0 rgba(0, 0, 0, 0.12);
}

popover.background, .csd popover.background {
  border-style: solid;
  border-width: 0;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0) rgba(0, 0, 0, 0);
  border-radius: 11px;
}

popover.background.combo {
  padding: 6px;
}

popover.background.combo > scrolledwindow > viewport.frame > list > row.activatable {
  border-radius: 5px;
  margin: 2px;
  padding: 6px;
}

popover.background > stack {
  margin: -2px;
}

popover.background > list,
popover.background > .view,
popover.background > toolbar {
  border-style: none;
  box-shadow: none;
  background-color: transparent;
}

popover.background > list > row:first-child {
  border-top-left-radius: 11px;
  border-top-right-radius: 11px;
}

popover.background > list > row:last-child {
  border-bottom-left-radius: 11px;
  border-bottom-right-radius: 11px;
}

popover.background button, popover.background entry, popover.background spinbutton {
  border-radius: 5px;
}

popover.background .linked > button,
popover.background button.model {
  border-radius: 0;
}

popover.background .linked > button:first-child,
popover.background button.model:first-child {
  border-radius: 5px 0 0 5px;
}

popover.background .linked > button:last-child,
popover.background button.model:last-child {
  border-radius: 0 5px 5px 0;
}

popover.background .linked > button:only-child,
popover.background button.model:only-child {
  border-radius: 5px;
}

popover.background button.model {
  min-height: 32px;
  min-width: 32px;
  padding: 0 12px;
  margin: 0;
}

popover.background separator {
  margin: 3px 0;
}

popover.background list separator {
  margin: 0;
}

/*************
 * Notebooks *
 *************/
tabbox > tab, notebook > header tab {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms;
  min-height: 24px;
  min-width: 24px;
  padding: 6px 12px;
  border-width: 1px;
  border-color: transparent;
  border-style: solid;
  outline: none;
  background-clip: padding-box;
  color: rgba(0, 0, 0, 0.6);
}

tabbox > tab:hover, notebook > header tab:hover {
  background-color: rgba(0, 0, 0, 0.04);
  color: rgba(0, 0, 0, 0.87);
}

tabbox > tab:disabled, notebook > header tab:disabled {
  color: rgba(0, 0, 0, 0.26);
}

tabbox > tab:checked, notebook > header tab:checked {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  background-color: #FFFFFF;
  background-clip: padding-box;
  border-color: #dedede;
  color: rgba(0, 0, 0, 0.87);
}

tabbox > tab:checked:disabled, notebook > header tab:checked:disabled {
  color: rgba(0, 0, 0, 0.38);
}

tabbox > tab:checked.reorderable-page, notebook > header tab:checked.reorderable-page {
  background-color: #FFFFFF;
}

notebook {
  background-color: #FFFFFF;
}

frame > paned > notebook > header, notebook.frame > header {
  background-color: #FAFAFA;
}

notebook.frame, notebook.frame > stack {
  border-radius: 6px;
}

notebook.frame > stack .inline-toolbar {
  border-radius: 0 0 6px 6px;
}

notebook.frame > stack > scrolledwindow.frame {
  border: none;
}

.background.csd notebook.frame, .background.csd notebook.frame > stack {
  border-radius: 12px;
}

.background.csd notebook.frame > stack scrolledwindow.frame {
  border-radius: 12px 12px 0 0;
}

.background.csd notebook.frame > stack .inline-toolbar {
  border-radius: 0 0 12px 12px;
}

notebook > stack {
  background-color: transparent;
}

notebook.frame frame > border {
  border: none;
  border-radius: 12px;
}

notebook.frame frame > list row.activatable {
  border-radius: 12px;
}

notebook:focus tab:checked {
  box-shadow: none;
}

notebook > header.top > tabs > tab {
  border-radius: 6px 6px 0 0;
}

notebook > header.bottom > tabs > tab {
  border-radius: 0 0 6px 6px;
}

notebook > header.left > tabs > tab {
  border-radius: 6px 0 0 6px;
}

notebook > header.right > tabs > tab {
  border-radius: 0 6px 6px 0;
}

notebook.frame > header.top {
  border-radius: 6px 6px 0 0;
}

notebook.frame > header.bottom {
  border-radius: 0 0 6px 6px;
}

notebook.frame > header.left {
  border-radius: 6px 0 0 6px;
}

notebook.frame > header.right {
  border-radius: 0 6px 6px 0;
}

.background.csd notebook.frame > header.top {
  border-radius: 12px 12px 0 0;
}

.background.csd notebook.frame > header.top > tabs > tab {
  border-radius: 12px 12px 0 0;
}

.background.csd notebook.frame > header.bottom {
  border-radius: 0 0 12px 12px;
}

.background.csd notebook.frame > header.bottom > tabs > tab {
  border-radius: 0 0 12px 12px;
}

.background.csd notebook.frame > header.left {
  border-radius: 12px 0 0 12px;
}

.background.csd notebook.frame > header.left > tabs > tab {
  border-radius: 12px 0 0 12px;
}

.background.csd notebook.frame > header.right {
  border-radius: 0 12px 12px 0;
}

.background.csd notebook.frame > header.right > tabs > tab {
  border-radius: 0 12px 12px 0;
}

notebook > header {
  border-width: 1px;
  border-color: #dedede;
  background-color: #F2F2F2;
  background-clip: border-box;
}

notebook > header.top {
  border-bottom-style: solid;
}

notebook > header.top > tabs {
  margin-bottom: -1px;
  margin-top: 4px;
}

notebook > header.top > tabs > tab {
  border-bottom: none;
}

notebook > header.bottom {
  border-top-style: solid;
}

notebook > header.bottom > tabs {
  margin-top: -1px;
  margin-bottom: 4px;
}

notebook > header.bottom > tabs > tab {
  border-top: none;
}

notebook > header.left {
  border-right-style: solid;
}

notebook > header.left > tabs {
  margin-left: 4px;
  margin-right: -1px;
}

notebook > header.left > tabs > tab {
  border-right: none;
}

notebook > header.right {
  border-left-style: solid;
}

notebook > header.right > tabs {
  margin-left: -1px;
  margin-right: 4px;
}

notebook > header.right > tabs > tab {
  border-left: none;
}

notebook > header.top > tabs > arrow {
  border-top-style: none;
}

notebook > header.bottom > tabs > arrow {
  border-bottom-style: none;
}

notebook > header.top > tabs > arrow, notebook > header.bottom > tabs > arrow {
  padding-left: 4px;
  padding-right: 4px;
}

notebook > header.top > tabs > arrow.down, notebook > header.bottom > tabs > arrow.down {
  margin-left: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

notebook > header.top > tabs > arrow.up, notebook > header.bottom > tabs > arrow.up {
  margin-right: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

notebook > header.left > tabs > arrow {
  border-left-style: none;
}

notebook > header.right > tabs > arrow {
  border-right-style: none;
}

notebook > header.left > tabs > arrow, notebook > header.right > tabs > arrow {
  padding-top: 4px;
  padding-bottom: 4px;
}

notebook > header.left > tabs > arrow.down, notebook > header.right > tabs > arrow.down {
  margin-top: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

notebook > header.left > tabs > arrow.up, notebook > header.right > tabs > arrow.up {
  margin-bottom: -8px;
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

notebook > header > tabs > arrow {
  min-height: 16px;
  min-width: 16px;
  border-radius: 0;
}

notebook > header tab > box {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  margin: -6px -12px;
  padding: 6px 12px;
}

notebook > header tab > box:drop(active) {
  background-color: rgba(0, 0, 0, 0.12);
  color: rgba(0, 0, 0, 0.87);
}

notebook > header tab button.flat:last-child {
  margin-left: 6px;
  margin-right: -6px;
}

notebook > header tab button.flat:first-child {
  margin-left: -6px;
  margin-right: 6px;
}

notebook > header.top tabs, notebook > header.bottom tabs {
  padding-left: 8px;
  padding-right: 8px;
}

notebook > header.top tabs:not(:only-child):first-child, notebook > header.bottom tabs:not(:only-child):first-child {
  margin-left: 0;
}

notebook > header.top tabs:not(:only-child):last-child, notebook > header.bottom tabs:not(:only-child):last-child {
  margin-right: 0;
}

notebook > header.top tabs tab.reorderable-page, notebook > header.bottom tabs tab.reorderable-page {
  border-style: solid;
}

notebook > header.left tabs, notebook > header.right tabs {
  padding-top: 8px;
  padding-bottom: 8px;
}

notebook > header.left tabs:not(:only-child):first-child, notebook > header.right tabs:not(:only-child):first-child {
  margin-top: 0;
}

notebook > header.left tabs:not(:only-child):last-child, notebook > header.right tabs:not(:only-child):last-child {
  margin-bottom: 0;
}

notebook > header.left tabs tab.reorderable-page, notebook > header.right tabs tab.reorderable-page {
  border-style: solid;
}

/**************
 * Scrollbars *
 **************/
scrollbar {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  background-color: #FFFFFF;
}

* {
  -GtkScrollbar-has-backward-stepper: false;
  -GtkScrollbar-has-forward-stepper: false;
}

scrollbar.top {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar.left {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar.right {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

scrollbar slider {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  min-width: 8px;
  min-height: 8px;
  border: 4px solid transparent;
  border-radius: 9999px;
  background-clip: padding-box;
  background-color: rgba(0, 0, 0, 0.26);
}

scrollbar slider:hover {
  background-color: rgba(0, 0, 0, 0.38);
}

scrollbar slider:active {
  background-color: rgba(0, 0, 0, 0.6);
}

scrollbar slider:disabled {
  background-color: rgba(0, 0, 0, 0.26);
}

scrollbar.fine-tune slider {
  min-width: 4px;
  min-height: 4px;
}

scrollbar.fine-tune.horizontal slider {
  margin: 2px 0;
}

scrollbar.fine-tune.vertical slider {
  margin: 0 2px;
}

scrollbar.overlay-indicator:not(.fine-tune) slider {
  transition-property: background-color, min-height, min-width;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) {
  border-color: transparent;
  background-color: transparent;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) slider {
  min-width: 4px;
  min-height: 4px;
  margin: 3px;
  border: 1px solid rgba(255, 255, 255, 0.3);
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) button {
  min-width: 4px;
  min-height: 4px;
  margin: 3px;
  border: 1px solid rgba(255, 255, 255, 0.3);
  border-radius: 9999px;
  background-color: rgba(0, 0, 0, 0.38);
  background-clip: padding-box;
  -gtk-icon-source: none;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering) button:disabled {
  background-color: rgba(0, 0, 0, 0.26);
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal slider {
  min-width: 24px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).horizontal button {
  min-width: 8px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical slider {
  min-height: 24px;
}

scrollbar.overlay-indicator:not(.dragging):not(.hovering).vertical button {
  min-height: 8px;
}

scrollbar.overlay-indicator.dragging, scrollbar.overlay-indicator.hovering {
  background-color: rgba(255, 255, 255, 0.9);
}

scrollbar.horizontal slider {
  min-width: 24px;
}

scrollbar.vertical slider {
  min-height: 24px;
}

scrollbar button {
  min-width: 16px;
  min-height: 16px;
  padding: 0;
  border-radius: 0;
}

scrollbar.vertical button.down {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

scrollbar.vertical button.up {
  -gtk-icon-source: -gtk-icontheme("pan-up-symbolic");
}

scrollbar.horizontal button.down {
  -gtk-icon-source: -gtk-icontheme("pan-end-symbolic");
}

scrollbar.horizontal button.up {
  -gtk-icon-source: -gtk-icontheme("pan-start-symbolic");
}

/**********
 * Switch *
 **********/
switch {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  margin: 6px 0;
  padding: 0 2px;
  border: 5px solid transparent;
  border-radius: 9999px;
  background-color: rgba(0, 0, 0, 0.26);
  background-clip: padding-box;
  font-size: 0;
}

switch:checked {
  background-color: rgba(26, 115, 232, 0.5);
}

switch:disabled {
  opacity: 0.5;
}

switch image {
  margin: -8px;
  -gtk-icon-transform: scale(0);
}

switch slider {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  min-width: 20px;
  min-height: 20px;
  margin: -3px -2px;
  border-radius: 9999px;
  outline: none;
  box-shadow: 0 0 0 10px transparent, 0 2px 2px -2px rgba(0, 0, 0, 0.3), 0 1px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 2px -1px rgba(0, 0, 0, 0.17);
  background-color: #FFFFFF;
}

switch:focus slider {
  box-shadow: 0 0 0 10px alpha(currentColor, 0.08), 0 2px 2px -2px rgba(0, 0, 0, 0.3), 0 1px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 2px -1px rgba(0, 0, 0, 0.17);
}

switch:hover slider {
  box-shadow: 0 0 0 10px alpha(currentColor, 0.08), 0 2px 2px -2px rgba(0, 0, 0, 0.3), 0 1px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 2px -1px rgba(0, 0, 0, 0.17);
}

switch:focus:hover slider {
  box-shadow: 0 0 0 10px alpha(currentColor, 0.16), 0 2px 2px -2px rgba(0, 0, 0, 0.3), 0 1px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 2px -1px rgba(0, 0, 0, 0.17);
}

switch:checked slider {
  background-color: #1A73E8;
  color: #1A73E8;
}

/*************************
 * Check and Radio items *
 *************************/
.view.content-view.check:not(list),
.content-view .tile check:not(list) {
  min-height: 40px;
  min-width: 40px;
  margin: 0;
  padding: 0;
  box-shadow: none;
  background-color: transparent;
  background-image: none;
  -gtk-icon-shadow: 0 1px 1px rgba(0, 0, 0, 0.2), 0 2px 2px rgba(0, 0, 0, 0.14), 0 1px 3px rgba(0, 0, 0, 0.12);
}

.view.content-view.check:not(list):hover, .view.content-view.check:not(list):active,
.content-view .tile check:not(list):hover,
.content-view .tile check:not(list):active {
  -gtk-icon-shadow: 0 2px 2px rgba(0, 0, 0, 0.2), 0 4px 4px rgba(0, 0, 0, 0.14), 0 1px 6px rgba(0, 0, 0, 0.12);
}

.view.content-view.check:not(list),
.content-view .tile check:not(list) {
  -gtk-icon-source: -gtk-scaled(url("assets/selectionmode-checkbox-unchecked.png"), url("assets/selectionmode-checkbox-unchecked@2.png"));
}

.view.content-view.check:not(list):checked,
.content-view .tile check:not(list):checked {
  -gtk-icon-source: -gtk-scaled(url("assets/selectionmode-checkbox-checked.png"), url("assets/selectionmode-checkbox-checked@2.png"));
}

checkbutton,
radiobutton {
  outline: none;
}

checkbutton.text-button,
radiobutton.text-button {
  padding: 2px;
}

checkbutton.text-button label:not(:only-child),
radiobutton.text-button label:not(:only-child) {
  margin: 0 4px;
}

check,
radio {
  min-height: 24px;
  min-width: 24px;
  margin: -8px;
  padding: 8px;
}

check:checked, check:indeterminate,
radio:checked,
radio:indeterminate {
  color: #0F9D58;
}

check:checked:disabled, check:indeterminate:disabled,
radio:checked:disabled,
radio:indeterminate:disabled {
  color: rgba(0, 0, 0, 0.26);
}

check:not(:hover):focus,
radio:not(:hover):focus {
  box-shadow: inset 0 0 0 9999px transparent;
}

popover modelbutton.flat check, popover modelbutton.flat check:focus, popover modelbutton.flat check:hover, popover modelbutton.flat check:focus:hover, popover modelbutton.flat check:active, popover modelbutton.flat check:disabled, popover modelbutton.flat radio, popover modelbutton.flat radio:focus, popover modelbutton.flat radio:hover, popover modelbutton.flat radio:focus:hover, popover modelbutton.flat radio:active, popover modelbutton.flat radio:disabled {
  transition: none;
  box-shadow: none;
  background-image: none;
}

popover modelbutton.flat check:not(:checked):not(:indeterminate):not(:disabled), popover modelbutton.flat radio:not(:checked):not(:indeterminate):not(:disabled) {
  color: rgba(0, 0, 0, 0.6);
}

popover modelbutton.flat check.left:dir(rtl), popover modelbutton.flat radio.left:dir(rtl) {
  margin-left: -12px;
  margin-right: -4px;
}

popover modelbutton.flat check.right:dir(ltr), popover modelbutton.flat radio.right:dir(ltr) {
  margin-left: -4px;
  margin-right: -12px;
}

menu menuitem check, menu menuitem radio {
  transition: none;
  margin: 0;
  padding: 0;
}

menu menuitem check:dir(ltr), menu menuitem radio:dir(ltr) {
  margin-right: 8px;
}

menu menuitem check:dir(rtl), menu menuitem radio:dir(rtl) {
  margin-left: 8px;
}

menu menuitem check:not(:checked):not(:indeterminate):not(:disabled), menu menuitem radio:not(:checked):not(:indeterminate):not(:disabled) {
  color: rgba(0, 0, 0, 0.6);
}

menu menuitem check, menu menuitem check:hover, menu menuitem check:disabled, menu menuitem radio, menu menuitem radio:hover, menu menuitem radio:disabled {
  box-shadow: none;
}


check {
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/unchecked-symbolic.svg"));
}


check:checked {
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/checkbox-checked-symbolic.svg"));
}


check:indeterminate {
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/mixed-symbolic.svg"));
}


radio {
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/unchecked-symbolic.svg"));
}


radio:checked {
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/radio-checked-symbolic.svg"));
}


radio:indeterminate {
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/mixed-symbolic.svg"));
}

#MozillaGtkWidget > widget > checkbutton > check,
menu menuitem check {
  min-height: 18px;
  min-width: 18px;
  border-radius: 12px;
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/small-unchecked-symbolic.svg"));
}

#MozillaGtkWidget > widget > checkbutton > check:checked,
menu menuitem check:checked {
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/small-checkbox-checked-symbolic.svg"));
}

#MozillaGtkWidget > widget > checkbutton > check:indeterminate,
menu menuitem check:indeterminate {
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/small-mixed-symbolic.svg"));
}

#MozillaGtkWidget > widget > radiobutton > radio,
menu menuitem radio {
  min-height: 18px;
  min-width: 18px;
  border-image: none;
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/small-unchecked-symbolic.svg"));
}

#MozillaGtkWidget > widget > radiobutton > radio:checked,
menu menuitem radio:checked {
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/small-radio-checked-symbolic.svg"));
}

#MozillaGtkWidget > widget > radiobutton > radio:indeterminate,
menu menuitem radio:indeterminate {
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/small-mixed-symbolic.svg"));
}

treeview.view check, treeview.view radio {
  padding: 0;
  margin: 0;
}

treeview.view check, treeview.view check:hover, treeview.view check:selected, treeview.view radio, treeview.view radio:hover, treeview.view radio:selected {
  box-shadow: none;
  background-color: transparent;
  background-image: none;
  color: rgba(0, 0, 0, 0.6);
}

treeview.view check:hover, treeview.view check:active, treeview.view check:hover:hover, treeview.view check:hover:active, treeview.view check:selected:hover, treeview.view check:selected:active, treeview.view radio:hover, treeview.view radio:active, treeview.view radio:hover:hover, treeview.view radio:hover:active, treeview.view radio:selected:hover, treeview.view radio:selected:active {
  color: rgba(0, 0, 0, 0.87);
}

treeview.view check:disabled, treeview.view check:hover:disabled, treeview.view check:selected:disabled, treeview.view radio:disabled, treeview.view radio:hover:disabled, treeview.view radio:selected:disabled {
  color: rgba(0, 0, 0, 0.26);
}

treeview.view check:checked, treeview.view check:indeterminate, treeview.view check:hover:checked, treeview.view check:hover:indeterminate, treeview.view check:selected:checked, treeview.view check:selected:indeterminate, treeview.view radio:checked, treeview.view radio:indeterminate, treeview.view radio:hover:checked, treeview.view radio:hover:indeterminate, treeview.view radio:selected:checked, treeview.view radio:selected:indeterminate {
  color: #0F9D58;
}

treeview.view check:checked:disabled, treeview.view check:indeterminate:disabled, treeview.view check:hover:checked:disabled, treeview.view check:hover:indeterminate:disabled, treeview.view check:selected:checked:disabled, treeview.view check:selected:indeterminate:disabled, treeview.view radio:checked:disabled, treeview.view radio:indeterminate:disabled, treeview.view radio:hover:checked:disabled, treeview.view radio:hover:indeterminate:disabled, treeview.view radio:selected:checked:disabled, treeview.view radio:selected:indeterminate:disabled {
  color: rgba(0, 0, 0, 0.26);
}

/************
 * GtkScale *
 ************/
scale {
  min-height: 2px;
  min-width: 2px;
}

scale.horizontal {
  padding: 17px 12px;
}

scale.vertical {
  padding: 12px 17px;
}

scale slider {
  min-height: 32px;
  min-width: 32px;
  margin: -15px;
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1), background-size 300ms cubic-bezier(0, 0, 0.2, 1), background-image 1200ms cubic-bezier(0, 0, 0.2, 1);
  background-repeat: no-repeat;
  background-position: center;
  background-size: auto, 1000% 1000%;
  border-radius: 50%;
  color: #1A73E8;
}

scale slider {
  background-image: -gtk-scaled(url("assets/scale-slider.png"), url("assets/scale-slider@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-slider-disabled.png"), url("assets/scale-slider-disabled@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale slider:focus {
  background-color: alpha(currentColor, 0.08);
}

scale slider:hover {
  background-color: alpha(currentColor, 0.08);
}

scale slider:focus:hover {
  background-color: alpha(currentColor, 0.16);
}

scale slider:active {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms;
  animation: ripple-on-slider 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  background-color: alpha(currentColor, 0.08);
  background-image: -gtk-scaled(url("assets/scale-slider.png"), url("assets/scale-slider@2.png")), radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
  background-size: auto, 0% 0%;
}

scale.fine-tune.horizontal {
  min-height: 4px;
  padding-top: 16px;
  padding-bottom: 16px;
}

scale.fine-tune.vertical {
  min-width: 4px;
  padding-left: 16px;
  padding-right: 16px;
}

scale.fine-tune slider {
  margin: -14px;
}

scale trough {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  outline: none;
  background-color: rgba(0, 0, 0, 0.26);
}

scale trough:disabled {
  background-color: rgba(0, 0, 0, 0.15);
}

scale highlight {
  transition: background-image 75ms cubic-bezier(0, 0, 0.2, 1);
  background-image: image(#1A73E8);
}

scale highlight:disabled {
  background-color: #F2F2F2;
  background-image: image(rgba(0, 0, 0, 0.26));
}

scale fill {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  background-color: rgba(0, 0, 0, 0.26);
}

scale fill:disabled {
  background-color: transparent;
}

scale marks,
scale value {
  color: rgba(0, 0, 0, 0.6);
}

scale indicator {
  background-color: rgba(0, 0, 0, 0.26);
  color: transparent;
}

scale.horizontal marks.top {
  margin-bottom: 7px;
  margin-top: -15px;
}

scale.horizontal.fine-tune marks.top {
  margin-bottom: 6px;
  margin-top: -14px;
}

scale.horizontal marks.bottom {
  margin-top: 7px;
  margin-bottom: -15px;
}

scale.horizontal.fine-tune marks.bottom {
  margin-top: 6px;
  margin-bottom: -14px;
}

scale.vertical marks.top {
  margin-right: 7px;
  margin-left: -15px;
}

scale.vertical.fine-tune marks.top {
  margin-right: 6px;
  margin-left: -14px;
}

scale.vertical marks.bottom {
  margin-left: 7px;
  margin-right: -15px;
}

scale.vertical.fine-tune marks.bottom {
  margin-left: 6px;
  margin-right: -14px;
}

scale.horizontal indicator {
  min-height: 8px;
  min-width: 1px;
}

scale.vertical indicator {
  min-height: 1px;
  min-width: 8px;
}

scale.horizontal.marks-before:not(.marks-after) slider {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-before-slider.png"), url("assets/scale-horz-marks-before-slider@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.horizontal.marks-before:not(.marks-after) slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-before-slider-disabled.png"), url("assets/scale-horz-marks-before-slider-disabled@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.horizontal.marks-before:not(.marks-after) slider:active {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-before-slider.png"), url("assets/scale-horz-marks-before-slider@2.png")), radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
}

scale.horizontal.marks-after:not(.marks-before) slider {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-after-slider.png"), url("assets/scale-horz-marks-after-slider@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.horizontal.marks-after:not(.marks-before) slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-after-slider-disabled.png"), url("assets/scale-horz-marks-after-slider-disabled@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.horizontal.marks-after:not(.marks-before) slider:active {
  background-image: -gtk-scaled(url("assets/scale-horz-marks-after-slider.png"), url("assets/scale-horz-marks-after-slider@2.png")), radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
}

scale.vertical.marks-before:not(.marks-after) slider {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-before-slider.png"), url("assets/scale-vert-marks-before-slider@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.vertical.marks-before:not(.marks-after) slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-before-slider-disabled.png"), url("assets/scale-vert-marks-before-slider-disabled@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.vertical.marks-before:not(.marks-after) slider:active {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-before-slider.png"), url("assets/scale-vert-marks-before-slider@2.png")), radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
}

scale.vertical.marks-after:not(.marks-before) slider {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-after-slider.png"), url("assets/scale-vert-marks-after-slider@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.vertical.marks-after:not(.marks-before) slider:disabled {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-after-slider-disabled.png"), url("assets/scale-vert-marks-after-slider-disabled@2.png")), radial-gradient(circle, transparent 10%, transparent 0%);
}

scale.vertical.marks-after:not(.marks-before) slider:active {
  background-image: -gtk-scaled(url("assets/scale-vert-marks-after-slider.png"), url("assets/scale-vert-marks-after-slider@2.png")), radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
}

scale.color {
  min-height: 0;
  min-width: 0;
}

scale.color.horizontal {
  padding: 0 0 12px 0;
}

scale.color.horizontal slider:dir(ltr), scale.color.horizontal slider:dir(rtl) {
  margin-bottom: -24px;
  margin-top: 8px;
}

scale.color.vertical:dir(ltr) {
  padding: 0 0 0 12px;
}

scale.color.vertical:dir(ltr) slider {
  margin-left: -24px;
  margin-right: 8px;
}

scale.color.vertical:dir(rtl) {
  padding: 0 12px 0 0;
}

scale.color.vertical:dir(rtl) slider {
  margin-right: -24px;
  margin-left: 8px;
}

/*****************
 * Progress bars *
 *****************/
progressbar {
  color: rgba(0, 0, 0, 0.6);
  font-size: smaller;
}

progressbar.horizontal trough,
progressbar.horizontal progress {
  min-height: 6px;
}

progressbar.vertical trough,
progressbar.vertical progress {
  min-width: 6px;
}

progressbar trough {
  border-radius: 12px;
  background-color: rgba(0, 0, 0, 0.15);
}

progressbar progress {
  border-radius: 12px;
  background-color: #1A73E8;
}

progressbar.osd {
  min-width: 6px;
  min-height: 6px;
  background-color: transparent;
}

progressbar.osd trough {
  background-color: transparent;
}

progressbar.osd progress {
  background-color: #1A73E8;
}

progressbar trough.empty progress {
  all: unset;
}

/*************
 * Level Bar *
 *************/
levelbar.horizontal block {
  min-height: 6px;
}

levelbar.horizontal.discrete block {
  min-width: 36px;
}

levelbar.horizontal.discrete block:not(:last-child) {
  margin-right: 2px;
}

levelbar.vertical block {
  min-width: 6px;
}

levelbar.vertical.discrete block {
  min-height: 36px;
}

levelbar.vertical.discrete block:not(:last-child) {
  margin-bottom: 2px;
}

levelbar trough {
  border-radius: 12px;
}

levelbar block.low {
  background-color: #FFD600;
}

levelbar block.high, levelbar block:not(.empty) {
  background-color: #1A73E8;
}

levelbar block.full {
  background-color: #0F9D58;
}

levelbar block.empty {
  background-color: rgba(0, 0, 0, 0.15);
}

/****************
 * Print dialog *
*****************/
printdialog paper {
  padding: 0;
  border: 1px solid rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.87);
}

printdialog .dialog-action-box {
  margin: 12px;
}

/**********
 * Frames *
 **********/
frame > border, .frame {
  margin: 0;
  padding: 0;
  border: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 0;
  box-shadow: none;
}

.frame.view {
  border-radius: 12px;
}

.frame.flat {
  border-style: none;
}

frame.flat > border,
frame > border.flat, statusbar frame > border {
  border: none;
}

actionbar > revealer > box {
  padding: 6px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
  background-clip: border-box;
}

.background.csd box.vertical > actionbar > revealer > box {
  border-radius: 0 0 18px 18px;
}

.background.csd frame box.vertical > actionbar > revealer > box {
  border-radius: 0;
}

scrolledwindow viewport.frame {
  border: none;
}

stack scrolledwindow.frame viewport.frame list {
  border: none;
}

overshoot.top {
  background-image: -gtk-gradient(radial, center top, 0, center top, 0.75, to(rgba(0, 0, 0, 0.04)), to(transparent));
  background-repeat: no-repeat;
  background-position: center top;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

overshoot.bottom {
  background-image: -gtk-gradient(radial, center bottom, 0, center bottom, 0.75, to(rgba(0, 0, 0, 0.04)), to(transparent));
  background-repeat: no-repeat;
  background-position: center bottom;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

overshoot.left {
  background-image: -gtk-gradient(radial, left center, 0, left center, 0.75, to(rgba(0, 0, 0, 0.04)), to(transparent));
  background-repeat: no-repeat;
  background-position: left center;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

overshoot.right {
  background-image: -gtk-gradient(radial, right center, 0, right center, 0.75, to(rgba(0, 0, 0, 0.04)), to(transparent));
  background-repeat: no-repeat;
  background-position: right center;
  background-color: transparent;
  border: none;
  box-shadow: none;
}

junction {
  border-style: solid none none solid;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
}

junction:dir(rtl) {
  border-style: solid solid none none;
}

separator {
  min-width: 1px;
  min-height: 1px;
  background-color: rgba(0, 0, 0, 0.12);
}

preferences stacksidebar.sidebar list separator, .tweak-categories separator, stacksidebar.sidebar + separator.vertical,
stacksidebar.sidebar separator.horizontal, button.font separator, button.file separator {
  min-width: 0;
  min-height: 0;
  background-color: transparent;
}

/*********
 * Lists *
 *********/
window.background.csd stack stack stack frame > list,
window.background.csd > stack > stack > box > frame > list,
window.background.csd > stack > stack > box > box > frame > list,
window.background.csd > stack > box > stack > box > frame > list,
window.background.csd > stack > box > stack > scrolledwindow > viewport frame > list,
window.background.csd > stack > box > stack > box > scrolledwindow > viewport > frame > list,
window.background.csd > stack > grid > scrolledwindow > viewport > box > frame > list, window.background.csd > stack > list,
window.background.csd > stack > scrolledwindow > viewport > box > list,
window.background.csd > box > stack > scrolledwindow > viewport > box > list, preferencesgroup list, .geary-accounts-editor-pane list, window.background.csd.unified > deck > deck > deck list, hdyleaflet list.view, hdyleaflet list.frame, leaflet list.view, leaflet list.frame, box.horizontal > stack.background list.view, box.horizontal > stack.background list.frame, hdyleaflet stack.background scrolledwindow > viewport list, hdyleaflet overlay scrolledwindow > viewport list, leaflet stack.background scrolledwindow > viewport list, leaflet overlay scrolledwindow > viewport list, box.horizontal > stack.background stack.background scrolledwindow > viewport list, box.horizontal > stack.background overlay scrolledwindow > viewport list, hdyleaflet frame:not(.view) list:not(.contacts-contact-list), leaflet frame:not(.view) list:not(.contacts-contact-list), box.horizontal > stack.background frame:not(.view) list:not(.contacts-contact-list), list.tweak-group list, .tweak-group-startup, list.content:not(.conversation-listbox) {
  border-radius: 13px;
  box-shadow: none;
  border: 1px solid rgba(0, 0, 0, 0.12);
}

window.background.csd stack stack stack frame > list row.activatable:first-child, window.background.csd > stack > list row.activatable:first-child, preferencesgroup list row.activatable:first-child, .geary-accounts-editor-pane list row.activatable:first-child, dialog.background scrolledwindow.frame > viewport > list > row.activatable:first-child, window.background.csd.unified > deck > deck > deck list row.activatable:first-child, hdyleaflet list.view row.activatable:first-child, hdyleaflet list.frame row.activatable:first-child, leaflet list.view row.activatable:first-child, leaflet list.frame row.activatable:first-child, box.horizontal > stack.background list.view row.activatable:first-child, box.horizontal > stack.background list.frame row.activatable:first-child, hdyleaflet stack.background scrolledwindow > viewport list row.activatable:first-child, hdyleaflet overlay scrolledwindow > viewport list row.activatable:first-child, leaflet stack.background scrolledwindow > viewport list row.activatable:first-child, leaflet overlay scrolledwindow > viewport list row.activatable:first-child, box.horizontal > stack.background stack.background scrolledwindow > viewport list row.activatable:first-child, box.horizontal > stack.background overlay scrolledwindow > viewport list row.activatable:first-child, hdyleaflet frame:not(.view) list:not(.contacts-contact-list) row.activatable:first-child, leaflet frame:not(.view) list:not(.contacts-contact-list) row.activatable:first-child, box.horizontal > stack.background frame:not(.view) list:not(.contacts-contact-list) row.activatable:first-child, list.tweak-group list row.activatable:first-child, .tweak-group-startup row.activatable:first-child, list.content:not(.conversation-listbox) > row:first-child {
  border-top-left-radius: 12px;
  border-top-right-radius: 12px;
}

window.background.csd stack stack stack frame > list row.activatable:last-child, window.background.csd > stack > list row.activatable:last-child, preferencesgroup list row.activatable:last-child, .geary-accounts-editor-pane list row.activatable:last-child, dialog.background scrolledwindow.frame > viewport > list > row.activatable:last-child, window.background.csd.unified > deck > deck > deck list row.activatable:last-child, hdyleaflet list.view row.activatable:last-child, hdyleaflet list.frame row.activatable:last-child, leaflet list.view row.activatable:last-child, leaflet list.frame row.activatable:last-child, box.horizontal > stack.background list.view row.activatable:last-child, box.horizontal > stack.background list.frame row.activatable:last-child, hdyleaflet stack.background scrolledwindow > viewport list row.activatable:last-child, hdyleaflet overlay scrolledwindow > viewport list row.activatable:last-child, leaflet stack.background scrolledwindow > viewport list row.activatable:last-child, leaflet overlay scrolledwindow > viewport list row.activatable:last-child, box.horizontal > stack.background stack.background scrolledwindow > viewport list row.activatable:last-child, box.horizontal > stack.background overlay scrolledwindow > viewport list row.activatable:last-child, hdyleaflet frame:not(.view) list:not(.contacts-contact-list) row.activatable:last-child, leaflet frame:not(.view) list:not(.contacts-contact-list) row.activatable:last-child, box.horizontal > stack.background frame:not(.view) list:not(.contacts-contact-list) row.activatable:last-child, list.tweak-group list row.activatable:last-child, .tweak-group-startup row.activatable:last-child, list.content:not(.conversation-listbox) > row:last-child {
  border-bottom-left-radius: 12px;
  border-bottom-right-radius: 12px;
}

window.background.csd stack stack stack frame > list row.activatable:only-child, window.background.csd > stack > list row.activatable:only-child, preferencesgroup list row.activatable:only-child, .geary-accounts-editor-pane list row.activatable:only-child, dialog.background scrolledwindow.frame > viewport > list > row.activatable:only-child, window.background.csd.unified > deck > deck > deck list row.activatable:only-child, hdyleaflet list.view row.activatable:only-child, hdyleaflet list.frame row.activatable:only-child, leaflet list.view row.activatable:only-child, leaflet list.frame row.activatable:only-child, box.horizontal > stack.background list.view row.activatable:only-child, box.horizontal > stack.background list.frame row.activatable:only-child, hdyleaflet stack.background scrolledwindow > viewport list row.activatable:only-child, hdyleaflet overlay scrolledwindow > viewport list row.activatable:only-child, leaflet stack.background scrolledwindow > viewport list row.activatable:only-child, leaflet overlay scrolledwindow > viewport list row.activatable:only-child, box.horizontal > stack.background stack.background scrolledwindow > viewport list row.activatable:only-child, box.horizontal > stack.background overlay scrolledwindow > viewport list row.activatable:only-child, hdyleaflet frame:not(.view) list:not(.contacts-contact-list) row.activatable:only-child, leaflet frame:not(.view) list:not(.contacts-contact-list) row.activatable:only-child, box.horizontal > stack.background frame:not(.view) list:not(.contacts-contact-list) row.activatable:only-child, list.tweak-group list row.activatable:only-child, .tweak-group-startup row.activatable:only-child, list.content:not(.conversation-listbox) > row:only-child {
  border-radius: 12px;
}

window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > list > row.activatable,
window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > scrolledwindow > viewport.frame > list > row.activatable,
window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > box.vertical > stack > scrolledwindow > viewport.frame > list > row.activatable, hdyleaflet > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable, leaflet > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable, box.horizontal > stack.background > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable {
  margin-right: 4px;
  border-radius: 0 9999px 9999px 0;
}

window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > list > row.activatable:selected,
window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > scrolledwindow > viewport.frame > list > row.activatable:selected,
window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > box.vertical > stack > scrolledwindow > viewport.frame > list > row.activatable:selected, hdyleaflet > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable:selected, leaflet > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable:selected, box.horizontal > stack.background > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable:selected {
  background-color: alpha(currentColor, 0.1);
  color: #1A73E8;
}

window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > list > row.activatable:selected image,
window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > scrolledwindow > viewport.frame > list > row.activatable:selected image,
window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > box.vertical > stack > scrolledwindow > viewport.frame > list > row.activatable:selected image, hdyleaflet > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable:selected image, leaflet > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable:selected image, box.horizontal > stack.background > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable:selected image, window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > list > row.activatable:selected label,
window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > scrolledwindow > viewport.frame > list > row.activatable:selected label,
window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > box.vertical > stack > scrolledwindow > viewport.frame > list > row.activatable:selected label, hdyleaflet > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable:selected label, leaflet > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable:selected label, box.horizontal > stack.background > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) row.activatable:selected label {
  color: #1A73E8;
}

list {
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
}

list row {
  padding: 2px;
}

.budgie-popover.budgie-menu row.activatable > button.flat, .budgie-popover scrolledwindow.sidebar + separator + scrolledwindow list > row.activatable, .budgie-popover scrolledwindow.sidebar:not(.categories) list > row.activatable, treeview.view header button, row.activatable {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 300ms cubic-bezier(0, 0, 0.2, 1), background-image 1200ms cubic-bezier(0, 0, 0.2, 1);
  outline: none;
  box-shadow: inset 0 0 0 9999px transparent;
  background-image: radial-gradient(circle, transparent 10%, transparent 0%);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 1000% 1000%;
}

.budgie-popover.budgie-menu row.activatable > button.flat:focus, .budgie-popover scrolledwindow.sidebar + separator + scrolledwindow list > row.activatable:focus, .budgie-popover scrolledwindow.sidebar:not(.categories) list > row.activatable:focus, treeview.view header button:focus, row.activatable:focus {
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
}

.budgie-popover.budgie-menu row.activatable > button.flat:hover, .budgie-popover scrolledwindow.sidebar + separator + scrolledwindow list > row.activatable:hover, .budgie-popover scrolledwindow.sidebar:not(.categories) list > row.activatable:hover, treeview.view header button:hover, row.activatable:hover {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), box-shadow 0ms, background-size 300ms cubic-bezier(0, 0, 0.2, 1), background-image 1200ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
}

.budgie-popover.budgie-menu row.activatable > button.has-open-popup.flat, .budgie-popover scrolledwindow.sidebar + separator + scrolledwindow list > row.has-open-popup.activatable, .budgie-popover scrolledwindow.sidebar:not(.categories) list > row.has-open-popup.activatable, treeview.view header button.has-open-popup, .budgie-popover.budgie-menu row.activatable > button.flat:active, .budgie-popover scrolledwindow.sidebar + separator + scrolledwindow list > row.activatable:active, .budgie-popover scrolledwindow.sidebar:not(.categories) list > row.activatable:active, treeview.view header button:active, row.activatable.has-open-popup, row.activatable:active {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms;
  animation: ripple 225ms cubic-bezier(0, 0, 0.2, 1) forwards;
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
  background-image: radial-gradient(circle, alpha(currentColor, 0.12) 10%, transparent 0%);
  background-size: 0% 0%;
}

row:selected {
  color: inherit;
}

row:selected image,
row:selected label {
  color: rgba(0, 0, 0, 0.87);
}

row:selected button image,
row:selected button label {
  color: inherit;
}

row:selected:disabled image,
row:selected:disabled label {
  color: rgba(0, 0, 0, 0.38);
}

/*********************
 * App Notifications *
 *********************/
.app-notification {
  margin: 8px;
}

.app-notification button.text-button:not(:disabled) {
  color: #1A73E8;
}

.app-notification > box > label {
  padding-left: 9px;
}

.app-notification.frame,
.app-notification border {
  border-style: none;
}

/*************
 * Expanders *
 *************/
expander title > arrow {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  min-width: 16px;
  min-height: 16px;
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  -gtk-icon-transform: rotate(-90deg);
  color: rgba(0, 0, 0, 0.6);
}

expander title > arrow:dir(rtl) {
  -gtk-icon-transform: rotate(90deg);
}

expander title > arrow:checked {
  -gtk-icon-transform: unset;
}

expander title > arrow:hover, expander title > arrow:active {
  color: rgba(0, 0, 0, 0.87);
}

expander title > arrow:disabled {
  color: rgba(0, 0, 0, 0.26);
}

/************
 * Calendar *
 ************/
calendar {
  padding: 3px 6px;
  border: 1px solid rgba(0, 0, 0, 0.12);
  color: rgba(0, 0, 0, 0.87);
}

calendar:disabled {
  color: rgba(0, 0, 0, 0.38);
}

calendar:selected {
  border-radius: 5px;
}

calendar.header {
  border-style: none none solid;
  border-color: rgba(0, 0, 0, 0.12);
  border-radius: 0;
}

calendar.button:focus {
  outline: none;
  box-shadow: none;
}

calendar.highlight {
  color: rgba(0, 0, 0, 0.6);
  font-weight: 500;
}

calendar:indeterminate {
  color: rgba(0, 0, 0, 0.26);
}

/***********
 * Dialogs *
 ***********/
messagedialog.background {
  background-color: #FFFFFF;
}

messagedialog .titlebar {
  min-height: 24px;
  border-style: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.87);
}

messagedialog .titlebar:backdrop {
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.6);
}

messagedialog.csd.background {
  border-bottom-left-radius: 18px;
  border-bottom-right-radius: 18px;
}

messagedialog.csd .dialog-action-box {
  margin-top: -6px;
}

messagedialog.csd .dialog-action-box button, messagedialog.csd .dialog-action-box button:first-child, messagedialog.csd .dialog-action-box button:last-child {
  border-radius: 9999px;
}

messagedialog.csd .dialog-action-box button:not(:last-child) {
  margin-right: 6px;
}

messagedialog.csd .dialog-action-box button:not(:disabled) {
  color: #1A73E8;
}

messagedialog.csd .dialog-action-box button.destructive-action:not(:disabled) {
  color: #E53935;
}

.csd filechooser {
  background-color: #FFFFFF;
  border-radius: 0 0 18px 18px;
}

filechooser .dialog-action-box {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

filechooser #pathbarbox {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  background-color: #F2F2F2;
}

filechooser stack.view {
  background-color: transparent;
}

filechooser stack.view scrolledwindow {
  background-color: transparent;
  border-radius: 0 0 18px 0;
}

filechooser stack.view scrolledwindow list {
  background-color: transparent;
}

filechooser stack.view scrolledwindow treeview.view:not(:hover):not(:active):not(:selected) {
  background-color: transparent;
}

filechooser stack.view > placesview {
  background-color: transparent;
}

filechooser stack.view > placesview > actionbar, filechooser stack.view > placesview > actionbar > revealer > box {
  background-color: transparent;
}

filechooser stack.view frame > border {
  border: none;
}

.csd filechooser placessidebar {
  background: none;
  border-bottom-left-radius: 18px;
}

filechooser actionbar, filechooser actionbar > revealer > box {
  background-color: transparent;
}

/***********
 * Sidebar *
 ***********/
.sidebar {
  border-style: none;
  background-color: #FAFAFA;
}

stacksidebar.sidebar:dir(ltr) list, stacksidebar.sidebar.left list, stacksidebar.sidebar.left:dir(rtl) list, .sidebar:not(separator):dir(ltr), .sidebar:not(separator).left {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
  border-left-style: none;
}

stacksidebar.sidebar:dir(rtl) list, stacksidebar.sidebar.right list, .sidebar:not(separator):dir(rtl), .sidebar:not(separator).right {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
  border-right-style: none;
}

.sidebar list {
  background-color: transparent;
}

paned .sidebar.left, paned .sidebar.right, paned .sidebar.left:dir(rtl), paned .sidebar:dir(rtl), paned .sidebar:dir(ltr), paned .sidebar {
  border-style: none;
}

stacksidebar.sidebar list {
  padding: 4px;
  background-color: #FAFAFA;
}

stacksidebar.sidebar row {
  min-height: 32px;
  padding: 0 2px;
  border-radius: 6px;
}

stacksidebar.sidebar row:selected {
  background-color: alpha(currentColor, 0.1);
  color: #1A73E8;
  font-weight: 500;
}

stacksidebar.sidebar row + row {
  margin-top: 4px;
}

stacksidebar.sidebar row > label {
  padding-left: 6px;
  padding-right: 6px;
  color: inherit;
}

separator.sidebar {
  background-color: rgba(0, 0, 0, 0.12);
}

/****************
 * File chooser *
 ****************/
row image.sidebar-icon {
  transition: color 75ms cubic-bezier(0, 0, 0.2, 1);
  color: rgba(0, 0, 0, 0.6);
}

row image.sidebar-icon:disabled {
  color: rgba(0, 0, 0, 0.26);
}

placessidebar.sidebar > viewport.frame {
  border-style: none;
}

placessidebar.sidebar list {
  padding: 1px 0 4px;
}

placessidebar.sidebar row {
  min-height: 32px;
  margin: -1px 4px -1px 0;
  padding: 0;
  border-radius: 0 9999px 9999px 0;
}

placessidebar.sidebar row > revealer {
  padding: 0 8px 0 16px;
}

placessidebar.sidebar row:selected {
  background-color: alpha(currentColor, 0.1);
  color: #1A73E8;
  font-weight: 500;
}

placessidebar.sidebar row:selected image.sidebar-icon {
  color: #1A73E8;
}

placessidebar.sidebar row:disabled {
  color: rgba(0, 0, 0, 0.38);
}

placessidebar.sidebar row image.sidebar-icon:dir(ltr) {
  padding-right: 8px;
}

placessidebar.sidebar row image.sidebar-icon:dir(rtl) {
  padding-left: 8px;
}

placessidebar.sidebar row label.sidebar-label {
  color: inherit;
}

placessidebar.sidebar row label.sidebar-label:dir(ltr) {
  padding-right: 2px;
}

placessidebar.sidebar row label.sidebar-label:dir(rtl) {
  padding-left: 2px;
}

placessidebar.sidebar row.sidebar-placeholder-row {
  background-color: alpha(currentColor, 0.08);
}

placessidebar.sidebar row.sidebar-new-bookmark-row {
  color: #1A73E8;
}

placessidebar.sidebar row.sidebar-new-bookmark-row image.sidebar-icon {
  color: #1A73E8;
}

placessidebar.sidebar row:drop(active) {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), box-shadow 0ms, background-size 300ms cubic-bezier(0, 0, 0.2, 1), background-image 1200ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
}

placesview .server-list-button > image {
  -gtk-icon-transform: rotate(0turn);
}

placesview .server-list-button:checked > image {
  -gtk-icon-transform: rotate(-0.5turn);
}

placesview > actionbar > revealer > box > label {
  padding-left: 8px;
  padding-right: 8px;
}

/*********
 * Paned *
 *********/
paned > separator {
  min-width: 1px;
  min-height: 1px;
  -gtk-icon-source: none;
  border-style: none;
  background-color: transparent;
  background-image: image(rgba(0, 0, 0, 0.12));
  background-size: 1px 1px;
  background-clip: content-box;
}

paned > separator.wide {
  min-width: 6px;
  min-height: 6px;
  background-color: #F2F2F2;
  background-image: image(rgba(0, 0, 0, 0.12)), image(rgba(0, 0, 0, 0.12));
  background-size: 1px 1px, 1px 1px;
}

paned.horizontal > separator {
  background-repeat: repeat-y;
}

paned.horizontal > separator:dir(ltr) {
  margin: 0 -8px 0 0;
  padding: 0 8px 0 0;
  background-position: left;
}

paned.horizontal > separator:dir(rtl) {
  margin: 0 0 0 -8px;
  padding: 0 0 0 8px;
  background-position: right;
}

paned.horizontal > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-y, repeat-y;
  background-position: left, right;
}

paned.vertical > separator {
  margin: 0 0 -8px 0;
  padding: 0 0 8px 0;
  background-repeat: repeat-x;
  background-position: top;
}

paned.vertical > separator.wide {
  margin: 0;
  padding: 0;
  background-repeat: repeat-x, repeat-x;
  background-position: bottom, top;
}

/**************
 * GtkInfoBar *
 **************/
infobar {
  border: none;
  margin-bottom: 0;
}

infobar.info > revealer > box, infobar.info:hover > revealer > box, infobar.info:backdrop > revealer > box {
  background-color: #FFFFFF;
}

infobar.info > revealer > box button, infobar.info > revealer > box button.text-button:not(:disabled), infobar.info:hover > revealer > box button, infobar.info:hover > revealer > box button.text-button:not(:disabled), infobar.info:backdrop > revealer > box button, infobar.info:backdrop > revealer > box button.text-button:not(:disabled) {
  color: #1A73E8;
}

infobar.action > revealer > box, infobar.action:backdrop > revealer > box, infobar.question > revealer > box, infobar.question:backdrop > revealer > box {
  background-color: #1A73E8;
  color: white;
}

infobar.action > revealer > box button, infobar.action > revealer > box button:hover, infobar.action > revealer > box button:focus, infobar.action > revealer > box button:active, infobar.action > revealer > box button:checked, infobar.action > revealer > box button.text-button:not(:disabled), infobar.action:backdrop > revealer > box button, infobar.action:backdrop > revealer > box button:hover, infobar.action:backdrop > revealer > box button:focus, infobar.action:backdrop > revealer > box button:active, infobar.action:backdrop > revealer > box button:checked, infobar.action:backdrop > revealer > box button.text-button:not(:disabled), infobar.question > revealer > box button, infobar.question > revealer > box button:hover, infobar.question > revealer > box button:focus, infobar.question > revealer > box button:active, infobar.question > revealer > box button:checked, infobar.question > revealer > box button.text-button:not(:disabled), infobar.question:backdrop > revealer > box button, infobar.question:backdrop > revealer > box button:hover, infobar.question:backdrop > revealer > box button:focus, infobar.question:backdrop > revealer > box button:active, infobar.question:backdrop > revealer > box button:checked, infobar.question:backdrop > revealer > box button.text-button:not(:disabled) {
  color: white;
}

infobar.action > revealer > box *:link, infobar.action:backdrop > revealer > box *:link, infobar.question > revealer > box *:link, infobar.question:backdrop > revealer > box *:link {
  color: white;
}

infobar.action:hover > revealer > box, infobar.question:hover > revealer > box {
  background-color: #3181ea;
}

infobar.warning > revealer > box, infobar.warning:backdrop > revealer > box {
  background-color: #FFD600;
  color: rgba(0, 0, 0, 0.87);
}

infobar.warning > revealer > box button, infobar.warning > revealer > box button:hover, infobar.warning > revealer > box button:focus, infobar.warning > revealer > box button:active, infobar.warning > revealer > box button:checked, infobar.warning > revealer > box button.text-button:not(:disabled), infobar.warning:backdrop > revealer > box button, infobar.warning:backdrop > revealer > box button:hover, infobar.warning:backdrop > revealer > box button:focus, infobar.warning:backdrop > revealer > box button:active, infobar.warning:backdrop > revealer > box button:checked, infobar.warning:backdrop > revealer > box button.text-button:not(:disabled) {
  color: rgba(0, 0, 0, 0.87);
}

infobar.warning > revealer > box *:link, infobar.warning:backdrop > revealer > box *:link {
  color: rgba(0, 0, 0, 0.87);
}

infobar.warning:hover > revealer > box {
  background-color: #ffda1a;
}

infobar.error > revealer > box, infobar.error:backdrop > revealer > box {
  background-color: #E53935;
  color: white;
}

infobar.error > revealer > box button, infobar.error > revealer > box button:hover, infobar.error > revealer > box button:focus, infobar.error > revealer > box button:active, infobar.error > revealer > box button:checked, infobar.error > revealer > box button.text-button:not(:disabled), infobar.error:backdrop > revealer > box button, infobar.error:backdrop > revealer > box button:hover, infobar.error:backdrop > revealer > box button:focus, infobar.error:backdrop > revealer > box button:active, infobar.error:backdrop > revealer > box button:checked, infobar.error:backdrop > revealer > box button.text-button:not(:disabled) {
  color: white;
}

infobar.error > revealer > box *:link, infobar.error:backdrop > revealer > box *:link {
  color: white;
}

infobar.error:hover > revealer > box {
  background-color: #e84f4c;
}

/************
 * Tooltips *
 ************/
tooltip {
  border-radius: 6px;
  box-shadow: none;
}

tooltip.background, tooltip.background.csd {
  border-radius: 12px;
  background-color: rgba(52, 52, 52, 0.9);
  color: white;
}

tooltip decoration {
  background-color: transparent;
}

tooltip > box {
  margin: -6px;
  min-height: 24px;
  padding: 4px 8px;
}

/*****************
 * Color Chooser *
 *****************/
colorswatch.top {
  border-top-left-radius: 11px;
  border-top-right-radius: 11px;
}

colorswatch.top overlay {
  border-top-left-radius: 11px;
  border-top-right-radius: 11px;
}

colorswatch.bottom {
  border-bottom-left-radius: 11px;
  border-bottom-right-radius: 11px;
}

colorswatch.bottom overlay {
  border-bottom-left-radius: 11px;
  border-bottom-right-radius: 11px;
}

colorswatch.left, colorswatch:first-child:not(.top) {
  border-top-left-radius: 11px;
  border-bottom-left-radius: 11px;
}

colorswatch.left overlay, colorswatch:first-child:not(.top) overlay {
  border-top-left-radius: 11px;
  border-bottom-left-radius: 11px;
}

colorswatch.right, colorswatch:last-child:not(.bottom) {
  border-top-right-radius: 11px;
  border-bottom-right-radius: 11px;
}

colorswatch.right overlay, colorswatch:last-child:not(.bottom) overlay {
  border-top-right-radius: 11px;
  border-bottom-right-radius: 11px;
}

colorswatch.dark {
  color: white;
}

colorswatch.light {
  color: rgba(0, 0, 0, 0.87);
}

colorswatch#add-color-button {
  border-radius: 11px 11px 0 0;
  color: rgba(0, 0, 0, 0.87);
}

colorswatch#add-color-button:only-child {
  border-radius: 11px;
}

colorswatch#add-color-button overlay {
  background-color: #FFFFFF;
}

colorswatch:disabled {
  opacity: 0.5;
}

colorswatch:disabled overlay {
  box-shadow: none;
}

colorswatch#editor-color-sample {
  border-radius: 11px;
}

colorswatch#editor-color-sample overlay {
  border-radius: 11px;
}

colorchooser .popover.osd {
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
  border-radius: 12px;
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

colorchooser .popover.osd:backdrop {
  box-shadow: 0 3px 2px -3px rgba(0, 0, 0, 0.3), 0 2px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 3px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
}

/********
 * Misc *
 ********/
.content-view {
  background-color: #F2F2F2;
}

/**********************
 * Window Decorations *
 **********************/
decoration {
  border-radius: 18px;
  box-shadow: 0 8px 6px -5px rgba(0, 0, 0, 0.2), 0 16px 16px 2px rgba(0, 0, 0, 0.14), 0 6px 18px 5px rgba(0, 0, 0, 0.12), 0 16px 16px 2px transparent, 0 6px 18px 5px transparent;
  border: none;
  margin: 8px;
}

decoration:backdrop {
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12), 0 16px 16px 2px transparent, 0 6px 18px 5px transparent;
  transition: box-shadow 75ms cubic-bezier(0, 0, 0.2, 1);
}

.maximized decoration, .fullscreen decoration, .tiled decoration, .tiled-top decoration, .tiled-right decoration, .tiled-bottom decoration, .tiled-left decoration {
  border-radius: 0;
}

.maximized decoration, .fullscreen decoration, .popup decoration {
  box-shadow: none;
}

.ssd decoration {
  border-radius: 18px 18px 0 0;
  box-shadow: none;
  margin: 0;
}

.ssd decoration, .ssd decoration:backdrop {
  transition: none;
}

.csd.popup decoration {
  border-radius: 11px;
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12);
}

tooltip.csd decoration {
  border-radius: 12px;
  box-shadow: none;
}

messagedialog.csd decoration {
  border-radius: 18px;
}

.solid-csd decoration {
  margin: 0;
  padding: 1px;
  border-radius: 0;
  box-shadow: none;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

.solid-csd decoration:backdrop {
  background-color: #FAFAFA;
}

/**********************
 * Touch Copy & Paste *
 **********************/
cursor-handle {
  color: #1A73E8;
  -gtk-icon-source: -gtk-recolor(url("assets/scalable/cursor-handle-symbolic.svg"));
}

cursor-handle.top:dir(ltr), cursor-handle.bottom:dir(rtl) {
  -gtk-icon-transform: rotate(90deg);
}

cursor-handle.bottom:dir(ltr), cursor-handle.top:dir(rtl) {
  -gtk-icon-transform: unset;
}

cursor-handle.insertion-cursor:dir(ltr), cursor-handle.insertion-cursor:dir(rtl) {
  padding-top: 6px;
  -gtk-icon-transform: rotate(45deg);
}

.context-menu {
  font: initial;
}

.keycap {
  min-width: 12px;
  min-height: 26px;
  margin-top: 2px;
  padding-bottom: 2px;
  padding-left: 8px;
  padding-right: 8px;
  border: solid 1px rgba(0, 0, 0, 0.12);
  border-radius: 8px;
  box-shadow: inset 0 -2px rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
  background-clip: border-box;
  color: rgba(0, 0, 0, 0.87);
  font-size: smaller;
}

:not(decoration):not(window):drop(active) {
  caret-color: #1A73E8;
}

stackswitcher {
  min-height: 0;
  padding: 0;
  border-radius: 9999px;
  background-color: alpha(currentColor, 0.05);
}

stackswitcher:not(.vertical) > button:not(.suggested-action):not(.destructive-action) {
  margin: 0 0;
  background-color: transparent;
}

stackswitcher:not(.vertical) > button:not(.suggested-action):not(.destructive-action):first-child, stackswitcher:not(.vertical) > button:not(.suggested-action):not(.destructive-action):last-child, stackswitcher:not(.vertical) > button:not(.suggested-action):not(.destructive-action) {
  border-radius: 9999px;
}

stackswitcher:not(.vertical) > button:not(.suggested-action):not(.destructive-action).text-button:not(.circular) {
  min-width: 100px;
}

stackswitcher:not(.vertical) > button:not(.suggested-action):not(.destructive-action):focus:not(:hover) {
  box-shadow: inset 0 0 0 2px alpha(currentColor, 0.08);
}

stackswitcher:not(.vertical) > button:not(.suggested-action):not(.destructive-action):active {
  box-shadow: inset 0 0 0 9999px alpha(#1A73E8, 0.08);
  background-image: radial-gradient(circle, alpha(#1A73E8, 0.08) 10%, transparent 0%);
}

stackswitcher:not(.vertical) > button:not(.suggested-action):not(.destructive-action):checked {
  background-color: #1A73E8;
  color: white;
}

stackswitcher button.text-button {
  min-width: 100px;
}

stackswitcher button.circular,
stackswitcher button.text-button.circular {
  min-width: 36px;
  min-height: 36px;
  padding: 0;
}

/*************
 * App Icons *
 *************/
.lowres-icon {
  -gtk-icon-shadow: none;
}

.icon-dropshadow {
  -gtk-icon-shadow: none;
}

/*********
 * Emoji *
 *********/
popover.emoji-picker {
  padding: 0;
}

popover.emoji-picker entry {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  border-image: none;
  border-radius: 0;
  box-shadow: none;
  background-color: transparent;
}

popover.emoji-picker scrolledwindow {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

button.emoji-section {
  margin: 3px;
  border-radius: 8px;
}

button.emoji-section:checked {
  color: #1A73E8;
}

button.emoji-section:not(:last-child) {
  margin-right: 0;
}

popover.emoji-picker .emoji {
  min-width: 3em;
  min-height: 3em;
  padding: 0 8px;
}

popover.emoji-picker .emoji widget {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  border-radius: 12px;
}

popover.emoji-picker .emoji widget:hover {
  background-color: alpha(currentColor, 0.08);
}

popover.emoji-completion {
  padding: 8px 0;
}

popover.emoji-completion arrow {
  border: none;
  background: none;
}

popover.emoji-completion .emoji-completion-row {
  min-height: 28px;
  padding: 0 12px;
}

popover.emoji-completion .emoji:hover {
  background-color: alpha(currentColor, 0.08);
}

/************
 * Nautilus *
 ************/
.nautilus-window.background.csd.unified headerbar {
  box-shadow: none;
}

.nautilus-window.background.csd {
  background-color: #FFFFFF;
  border-radius: 0 0 18px 18px;
}

.nautilus-window.background.csd headerbar {
  padding-left: 12px;
  background-color: #FFFFFF;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
}

.nautilus-window.background.csd > grid.horizontal > paned.horizontal > separator,
.nautilus-window.background.csd > deck > box.vertical > paned.horizontal > separator {
  margin-left: 0;
}

.nautilus-window.background.csd placessidebar {
  background-color: transparent;
  border-radius: 18px;
  color: rgba(0, 0, 0, 0.6);
  margin: 0 0 12px 12px;
}

.nautilus-window.background.csd placessidebar > viewport.frame {
  border-radius: 12px;
  background-color: rgba(26, 115, 232, 0.08);
}

.nautilus-window.background.csd placessidebar > viewport.frame > list {
  padding: 12px 0 12px 0;
  background: none;
  border-radius: 12px;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable {
  border-radius: 0;
  margin: -8px 0 -8px 0;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:focus, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:hover, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:active {
  background-image: none;
  box-shadow: none;
  animation: none;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable image.sidebar-icon, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable label.sidebar-label {
  color: rgba(0, 0, 0, 0.6);
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable image.sidebar-icon {
  padding-right: 6px;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable label.sidebar-label {
  color: inherit;
  min-height: 54px;
  padding: 0 0 0 6px;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable.sidebar-placeholder-row {
  background-color: transparent;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable > revealer.sidebar-revealer {
  padding-left: 12px;
  padding-right: 0;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable > revealer.sidebar-revealer > widget > box {
  padding-right: 12px;
  padding-left: 0;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:drop(active) {
  border-radius: 0;
  background-color: rgba(245, 124, 0, 0.1);
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:drop(active), .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:drop(active) image.sidebar-icon, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:drop(active) label.sidebar-label {
  color: #F57C00;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:hover image.sidebar-icon, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:hover label.sidebar-label {
  color: #1A73E8;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:selected {
  background-color: transparent;
  font-weight: 700;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:selected image.sidebar-icon, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:selected label.sidebar-label {
  color: #1A73E8;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:selected > revealer.sidebar-revealer > widget > box {
  background-color: #FFFFFF;
  border-image-width: 10px 10px 10px 46px;
  border-image-slice: 10 10 10 46;
  border-image-repeat: stretch;
  border-image-source: -gtk-scaled(url("assets/row-selected-light.png"), url("assets/row-selected-light@2.png"));
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:selected > revealer.sidebar-revealer > widget > box label.sidebar-label {
  padding-left: 14px;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:selected button.sidebar-button {
  color: #1A73E8;
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:disabled, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:disabled image.sidebar-icon, .nautilus-window.background.csd placessidebar > viewport.frame > list > row.activatable:disabled label.sidebar-label {
  color: rgba(0, 0, 0, 0.26);
}

.nautilus-window.background.csd placessidebar > viewport.frame > list > separator {
  background: none;
}

.nautilus-window.background.csd placessidebar scrollbar {
  background: none;
  border: none;
  margin: 2px 0;
}

.nautilus-window.background.csd placessidebar > undershoot.top {
  background: none;
}

.nautilus-window.background.csd placessidebar > undershoot.bottom {
  background: none;
}

.nautilus-window.background.csd placessidebar > overshoot.top {
  border-radius: 12px 12px 0 0;
}

.nautilus-window.background.csd placessidebar > overshoot.bottom {
  border-radius: 0 0 12px 12px;
}

.nautilus-window.background.csd .nautilus-list-view {
  background-color: transparent;
  border-radius: 18px;
}

.nautilus-window.background.csd .nautilus-list-view treeview.view:not(:hover):not(:active):not(:selected) {
  background-color: transparent;
  border-radius: 0;
}

.nautilus-window.background.csd .nautilus-list-view treeview.view:not(:hover):not(:active):not(:selected) > header > button:first-child {
  border-top-left-radius: 18px;
}

.nautilus-window.background.csd .nautilus-list-view treeview.view:not(:hover):not(:active):not(:selected) > header > button:last-child {
  border-top-right-radius: 18px;
}

.nautilus-window.background.csd notebook {
  background: none;
  margin: 0;
}

.nautilus-window.background.csd notebook > header {
  padding: 0 16px;
  background: none;
  border-color: #dedede;
}

.nautilus-window.background.csd notebook > header tab {
  color: rgba(0, 0, 0, 0.6);
}

.nautilus-window.background.csd notebook > header tab:hover:not(:checked):not(:active) {
  color: rgba(0, 0, 0, 0.87);
  background-color: rgba(0, 0, 0, 0.04);
}

.nautilus-window.background.csd notebook > header tab:disabled {
  color: rgba(0, 0, 0, 0.26);
}

.nautilus-window.background.csd notebook > header tab:checked, .nautilus-window.background.csd notebook > header tab:active {
  color: rgba(0, 0, 0, 0.87);
  border-color: #dedede;
}

.nautilus-window.background.csd notebook > header tab:checked:disabled, .nautilus-window.background.csd notebook > header tab:active:disabled {
  color: rgba(0, 0, 0, 0.38);
}

.nautilus-window.background.csd notebook > stack {
  background-color: #FFFFFF;
  border-radius: 16px;
}

.nautilus-window.background.csd notebook scrolledwindow > .view:not(:selected):not(:hover):not(:checked) {
  background-color: transparent;
}

.nautilus-window.background.csd notebook scrolledwindow .view:selected {
  background-color: #ddeafc;
}

.nautilus-window.background.csd notebook placesview > stack > frame > scrolledwindow > viewport > list {
  background-color: transparent;
}

.nautilus-window.background.csd notebook placesview > actionbar {
  background-color: transparent;
  border-radius: 0 0 18px 18px;
}

.nautilus-window.background.csd notebook placesview > actionbar > revealer > box {
  background-color: transparent;
}

.nautilus-window.background.csd paned > separator {
  background: none;
}

.nautilus-window.background.csd paned > separator.wide {
  min-width: 0;
  min-height: 0;
  background: none;
}

.nautilus-window.maximized, .nautilus-window.maximized placessidebar {
  border-radius: 0;
}

.nautilus-window .floating-bar {
  min-height: 28px;
  padding: 3px;
  margin: 6px;
  border-style: none;
  border-radius: 9999px;
  background-color: rgba(242, 242, 242, 0.95);
}

.nautilus-window .floating-bar button {
  margin: 4px;
}

.windowhandle .linked.nautilus-path-bar {
  background-color: rgba(0, 0, 0, 0.04);
  border-radius: 9999px;
  margin: 6px 0;
}

.windowhandle .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action) {
  margin-top: 0;
  margin-bottom: 0;
  border-radius: 9999px;
}

.windowhandle .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action).current-dir {
  color: rgba(0, 0, 0, 0.87);
}

.windowhandle .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action).current-dir:hover, .windowhandle .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action).current-dir:active {
  background: none;
  box-shadow: none;
}

.nautilus-canvas-item.dim-label,
.nautilus-list-dim-label {
  color: rgba(0, 0, 0, 0.6);
}

.nemo-desktop.nemo-canvas-item, .caja-desktop.caja-canvas-item,
.nautilus-desktop.nautilus-canvas-item {
  color: white;
  text-shadow: 0 1px 1px rgba(0, 0, 0, 0.2), 0 1px 2px rgba(0, 0, 0, 0.14), 0 1px 3px rgba(0, 0, 0, 0.12);
}

@keyframes nautilus-operations-button-needs-attention {
  to {
    background-color: alpha(currentColor, 0.08);
  }
}

.nautilus-operations-button-needs-attention {
  animation: nautilus-operations-button-needs-attention 300ms cubic-bezier(0.4, 0, 0.2, 1) 2 alternate;
}

.nautilus-operations-button-needs-attention-multiple {
  animation: nautilus-operations-button-needs-attention 300ms cubic-bezier(0.4, 0, 0.2, 1) 6 alternate;
}

.path-bar-box {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  margin: 6px 0;
  border-radius: 9999px;
}

.path-bar-box button {
  margin: 0;
}

.path-bar-box.width-maximized {
  background-color: rgba(0, 0, 0, 0.04);
}

.path-bar-box.background.frame {
  border-style: none;
  background-color: rgba(0, 0, 0, 0.04);
}

.path-bar-box .path-bar button label:not(:only-child):first-child {
  margin-left: 0;
}

.path-bar-box .path-bar button label:not(:only-child):last-child {
  margin-right: 0;
}

.path-bar-box .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action) {
  padding-left: 12px;
  padding-right: 12px;
  margin-left: 1px;
  margin-right: 1px;
}

.path-bar-box .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action) label:not(:only-child):first-child {
  margin-left: 0;
}

.path-bar-box .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action) label:not(:only-child):last-child {
  margin-right: 0;
}

.path-bar-box .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action).text-button {
  min-width: 0;
  border-radius: 9999px;
}

.path-bar-box .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action).text-button.image-button {
  border-radius: 9999px;
}

.path-bar-box .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action).text-button.image-button image:not(:only-child) {
  margin: 0;
}

.path-bar-box .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action):last-child:dir(ltr), .path-bar-box .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action):first-child:dir(rtl) {
  background-color: rgba(0, 0, 0, 0.08);
}

.path-bar-box .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action):last-child:dir(ltr):disabled, .path-bar-box .linked.nautilus-path-bar button:not(.suggested-action):not(.destructive-action):first-child:dir(rtl):disabled {
  background-color: transparent;
  color: rgba(0, 0, 0, 0.38);
}

.disk-space-display.unknown {
  background-color: rgba(0, 0, 0, 0.26);
  color: rgba(0, 0, 0, 0.26);
}

.disk-space-display.used {
  background-color: #1A73E8;
  color: #1A73E8;
}

.disk-space-display.free {
  background-color: rgba(0, 0, 0, 0.15);
  color: rgba(0, 0, 0, 0.15);
}

.search-information {
  padding: 2px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.87);
}

.conflict-row:not(:selected) {
  background-color: #fff3b3;
}

.nautilus-window flowboxchild .icon-item-background {
  padding: 4px;
  border-radius: 6px;
}

.nautilus-window flowboxchild:selected {
  background-color: transparent;
}

.nautilus-window notebook :not(treeview).view {
  border-radius: 6px;
}

dialog.background > box.dialog-vbox.vertical > grid.horizontal > scrolledwindow.frame {
  border-style: none;
}

dialog.background > box.dialog-vbox.vertical > grid.horizontal > box.horizontal:last-child {
  margin: -6px 0 0 -6px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

dialog.background > box.dialog-vbox.vertical > grid.horizontal > box.horizontal:last-child > label {
  margin: 0 8px;
}

dialog.background > box.dialog-vbox.vertical > grid.horizontal > box.horizontal:last-child > box > button {
  border-radius: 0;
}

.nautilus-window > popover.menu:not(:last-child) {
  padding: 3px;
}

.nautilus-window > popover.menu:not(:last-child) > stack > box > box > box {
  margin-top: -6px;
}

.nautilus-window > popover.menu:not(:last-child) > stack > box > box > box > box {
  margin-bottom: -6px;
}

.nautilus-window > popover.menu:not(:last-child) > stack > box > box > box > box.linked {
  margin-top: 1px;
}

.nautilus-window > popover.menu:not(:last-child) separator {
  margin-bottom: -2px;
}

.nautilus-menu-sort-heading {
  margin: 1px 3px;
  font-weight: 500;
}

.nautilus-menu-sort-heading:disabled {
  color: rgba(0, 0, 0, 0.6);
}

.nautilus-window paned > separator {
  background-color: #FAFAFA;
}

/*********
 * gedit *
 *********/
window.org-gnome-gedit > paned.titlebar,
window.background.csd > paned.titlebar {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

window.org-gnome-gedit > paned.titlebar:backdrop,
window.background.csd > paned.titlebar:backdrop {
  background-color: #FAFAFA;
}

window.org-gnome-gedit > paned.titlebar > separator, window.org-gnome-gedit > paned.titlebar > headerbar,
window.background.csd > paned.titlebar > separator,
window.background.csd > paned.titlebar > headerbar {
  background-color: transparent;
}

.gedit-side-panel-paned > box.vertical > stack > grid.horizontal > box.horizontal {
  margin: 4px 2px;
}

.gedit-side-panel-paned > box.vertical > stack > grid.horizontal > scrolledwindow {
  border-bottom-left-radius: 18px;
}

.gedit-side-panel-paned > box.vertical > stack > grid.horizontal > scrolledwindow treeview.view:not(:hover):not(:selected) {
  background: none;
}

.gedit-side-panel-paned stack scrolledwindow viewport.frame list.gedit-document-panel {
  background: none;
}

.open-document-selector-path-label {
  color: rgba(0, 0, 0, 0.6);
  font-size: smaller;
}

.open-document-selector-match {
  background-color: #FFD600;
  color: rgba(0, 0, 0, 0.87);
}

.gedit-document-panel {
  background-color: #FAFAFA;
  border-bottom-left-radius: 18px;
}

.gedit-document-panel row button.flat {
  margin-top: 8px;
  margin-bottom: 8px;
}

.gedit-document-panel-group-row:not(:first-child) {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.gedit-side-panel-paned statusbar {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 0 0 18px 18px;
}

.gedit-search-slider {
  margin: 0 6px 8px;
  padding: 6px;
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.6);
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12);
  border-radius: 0 0 18px 18px;
}

.gedit-search-slider .linked:not(.vertical) > entry {
  border-radius: 12px;
}

.gedit-search-slider .linked:not(.vertical) > entry .gedit-search-entry-occurrences-tag {
  all: unset;
  color: rgba(0, 0, 0, 0.6);
}

.gedit-search-slider .linked:not(.vertical) > entry:dir(ltr):not(:only-child) {
  margin-right: -66px;
  padding-right: 66px;
}

.gedit-search-slider .linked:not(.vertical) > entry:dir(ltr):not(:only-child) .gedit-search-entry-occurrences-tag {
  margin-left: 6px;
}

.gedit-search-slider .linked:not(.vertical) > entry:dir(ltr):not(:only-child) image.right {
  margin-right: 0;
}

.gedit-search-slider .linked:not(.vertical) > entry:dir(rtl):not(:only-child) {
  margin-left: -66px;
  padding-left: 66px;
}

.gedit-search-slider .linked:not(.vertical) > entry:dir(rtl):not(:only-child) .gedit-search-entry-occurrences-tag {
  margin-right: 6px;
}

.gedit-search-slider .linked:not(.vertical) > entry:dir(rtl):not(:only-child) image.left {
  margin-left: 0;
}

.gedit-search-slider .linked:not(.vertical) > entry:not(.error) {
  background-color: #FFFFFF;
}

.gedit-search-slider .linked:not(.vertical) > entry.error ~ button {
  color: rgba(255, 255, 255, 0.7);
}

.gedit-search-slider .linked:not(.vertical) > entry.error ~ button:hover, .gedit-search-slider .linked:not(.vertical) > entry.error ~ button:active {
  color: white;
}

.gedit-search-slider .linked:not(.vertical) > entry.error ~ button:disabled {
  color: rgba(255, 255, 255, 0.3);
}

.gedit-search-slider .linked > button {
  border: solid 6px transparent;
  border-radius: 9999px;
}

.gedit-search-slider .linked > button:last-child:dir(ltr), .gedit-search-slider .linked > button:not(:first-child):dir(rtl) {
  margin-left: -3px;
  border-radius: 9999px;
}

.gedit-search-slider .linked > button:first-child:dir(rtl), .gedit-search-slider .linked > button:not(:last-child):dir(ltr) {
  margin-right: -3px;
  border-radius: 9999px;
}

frame.gedit-map-frame > border:dir(ltr) {
  border-style: none none none solid;
}

frame.gedit-map-frame > border:dir(rtl) {
  border-style: none solid none none;
}

/**********
 * Tweaks *
 **********/
.tweak-categories {
  background-image: image(#FAFAFA);
}

.csd .tweak-categories {
  border-bottom-left-radius: 18px;
}

.tweak {
  padding: 3px;
}

.tweak.title:hover {
  box-shadow: none;
}

.tweak-group-white,
.tweak-white,
.tweak-white:hover {
  background-image: image(#FFFFFF);
}

.tweak-startup,
.tweak-startup:hover {
  background-image: image(#FFFFFF);
}

.tweak-group-startup {
  background-image: image(#FFFFFF);
}

.tweak-group-startup row.tweak-startup {
  border-radius: 12px;
  background-color: transparent;
  background-image: none;
}

row#Focus,
row#ClickMethod,
row#PrimaryWorkspaceTweak,
row#workspaces-only-on-primary {
  margin-top: 4px;
}

leaflet.titlebar > .titlebar.tweak-titlebar-right, leaflet.titlebar > .titlebar.tweak-titlebar-left, hdyleaflet.titlebar > .titlebar.tweak-titlebar-right, hdyleaflet.titlebar > .titlebar.tweak-titlebar-left {
  background-color: inherit;
  box-shadow: inherit;
  transition: color 75ms cubic-bezier(0, 0, 0.2, 1);
}

leaflet.titlebar > .titlebar.tweak-titlebar-right + separator, leaflet.titlebar > .titlebar.tweak-titlebar-left + separator, hdyleaflet.titlebar > .titlebar.tweak-titlebar-right + separator, hdyleaflet.titlebar > .titlebar.tweak-titlebar-left + separator {
  background-color: inherit;
  background-image: image(rgba(0, 0, 0, 0.12));
}

list.navigation-sidebar {
  border-bottom-left-radius: 18px;
}

list.navigation-sidebar > separator {
  background-color: transparent;
}

/************************
 * Gnome Control Center *
 ************************/
window.background.csd > headerbar.titlebar > leaflet.unfolded > headerbar:first-child:not(:only-child),
window.background.csd > headerbar.titlebar > hdyleaflet.unfolded > headerbar:first-child:not(:only-child) {
  border-top-left-radius: 18px;
}

window.background.csd > headerbar.titlebar > leaflet.unfolded > headerbar:last-child:not(:only-child),
window.background.csd > headerbar.titlebar > hdyleaflet.unfolded > headerbar:last-child:not(:only-child) {
  border-top-right-radius: 18px;
}

window.background.csd > headerbar.titlebar > leaflet.unfolded > headerbar:first-child:only-child, window.background.csd > headerbar.titlebar > leaflet.unfolded > headerbar:last-child:only-child,
window.background.csd > headerbar.titlebar > hdyleaflet.unfolded > headerbar:first-child:only-child,
window.background.csd > headerbar.titlebar > hdyleaflet.unfolded > headerbar:last-child:only-child {
  border-top-right-radius: 18px;
  border-top-left-radius: 18px;
}

window.background.csd > stack:not(.titlebar) > stack.background {
  border-radius: 0 0 18px 18px;
}

window.background.csd > leaflet > stack.background,
window.background.csd > hdyleaflet > stack.background,
window.background.csd > box.horizontal > stack.background {
  background: none;
}

window.background.csd > leaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame,
window.background.csd > hdyleaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame,
window.background.csd > box.horizontal > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame {
  background-color: #FFFFFF;
  border-bottom-right-radius: 18px;
}

window.background.csd > leaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view,
window.background.csd > hdyleaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view,
window.background.csd > box.horizontal > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view {
  background: none;
}

window.background.csd > leaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button,
window.background.csd > hdyleaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button,
window.background.csd > box.horizontal > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button {
  min-width: 28px;
  min-height: 26px;
  margin: 3px;
  background-color: rgba(0, 0, 0, 0.65);
  color: white;
}

window.background.csd > leaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button:hover,
window.background.csd > hdyleaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button:hover,
window.background.csd > box.horizontal > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button:hover {
  background-color: rgba(0, 0, 0, 0.75);
  color: white;
}

window.background.csd > leaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button:active,
window.background.csd > hdyleaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button:active,
window.background.csd > box.horizontal > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button:active {
  background-color: rgba(0, 0, 0, 0.85);
  color: white;
}

window.background.csd > leaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button:disabled,
window.background.csd > hdyleaflet > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button:disabled,
window.background.csd > box.horizontal > stack.background > widget > box.vertical > box.vertical > scrolledwindow > viewport.frame > box.vertical.view flowboxchild button.osd.remove-button:disabled {
  background-color: rgba(0, 0, 0, 0.3);
  color: rgba(255, 255, 255, 0.45);
}

window.background.csd > leaflet > stack.background frame.view,
window.background.csd > hdyleaflet > stack.background frame.view,
window.background.csd > box.horizontal > stack.background frame.view {
  border-radius: 12px;
  background: none;
}

window.background.csd > leaflet > box.vertical > scrolledwindow.view,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view,
window.background.csd > box.horizontal > box.vertical > scrolledwindow.view {
  background-color: #FFFFFF;
  border-bottom-left-radius: 18px;
}

window.background.csd > leaflet > box.vertical > scrolledwindow.view > viewport.frame > stack,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack,
window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack {
  background-color: transparent;
}

window.background.csd > leaflet > box.vertical > scrolledwindow.view > viewport.frame > stack list,
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack list,
window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack list {
  background-color: transparent;
}

window.background.csd > leaflet > box.vertical > scrolledwindow.view > viewport.frame > stack list row.activatable:not(:hover):not(:active):not(:selected),
window.background.csd > hdyleaflet > box.vertical > scrolledwindow.view > viewport.frame > stack list row.activatable:not(:hover):not(:active):not(:selected),
window.background.csd > box.horizontal > box.vertical > scrolledwindow.view > viewport.frame > stack list row.activatable:not(:hover):not(:active):not(:selected) {
  background-color: transparent;
}

window.background.csd > leaflet.folded > box.vertical > scrolledwindow.view {
  border-bottom-right-radius: 18px;
}

window.background.csd stack.background clamp.medium frame > box.vertical > box.vertical > list {
  border-top-width: 0;
  border-bottom-width: 0;
}

window.background.csd stack.background clamp.medium frame > box.vertical > box.vertical > list, window.background.csd stack.background clamp.medium frame > box.vertical > box.vertical > list > row {
  border-radius: 0;
}

window.background.csd stack.background clamp.medium frame > box.vertical > box.vertical:first-child > list {
  border-top-width: 1px;
}

window.background.csd stack.background clamp.medium frame > box.vertical > box.vertical:first-child > list, window.background.csd stack.background clamp.medium frame > box.vertical > box.vertical:first-child > list > row {
  border-radius: 12px 12px 0 0;
}

window.background.csd stack.background clamp.medium frame > box.vertical > box.vertical:last-child > list {
  border-bottom-width: 1px;
}

window.background.csd stack.background clamp.medium frame > box.vertical > box.vertical:last-child > list, window.background.csd stack.background clamp.medium frame > box.vertical > box.vertical:last-child > list > row {
  border-radius: 0 0 12px 12px;
}

dialog.background.csd > box.vertical.dialog-vbox > notebook > stack > box.horizontal > notebook > stack {
  border-radius: 0 0 18px 18px;
}

hdyleaflet frame > border, leaflet frame > border, box.horizontal > stack.background frame > border {
  border: none;
}

hdyleaflet > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) > separator, leaflet > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) > separator, box.horizontal > stack.background > box.vertical > scrolledwindow > viewport.frame list:not(.view):not(.tweak-group) > separator {
  margin: 3px 0;
}

/************************
 * Gnome system monitor *
 ************************/
window#gnome-system-monitor.background.csd > box.vertical > stack {
  background-color: #FFFFFF;
  border-radius: 0 0 18px 18px;
}

window#gnome-system-monitor.background.csd > box.vertical > stack > box.vertical > scrolledwindow treeview.view:not(.progressbar):not(.trough):not(:hover):not(:active):not(:selected) {
  background: none;
}

window#gnome-system-monitor.background.csd > box.vertical > stack > box.vertical > revealer > actionbar > revealer > box {
  border-radius: 0 0 18px 18px;
}

window#gnome-system-monitor.background:not(.csd) > box.vertical > headerbar {
  box-shadow: none;
}

/************************
 * Gnome Sound Recorder *
 ************************/
stack > grid.vertical > scrolledwindow {
  border: none;
  border-radius: 0 0 18px 18px;
}

stack > grid.vertical > scrolledwindow > viewport.frame list {
  border-radius: 0 0 18px 18px;
}

stack > grid.vertical scrolledwindow.frame.emptyGrid {
  border: none;
}

/******************
 * Gnome Contacts *
 ******************/
window.background.csd scrolledwindow.contacts-contact-form {
  border-bottom-right-radius: 18px;
}

/************************
 * Epiphany (Gnome Web) *
 ************************/
tabbox {
  background-color: #F2F2F2;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
  padding: 3px 3px 0;
}

tabbox > tab {
  border-radius: 12px 12px 0 0;
  border-bottom: none;
}

tabbox > tab button {
  min-height: 24px;
  min-width: 24px;
  border-radius: 9999px;
  border: none;
  padding: 0;
}

/*****************
 * Gnome Weather *
 *****************/
#weather-page,
#weekly-forecast-frame {
  border-bottom-right-radius: 18px;
}

#weather-page-content-view {
  border-bottom-right-radius: 18px;
  border-bottom-left-radius: 18px;
}

statuspage.search-view entry.search {
  background-color: #FFFFFF;
}

statuspage.search-view entry.search:focus {
  box-shadow: none;
}

/***************
 * Gnome Music *
 ***************/
window.background.csd box.vertical > overlay > stack.background {
  border-radius: 0 0 18px 18px;
}

/****************
 * Gnome Clocks *
 ****************/
window.background.csd.unified {
  border-top-left-radius: 18px;
  border-top-right-radius: 18px;
}

window.background.csd.unified > deck > deck > deck > box.vertical > headerbar.titlebar.windowhandle {
  border-top-left-radius: 18px;
  border-top-right-radius: 18px;
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
}

window.background.csd.unified > deck > deck > deck > box.vertical > headerbar.titlebar.windowhandle > viewswitchertitle > squeezer {
  margin: 0 0;
  background: none;
}

window.background.csd.unified > deck > deck > deck > box.vertical > headerbar.titlebar.windowhandle > viewswitchertitle > squeezer > viewswitcher > box.horizontal > button.radio {
  margin: 0;
  padding: 0;
  border-radius: 0;
}

/*************
 * Rhythmbox *
 *************/
window.background > box.vertical > toolbar.primary-toolbar > toolitem > box.horizontal:not(.linked) > button.toggle,
window.background > box.vertical > toolbar.primary-toolbar > toolitem > .linked > button:not(.toggle):not(.raised):not(.flat), window.background > box.vertical > toolbar.primary-toolbar > toolitem button.flat.scale, window.background > box.vertical > toolbar.primary-toolbar > toolitem > .linked > button.image-button.raised, window.csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > .linked > button,
window.csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > box.horizontal > button,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > .linked > button,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal > toolitem > box.horizontal > button {
  min-height: 24px;
  min-width: 24px;
  padding: 6px;
  margin: 0;
}

.sidebar-paned .inline-toolbar.horizontal.sidebar-toolbar button.image-button {
  border-radius: 9999px;
}

.sidebar-paned .inline-toolbar.horizontal.sidebar-toolbar button.image-button:not(:first-child), .sidebar-paned .inline-toolbar.horizontal.sidebar-toolbar button.image-button:not(:last-child) {
  border-top-left-radius: 9999px;
  border-bottom-left-radius: 9999px;
  border-top-right-radius: 9999px;
  border-bottom-right-radius: 9999px;
}

.sidebar-paned .inline-toolbar.horizontal.sidebar-toolbar button.image-button.image-button:not(.text-button):first-child {
  border-top-left-radius: 9999px;
  border-bottom-left-radius: 9999px;
}

.sidebar-paned .inline-toolbar.horizontal.sidebar-toolbar button.image-button.image-button:not(.text-button):last-child {
  border-top-right-radius: 9999px;
  border-bottom-right-radius: 9999px;
}

.sidebar-paned .inline-toolbar.horizontal.sidebar-toolbar button.image-button > widget > box > image {
  padding: 0;
}

window.csd > box.vertical > box.vertical > toolbar.horizontal,
window.solid-csd > box.vertical > box.vertical > toolbar.horizontal {
  padding: 6px;
  border-bottom: none;
  box-shadow: none;
  background-color: transparent;
}

window.csd > box.vertical > box.vertical > frame,
window.solid-csd > box.vertical > box.vertical > frame {
  margin: -1px 0;
  padding: 0;
}

window.csd > box.vertical > box.vertical > frame > border,
window.solid-csd > box.vertical > box.vertical > frame > border {
  border: none;
}

window.background > box.vertical > toolbar.primary-toolbar > toolitem > .linked > button.image-button.raised > widget > box > image {
  padding: 0;
}

/**********
 * Polari *
 **********/
.polari-room-list .sidebar {
  background: none;
}

.polari-room-list .sidebar > row.activatable:selected {
  background-color: #1A73E8;
  color: white;
}

stack.view.polari-entry-area {
  background-color: #F2F2F2;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  border-bottom-right-radius: 18px;
}

stack:disabled.view.polari-entry-area {
  background-image: image(#F2F2F2);
}

/***********
 * Builder *
 ***********/
layouttabbar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  background-color: #F2F2F2;
}

layouttabbar > box > button {
  margin: 2px 0;
}

layouttab {
  margin: 0 8px;
  border-style: none solid;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.1);
  box-shadow: inset 0 -2px #1A73E8;
  background-color: #FFFFFF;
}

layouttab separator.vertical {
  margin: 8px 4px;
}

layouttab button.text-button, layouttab button.image-button, layouttab button {
  margin-top: 8px;
  margin-bottom: 8px;
  padding: 0 4px;
}

layout {
  border: 1px solid rgba(0, 0, 0, 0.1);
  -PnlDockBin-handle-size: 1;
}

entry.search-missing {
  background-color: #E53935;
  color: white;
}

window.workbench treeview.image {
  color: rgba(0, 0, 0, 0.6);
}

popover.popover-selector list {
  padding: 6px;
}

popover.popover-selector list row {
  border-radius: 12px;
}

popover.popover-selector list row image:dir(ltr) {
  margin-right: 6px;
}

popover.popover-selector list row image:dir(rtl) {
  margin-left: 6px;
}

popover.popover-selector list row .accel:dir(ltr) {
  margin-left: 6px;
}

popover.popover-selector list row .accel:dir(rtl) {
  margin-right: 6px;
}

omnibar.linked:not(.vertical) entry {
  border-radius: 12px;
}

omnibar:not(:hover):not(:active) entry {
  color: rgba(0, 0, 0, 0.6);
}

popover.omnibar list row:not(:last-child) {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

entry.preferences-search {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  box-shadow: none;
  background-color: #FFFFFF;
}

preferences stacksidebar.sidebar list {
  background-color: #FAFAFA;
}

preferences stacksidebar.sidebar:dir(ltr) list, preferences stacksidebar.sidebar:dir(rtl) list {
  border-style: none;
}

preferences > box > box:dir(ltr) {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
}

preferences > box > box:dir(rtl) {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

popover.messagepopover.background {
  padding: 0;
}

popover.messagepopover .popover-action-area button {
  padding: 8px 16px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 0;
}

popover.messagepopover .popover-action-area button:first-child {
  border-bottom-left-radius: 12px;
}

popover.messagepopover .popover-action-area button:last-child {
  border-bottom-right-radius: 12px;
}

popover.messagepopover .popover-content-area {
  margin: 16px;
}

popover.transfers list {
  background-color: transparent;
}

popover.transfers list row:not(:first-child) {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

popover.transfers list row > box {
  padding: 10px;
}

dockbin {
  border: 1px solid rgba(0, 0, 0, 0.1);
  -PnlDockBin-handle-size: 1;
}

dockpaned {
  border: 1px solid rgba(0, 0, 0, 0.1);
}

eggsearchbar box.search-bar {
  padding: 0 8px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  background-color: #F2F2F2;
}

docktabstrip {
  padding: 0 8px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  background-color: #F2F2F2;
}

docktab {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 0ms, background-image 0ms;
  min-height: 24px;
  min-width: 24px;
  margin-bottom: -1px;
  padding: 6px 6px;
  border-width: 1px;
  border-color: transparent;
  box-shadow: inset 0 -2px transparent;
  background-image: radial-gradient(circle, #1A73E8 10%, transparent 0%);
  background-repeat: no-repeat;
  background-position: center;
  background-size: 0% 0%;
  color: rgba(0, 0, 0, 0.6);
  font-weight: 500;
}

docktab:hover {
  background-color: alpha(currentColor, 0.08);
  color: rgba(0, 0, 0, 0.87);
}

docktab:checked {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1), background-size 225ms cubic-bezier(0, 0, 0.2, 1), background-image 525ms cubic-bezier(0, 0, 0.2, 1);
  box-shadow: inset 0 -2px #1A73E8;
  background-color: transparent;
  background-image: radial-gradient(circle, transparent 10%, transparent 0%);
  background-size: 1000% 1000%;
  color: rgba(0, 0, 0, 0.87);
}

dockoverlayedge {
  background-color: #F2F2F2;
}

dockoverlayedge docktabstrip {
  padding: 0;
  border: none;
}

dockoverlayedge.left-edge docktab:checked {
  box-shadow: inset -2px 0 #1A73E8;
}

dockoverlayedge.right-edge docktab:checked {
  box-shadow: inset 2px 0 #1A73E8;
}

pillbox {
  background-color: #F2F2F2;
  border-radius: 12px;
}

layoutpane entry.search {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  box-shadow: none;
  background-color: #FFFFFF;
}

editortweak entry.search {
  margin-bottom: -1px;
  box-shadow: none;
  background-color: transparent;
}

.gb-search-entry-occurrences-tag {
  box-shadow: none;
  background-color: transparent;
}

docktabstrip {
  min-height: 39px;
}

window.workbench preferences preferencesgroup list entry {
  padding-top: 8px;
  padding-bottom: 8px;
}

button.run-arrow-button {
  padding-left: 10px;
  padding-right: 10px;
}

button.dzlmenubutton image {
  min-width: 30px;
}

button.dzlmenubutton image.arrow {
  min-width: 27px;
}

button.dzlmenubuttonitem {
  color: rgba(0, 0, 0, 0.87);
  font-weight: normal;
}

button.dzlmenubuttonitem:disabled {
  color: rgba(0, 0, 0, 0.38);
}

idelayoutstackheader {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

idelayoutstackheader button:checked {
  color: rgba(0, 0, 0, 0.87);
}

ideeditorutilities > dzldockpaned > box > stackswitcher {
  padding: 8px 0;
  background-color: #F2F2F2;
}

ideeditorutilities > dzldockpaned > box > stackswitcher:dir(ltr) {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
}

ideeditorutilities > dzldockpaned > box > stackswitcher:dir(rtl) {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

ideeditorutilities > dzldockpaned > box > stackswitcher button {
  border-radius: 0;
  box-shadow: none;
  background-color: transparent;
}

ideeditorutilities > dzldockpaned > box > stackswitcher button:active {
  background-image: radial-gradient(circle, rgba(26, 115, 232, 0.7) 10%, transparent 0%);
}

ideeditorutilities > dzldockpaned > box > stackswitcher button:checked {
  background-color: transparent;
  color: rgba(0, 0, 0, 0.87);
}

ideeditorutilities > dzldockpaned > box > stackswitcher button:dir(ltr) {
  margin-right: -1px;
}

ideeditorutilities > dzldockpaned > box > stackswitcher button:dir(ltr):checked {
  box-shadow: inset -2px 0 #1A73E8;
}

ideeditorutilities > dzldockpaned > box > stackswitcher button:dir(rtl) {
  margin-left: -1px;
}

ideeditorutilities > dzldockpaned > box > stackswitcher button:dir(rtl):checked {
  box-shadow: inset 2px 0 #1A73E8;
}

ideeditorsidebar notebook header {
  background: transparent;
}

popover.messagepopover list {
  border: 1px solid rgba(0, 0, 0, 0.12);
}

popover.messagepopover list row:not(:last-child) {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

/**********
 * Photos *
 **********/
GdMainIconView.content-view {
  -GdMainIconView-icon-size: 48;
}

.documents-counter {
  margin: 8px;
  border-radius: 9999px;
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12);
  background-color: #1A73E8;
  color: white;
  font-weight: bold;
}

.documents-scrolledwin.frame {
  border-style: none;
}

.documents-scrolledwin.frame frame.content-view > border {
  border-style: none;
}

.photos-fade-in {
  opacity: 1;
  transition: opacity 75ms cubic-bezier(0, 0, 0.2, 1);
}

.photos-fade-out {
  opacity: 0;
  transition: opacity 75ms cubic-bezier(0, 0, 0.2, 1);
}

button.photos-filter-preview {
  color: rgba(0, 0, 0, 0.87);
  font-weight: normal;
}

button.photos-filter-preview:checked {
  background-color: alpha(currentColor, 0.06);
  color: rgba(0, 0, 0, 0.87);
}

button.photos-filter-preview:checked image {
  color: white;
  -gtk-icon-shadow: 0 1px 1px rgba(0, 0, 0, 0.2), 0 1px 2px rgba(0, 0, 0, 0.14), 0 1px 3px rgba(0, 0, 0, 0.12);
}

overlay grid.horizontal > revealer > scrolledwindow.frame:dir(ltr) {
  border-style: none none none solid;
}

overlay grid.horizontal > revealer > scrolledwindow.frame:dir(rtl) {
  border-style: none solid none none;
}

/*********
 * Music *
 *********/
.side-panel:dir(ltr) {
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.12);
}

.side-panel:dir(rtl) {
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.12);
}

.side-panel .view {
  background-image: image(#FAFAFA);
}

.side-panel .view:hover {
  background-image: image(rgba(234, 234, 234, 0.9896));
}

.side-panel .view:selected {
  background-image: image(#1A73E8);
}

.side-panel .view:selected:hover {
  background-image: image(#2c7eea);
}

.songs-list:hover {
  background-image: image(alpha(currentColor, 0.08));
}

frame.documents-dropdown {
  margin: 8px;
}

frame.documents-dropdown > border {
  border: none;
}

box.vertical > revealer > toolbar.search-bar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  background-clip: border-box;
}

box.vertical > revealer > toolbar.search-bar button > widget {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
}

/*************
 * Documents *
 *************/
.documents-scrolledwin {
  background-color: transparent;
}

.documents-scrolledwin .content-view:not(:selected):not(:hover) {
  background-color: transparent;
}

.documents-scrolledwin viewport.frame {
  background-color: transparent;
}

.documents-scrolledwin viewport.frame widget > frame.content-view:not(:selected):not(:hover) {
  background-color: transparent;
}

.documents-scrolledwin viewport.frame widget > frame.content-view:not(:selected):not(:hover) border {
  border: none;
}

/***********************
 * Gnome Note (bijiben)*
 ***********************/
dialog.background scrolledwindow.frame > viewport > list {
  background-color: transparent;
  border: none;
}

/*******************
 * Document Viewer *
 *******************/
window.background.csd > box.vertical > paned.horizontal > box.vertical > scrolledwindow > treeview.view:not(:hover):not(:active):not(:selected) {
  background-color: transparent;
}

window.background.csd evview.view.content-view {
  border-radius: 0 0 18px 18px;
}

/*********************************
 * Archive Manager (File roller) *
 *********************************/
window.background.csd > grid.horizontal > paned.horizontal > scrolledwindow {
  border-radius: 0 0 18px 18px;
  background-color: #FFFFFF;
}

window.background.csd > grid.horizontal > paned.horizontal > scrolledwindow treeview.view:not(:hover):not(:active):not(:selected) {
  background-color: transparent;
}

window.background.csd > grid.horizontal > paned.horizontal > scrolledwindow > treeview.view:not(:hover):not(:active):not(:selected) {
  background-color: #FFFFFF;
}

window.background.csd > grid.horizontal > paned.horizontal > box + separator + scrolledwindow {
  border-radius: 0 0 18px 0;
}

window.background.csd > grid.horizontal > paned.horizontal > box.vertical > scrolledwindow {
  border-radius: 0 0 0 18px;
  background-color: #F2F2F2;
}

window.background.csd > grid.horizontal > paned.horizontal > box.vertical > scrolledwindow treeview.view:not(:hover):not(:active):not(:selected) {
  background-color: transparent;
}

/**************
 * Gnome Disk *
 **************/
window.background.csd > box.vertical > paned.horizontal > scrolledwindow treeview.view:not(:hover):not(:active):not(:selected) {
  background-color: transparent;
}

/************
 * Terminal *
 ************/
terminal-window.background.csd {
  border-radius: 0;
}

terminal-window.background.csd.maximized {
  border-radius: 0;
}

window.background > box.vertical > box.horizontal > frame > border {
  border-width: 0 1px 0 0;
}

window.background > box.vertical > box.horizontal > frame > scrolledwindow > viewport.frame list {
  border-bottom-left-radius: 18px;
}

window.background > box.vertical > box.horizontal > stack > widget > notebook.frame {
  border-width: 0;
}

window.background > box.vertical > box.horizontal > stack > widget > notebook.frame > stack {
  border-bottom-right-radius: 18px;
}

popover.background.menu radiobutton.system, popover.background.menu radiobutton.light, popover.background.menu radiobutton.dark {
  margin: 6px 0 3px;
}

/*********
 * To Do *
 *********/
task-list-view taskrow {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
  margin: 0 -8px;
}

task-list-view taskrow:hover {
  transition: none;
}

task-list-view taskrow label {
  margin: 0 8px;
}

task-list-view taskrow image.dim-label {
  min-width: 16px;
}

task-list-view > box > revealer > box > button {
  margin: -6px;
}

task-list-view > box > revealer > box > button .dim-label {
  color: inherit;
}

tasklistview taskrow {
  outline: none;
}

tasklistview taskrow entry, tasklistview taskrow entry:focus, tasklistview taskrow entry:disabled {
  box-shadow: none;
}

tasklistview taskrow image.dim-label {
  min-width: 16px;
}

tasklistview > box > revealer > box > button {
  margin: -6px;
}

tasklistview > box > revealer > box > button .dim-label {
  color: inherit;
}

/*******
 * Eog *
 *******/
#eog-thumb-nav scrolledwindow {
  border-top: none;
}

/*************
 * Evolution *
 *************/
frame.taskbar > border {
  border-style: solid none none;
}

box.vertical > paned.horizontal notebook widget .frame {
  border-style: none;
}

/***********
 * Fractal *
 ***********/
.background.csd.main-window .sidebar.rooms-sidebar {
  border-bottom-left-radius: 18px;
}

/********
 * Gitg *
 ********/
frame.commit-frame > border {
  border-style: solid none none;
}

/**************
 * Characters *
 **************/
box.dialog-vbox scrolledwindow.related {
  border: 1px solid rgba(0, 0, 0, 0.1);
}

list.categories {
  background-image: image(#FAFAFA);
}

/*********
 * Boxes *
 *********/
.transparent-bg + stack overlay > label {
  min-height: 24px;
  padding: 0 4px;
  border-radius: 12px;
  background-color: #242424;
  color: white;
}

/**************
 * Calculator *
 **************/
button.title label {
  min-height: 36px;
}

/*********
 * Geary *
 *********/
window.background.csd.geary-main-window box.vertical > paned.horizontal > box.sidebar.vertical,
window#GearyMainWindow.background.csd box.vertical > paned.horizontal > box.sidebar.vertical {
  border-bottom-left-radius: 18px;
}

window.background.csd.geary-main-window box.vertical > paned.horizontal > box.sidebar.vertical statusbar,
window#GearyMainWindow.background.csd box.vertical > paned.horizontal > box.sidebar.vertical statusbar {
  border-bottom-left-radius: 18px;
}

window.background.csd.geary-main-window stack#conversation_viewer,
window#GearyMainWindow.background.csd stack#conversation_viewer {
  border-bottom-right-radius: 18px;
}

window.background.csd.geary-main-window stack#conversation_viewer scrolledwindow.geary-conversation-scroller viewport.frame list.conversation-listbox,
window#GearyMainWindow.background.csd stack#conversation_viewer scrolledwindow.geary-conversation-scroller viewport.frame list.conversation-listbox {
  background: none;
  border-bottom-right-radius: 18px;
}

window.background.csd.geary-main-window stack#conversation_viewer .geary-expanded,
window#GearyMainWindow.background.csd stack#conversation_viewer .geary-expanded {
  animation: none;
  background-image: none;
}

window.background.csd.geary-main-window stack#conversation_viewer .geary-expanded > .geary-composer-embed actionbar > revealer > box,
window#GearyMainWindow.background.csd stack#conversation_viewer .geary-expanded > .geary-composer-embed actionbar > revealer > box {
  border-radius: 0;
}

window.background.csd.geary-main-window stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar,
window#GearyMainWindow.background.csd stack#conversation_viewer .geary-expanded > .geary-composer-embed headerbar {
  color: rgba(0, 0, 0, 0.87);
  background-color: #F2F2F2;
  box-shadow: none;
  border-bottom: 1px solid rgba(0, 0, 0, 0.1);
}

window.background.csd.geary-main-window stack#conversation_viewer .geary-composer-box actionbar > revealer > box,
window#GearyMainWindow.background.csd stack#conversation_viewer .geary-composer-box actionbar > revealer > box {
  border-bottom-left-radius: 0;
}

.geary-accounts-editor-pane frame:not(.geary-signature) > border,
.geary-accounts-editor-pane scrolledwindow.frame {
  border: none;
}

.geary-main-window > deck > overlay > .geary-main-layout {
  background-color: #FAFAFA;
}

.geary-main-window > deck > overlay > .geary-main-layout > leaflet > separator.sidebar,
.geary-main-window > deck > overlay > .geary-main-layout > leaflet > separator.geary-sidebar-pane-separator,
.geary-main-window > deck > overlay > .geary-main-layout > leaflet > leaflet > separator.sidebar {
  background-color: transparent;
  background-image: linear-gradient(to bottom, #FFFFFF 0%, #FFFFFF 47px, rgba(0, 0, 0, 0.12) 47px, rgba(0, 0, 0, 0.12) 100%);
  transition: background-image 75ms cubic-bezier(0, 0, 0.2, 1), color 75ms cubic-bezier(0, 0, 0.2, 1);
}

.geary-main-window > deck > overlay > .geary-main-layout > leaflet > separator.sidebar:backdrop,
.geary-main-window > deck > overlay > .geary-main-layout > leaflet > separator.geary-sidebar-pane-separator:backdrop,
.geary-main-window > deck > overlay > .geary-main-layout > leaflet > leaflet > separator.sidebar:backdrop {
  background-color: transparent;
  background-image: linear-gradient(to bottom, #FAFAFA 0%, #FAFAFA 47px, rgba(0, 0, 0, 0.12) 47px, rgba(0, 0, 0, 0.12) 100%);
}

.geary-main-window > deck > overlay > .geary-main-layout > leaflet > leaflet > box.vertical > .geary-conversation-frame > scrolledwindow {
  margin: -1px 0;
}

.geary-main-window geary-conversation-viewer#conversation_viewer list.background.conversation-listbox.content > row.activatable {
  border: 1px solid rgba(0, 0, 0, 0.12);
  border-bottom-width: 0;
  background-color: #FFFFFF;
}

.geary-main-window geary-conversation-viewer#conversation_viewer list.background.conversation-listbox.content > row.activatable:first-child {
  border-top-left-radius: 8px;
  border-top-right-radius: 8px;
}

.geary-main-window geary-conversation-viewer#conversation_viewer list.background.conversation-listbox.content .geary-attachment-pane {
  border-radius: 0 0 8px 8px;
}

.geary-main-window geary-conversation-viewer#conversation_viewer list.background.conversation-listbox.content .geary-attachment-pane actionbar.background {
  background-color: transparent;
}

.geary-main-window geary-conversation-viewer#conversation_viewer list.background.conversation-listbox.content .geary-attachment-pane actionbar.background > revealer > box {
  border-radius: 0 0 6px 6px;
}

.geary-main-window geary-conversation-viewer#conversation_viewer list.background.conversation-listbox.content geary-composer-editor box.background,
.geary-main-window geary-conversation-viewer#conversation_viewer list.background.conversation-listbox.content geary-composer-editor actionbar > revealer > box {
  border-radius: 0 0 8px 8px;
}

geary-composer-box#GearyComposerWindow geary-composer-editor box.background,
geary-composer-box#GearyComposerWindow geary-composer-editor actionbar > revealer > box {
  border-radius: 0 0 18px 18px;
}

/**************
 * Extensions *
 **************/
window.background.csd stack stack stack frame > border,
window.background.csd > stack > stack > box > frame > border,
window.background.csd > stack > stack > box > box > frame > border,
window.background.csd > stack > box > stack > box > frame > border,
window.background.csd > stack > box > stack > scrolledwindow > viewport frame > border,
window.background.csd > stack > box > stack > box > scrolledwindow > viewport > frame > border,
window.background.csd > stack > grid > scrolledwindow > viewport > box > frame > border {
  border: none;
}

window.background.csd > stack > box > box > list,
window.background.csd > stack > box > stack > scrolledwindow > viewport > list {
  border-bottom-left-radius: 18px;
}

window.background.csd > stack > box > .sidebar > scrolledwindow > viewport > list {
  padding: 0 0;
}

/***********
 * Dialogs *
 ***********/
dialog.background.csd > box.vertical.dialog-vbox > grid.horizontal > scrolledwindow.frame > viewport.frame list:first-child {
  border-radius: 0 0 0 18px;
}

dialog.background.csd > box.vertical.dialog-vbox > grid.horizontal > scrolledwindow.frame > viewport.frame list:last-child {
  border-radius: 0 0 18px 0;
}

dialog.background.csd > box.vertical.dialog-vbox > stack > scrolledwindow,
dialog.background.csd > box.vertical.dialog-vbox > stack > stack > scrolledwindow {
  border-radius: 0 0 18px 18px;
  background-color: #FFFFFF;
}

dialog.background.csd > box.vertical.dialog-vbox > stack > scrolledwindow iconview.view:not(:hover):not(:selected):not(:active),
dialog.background.csd > box.vertical.dialog-vbox > stack > stack > scrolledwindow iconview.view:not(:hover):not(:selected):not(:active) {
  background-color: transparent;
}

dialog.background.csd > box.vertical.dialog-vbox > stack > scrolledwindow > viewport.frame > list {
  border-radius: 0 0 18px 18px;
}

dialog.background.csd > box.vertical.dialog-vbox > stack > scrolledwindow > viewport.frame > list row.activatable:not(:hover):not(:selected):not(:active) {
  background-color: transparent;
}

dialog.background.csd > box.vertical.dialog-vbox > stack > box.vertical > stack.view > scrolledwindow > treeview.view:not(:hover):not(:selected):not(:active) {
  background-color: transparent;
}

dialog.background.csd > box.vertical.dialog-vbox > stack toolbar.toolbar {
  border-radius: 0 0 18px 18px;
}

dialog.background.csd > box.vertical.dialog-vbox > notebook:not(.frame), dialog.background.csd > box.vertical.dialog-vbox > notebook:not(.frame) > stack {
  border-radius: 0 0 18px 18px;
}

dialog.background.csd > box.vertical.dialog-vbox > notebook:not(.frame) .inline-toolbar {
  border-radius: 0 0 12px 12px;
}

dialog.background.csd stack scrolledwindow.frame {
  border-radius: 12px;
}

dialog.background.csd stack scrolledwindow.frame textview.view {
  border-radius: 12px;
}

dialog.background.csd stack scrolledwindow.frame textview.view > text {
  background: none;
}

dialog.background.csd stack scrolledwindow.frame treeview.view:not(:hover):not(:active):not(:selected) {
  background: none;
}

dialog.background.csd stack scrolledwindow viewport.frame.view {
  border-radius: 12px;
}

window.background > deck > box > overlay > stack > leaflet > box > scrolledwindow > viewport > box > stack > scrolledwindow {
  border: 1px solid rgba(0, 0, 0, 0.12);
}

window.background.csd.unified headerbar {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
}

window.background.csd.unified headerbar.selection-mode {
  box-shadow: none;
}

window.background.csd.unified > decoration-overlay {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
}

window.background.csd.unified,
window.background.csd.unified > decoration,
window.background.csd.unified > decoration-overlay {
  border-radius: 18px;
}

window.background.csd.unified.tiled > decoration-overlay, window.background.csd.unified.tiled-top > decoration-overlay, window.background.csd.unified.tiled-right > decoration-overlay, window.background.csd.unified.tiled-bottom > decoration-overlay, window.background.csd.unified.tiled-left > decoration-overlay, window.background.csd.unified.maximized > decoration-overlay, window.background.csd.unified.fullscreen > decoration-overlay {
  box-shadow: none;
}

window.background.csd.unified.tiled,
window.background.csd.unified.tiled > decoration,
window.background.csd.unified.tiled > decoration-overlay, window.background.csd.unified.tiled-top,
window.background.csd.unified.tiled-top > decoration,
window.background.csd.unified.tiled-top > decoration-overlay, window.background.csd.unified.tiled-right,
window.background.csd.unified.tiled-right > decoration,
window.background.csd.unified.tiled-right > decoration-overlay, window.background.csd.unified.tiled-bottom,
window.background.csd.unified.tiled-bottom > decoration,
window.background.csd.unified.tiled-bottom > decoration-overlay, window.background.csd.unified.tiled-left,
window.background.csd.unified.tiled-left > decoration,
window.background.csd.unified.tiled-left > decoration-overlay, window.background.csd.unified.maximized,
window.background.csd.unified.maximized > decoration,
window.background.csd.unified.maximized > decoration-overlay, window.background.csd.unified.fullscreen,
window.background.csd.unified.fullscreen > decoration,
window.background.csd.unified.fullscreen > decoration-overlay {
  border-radius: 0;
}

window.background.csd.unified > deck > .view > notebook > header.top {
  border-radius: 0;
}

/*********
 * Tilix *
 *********/
overlay > revealer.left > scrolledwindow.frame, overlay > revealer.right > scrolledwindow.frame {
  border-style: none;
  box-shadow: 0 8px 6px -5px rgba(0, 0, 0, 0.2), 0 16px 16px 2px rgba(0, 0, 0, 0.14), 0 6px 18px 5px rgba(0, 0, 0, 0.12);
}

overlay > revealer.left > scrolledwindow.frame {
  margin-right: 32px;
}

overlay > revealer.right > scrolledwindow.frame {
  margin-left: 32px;
}

.terminix-session-sidebar,
.tilix-session-sidebar {
  background-image: image(#FFFFFF);
}

.terminal-titlebar button {
  border-radius: 0;
}

button.image-button.session-new-button {
  min-width: 32px;
}

notebook.tilix-background tab > box > stack {
  margin: -6px;
}

button.flat.tilix-small-button {
  min-height: 20px;
  min-width: 16px;
}

/**************
 * Terminator *
 **************/
.terminator-terminal-window paned > separator {
  background-color: #F2F2F2;
}

.terminator-terminal-window notebook.frame {
  border-style: none;
}

/*************
 * Ubitquity *
 *************/
#live_installer .menubar progressbar trough {
  border-radius: 4px;
  background-color: rgba(0, 0, 0, 0.15);
}

/***********
 * Eclipse *
 ***********/
window.background > box.vertical > scrolledwindow > widget toolbar {
  padding: 2px;
}

window.background > box.vertical > scrolledwindow > widget toolbar separator,
window.background > box.vertical > scrolledwindow > widget toolbar button {
  margin: 2px;
}

window.background > box.vertical > scrolledwindow > widget toolbar button {
  border-radius: 12px;
}

/********
 * Meld *
 ********/
notebook.meld-notebook {
  background-color: #FFFFFF;
  border-radius: 0 0 18px 18px;
}

notebook.meld-notebook > stack {
  background-color: #FFFFFF;
  border-radius: 0 0 18px 18px;
}

.meld-notebook-child {
  background-color: #FFFFFF;
  border-radius: 0 0 18px 18px;
}

.meld-status-bar {
  background-color: transparent;
}

.meld-status-bar button {
  border-radius: 0;
}

/************
 * Chromium *
 ************/
window.background.chromium {
  background-color: #FFFFFF;
}

window.background.chromium entry,
window.background.chromium > button {
  border: 1px solid #dedede;
}

window.background.chromium > button {
  color: #1A73E8;
}

window.background.chromium > button:disabled {
  color: rgba(0, 0, 0, 0.26);
}

window.background.chromium menubar, window.background.chromium headerbar {
  color: rgba(0, 0, 0, 0.6);
}

window.background.chromium menu {
  padding: 0;
  border: 1px solid rgba(0, 0, 0, 0.12);
  box-shadow: none;
}

window.background.chromium menu menuitem {
  border-radius: 0;
}

window.background.chromium headerbar {
  padding: 0 12px;
}

window.background.chromium spinner {
  color: #1A73E8;
}

window.background.chromium textview.view {
  background-color: transparent;
}

window.background.chromium treeview.view.cell:selected:focus {
  background-color: #1A73E8;
  color: white;
}

window.background.chromium treeview.view button {
  border: 1px solid rgba(0, 0, 0, 0.26);
  background-color: #FFFFFF;
}

tooltip.background.chromium {
  color: white;
  background-color: #343434;
}

/***********
 * Firefox *
 ***********/
#MozillaGtkWidget > widget text {
  background-color: #FFFFFF;
}

#MozillaGtkWidget > widget text:selected {
  background-color: #1A73E8;
  color: white;
}

#MozillaGtkWidget > widget > separator {
  color: #dedede;
}

#MozillaGtkWidget > widget > scrollbar {
  background-clip: border-box;
}

#MozillaGtkWidget > widget > frame > border {
  border-color: #dedede;
}

#MozillaGtkWidget > widget > entry,
#MozillaGtkWidget > widget > button > button {
  border: 1px solid #dedede;
  border-radius: 12px;
  box-shadow: none;
}

#MozillaGtkWidget > widget > entry:disabled,
#MozillaGtkWidget > widget > button > button:disabled {
  border-color: rgba(0, 0, 0, 0.15);
}

#MozillaGtkWidget > widget > entry {
  min-height: 30px;
  background-color: #FFFFFF;
}

#MozillaGtkWidget > widget > entry:focus {
  border-color: #1A73E8;
  box-shadow: inset 0 0 0 1px #1A73E8;
}

#MozillaGtkWidget > widget > entry:disabled {
  background-color: #FAFAFA;
}

#MozillaGtkWidget > widget > button > button {
  padding: 4px 8px;
  background-size: auto;
}

#MozillaGtkWidget > widget > button > button:hover {
  box-shadow: inset 0 0 0 9999px alpha(currentColor, 0.08);
}

#MozillaGtkWidget > widget > button > button:active {
  background-image: image(alpha(currentColor, 0.12));
}

#MozillaGtkWidget > widget > checkbutton > check,
#MozillaGtkWidget > widget > radiobutton > radio {
  margin: 0;
  padding: 0;
}

#MozillaGtkWidget > widget > checkbutton > check:not(:checked):not(:indeterminate),
#MozillaGtkWidget > widget > radiobutton > radio:not(:checked):not(:indeterminate) {
  color: #464646;
}

#MozillaGtkWidget > widget > checkbutton > check:not(:checked):not(:indeterminate):hover, #MozillaGtkWidget > widget > checkbutton > check:not(:checked):not(:indeterminate):active,
#MozillaGtkWidget > widget > radiobutton > radio:not(:checked):not(:indeterminate):hover,
#MozillaGtkWidget > widget > radiobutton > radio:not(:checked):not(:indeterminate):active {
  color: #727272;
}

#MozillaGtkWidget > widget > checkbutton > check:not(:checked):not(:indeterminate):disabled,
#MozillaGtkWidget > widget > radiobutton > radio:not(:checked):not(:indeterminate):disabled {
  color: rgba(70, 70, 70, 0.5);
}

#MozillaGtkWidget menu {
  border: none;
}

#MozillaGtkWidget > widget > menubar {
  color: rgba(0, 0, 0, 0.6);
}

#MozillaGtkWidget > widget > menubar:hover {
  color: rgba(0, 0, 0, 0.87);
}

#MozillaGtkWidget > widget > menubar:disabled {
  color: rgba(0, 0, 0, 0.26);
}

#MozillaGtkWidget > widget > frame {
  color: #dedede;
}

#MozillaGtkWidget menu > separator {
  color: #dedede;
}

window.background:not(.csd) > window > menu menuitem {
  transition: none;
}

.background.popup.xapp-status-icon-menu-window decoration {
  border-radius: 11px;
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12);
}

/************
 * Inkscape *
 ************/
#ToolboxCommon > #AuxToolbox #StyleSwatch {
  font-size: smaller;
}

#ToolboxCommon > #AuxToolbox #Kludge {
  padding: 0;
}

#ToolboxCommon > #AuxToolbox spinbutton,
#ToolboxCommon > #AuxToolbox entry {
  min-height: 32px;
}

#ToolboxCommon > #AuxToolbox button:not(.up):not(.down) {
  min-height: 24px;
  min-width: 16px;
  padding: 4px 8px;
  border-radius: 12px;
}

#ToolboxCommon > #AuxToolbox spinbutton button {
  border-width: 4px;
}

#ToolboxCommon > toolbar.vertical {
  margin-top: -4px;
}

#ToolboxCommon > toolbar.vertical button {
  min-height: 24px;
  min-width: 24px;
  padding: 4px;
  border-radius: 12px;
}

#CanvasTable button {
  min-height: 16px;
  min-width: 16px;
  padding: 0;
}

#CanvasTable #HorizontalScrollbar {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

#CanvasTable #VerticalScrollbar:dir(ltr) {
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

#CanvasTable #VerticalScrollbar:dir(rtl) {
  border-right: 1px solid rgba(0, 0, 0, 0.12);
}

#Canvas_and_Dock frame > border {
  border: none;
}

#Canvas_and_Dock widget > widget > button.flat {
  min-height: 16px;
  min-width: 16px;
  padding: 4px;
}

#Canvas_and_Dock widget > widget > box.horizontal image {
  padding: 4px;
}

#Canvas_and_Dock box.horizontal > box.vertical > button.flat {
  min-height: 16px;
  min-width: 24px;
  padding: 8px 4px;
}

/***********
 * Synapse *
 ***********/
/*********
 * Pamac *
 *********/
window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > list,
window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > scrolledwindow > viewport.frame > list,
window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > revealer > stack > box.vertical > stack > scrolledwindow > viewport.frame > list {
  border: none;
  border-radius: 0;
}

window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > box.vertical > stack > scrolledwindow > viewport.frame > list {
  border: none;
  border-radius: 0;
}

window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > box.vertical > stack > scrolledwindow > viewport.frame > list > row.activatable:first-child, window.background.csd > box.vertical > overlay > stack > box.vertical > box.horizontal > box.vertical > stack > scrolledwindow > viewport.frame > list > row.activatable:last-child {
  border-radius: 0;
}

window.background.csd > box.vertical > overlay > stack > scrolledwindow.frame {
  border: none;
}

window.background.csd > box.vertical > overlay > stack > scrolledwindow.frame > viewport.frame > box.vertical > stack > scrolledwindow {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

window.background:not(.solid-csd):not(.csd) > grid.horizontal > grid.horizontal {
  box-shadow: inset 0 -1px rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
}

window.background:not(.solid-csd):not(.csd) > grid.horizontal > widget > widget viewport.frame > box > box > box > grid toolbar {
  background: none;
  border: none;
  padding: 3px;
}

window.background:not(.solid-csd):not(.csd) > grid.horizontal > widget > widget > scrolledwindow > viewport.frame {
  background: #FFFFFF;
}

window.background:not(.solid-csd):not(.csd) > grid.horizontal > widget > widget > scrolledwindow > viewport.frame > grid > box.horizontal {
  background: #FFFFFF;
}

window.background:not(.solid-csd):not(.csd) > grid.horizontal > widget > widget > scrolledwindow > viewport.frame > grid > box.horizontal > box.vertical > toolbar {
  background: #FFFFFF;
}

window.background:not(.solid-csd):not(.csd) > grid.horizontal > widget > widget > scrolledwindow > viewport.frame > grid > box.vertical > toolbar {
  background: none;
  border: none;
  padding: 6px;
}

window.background:not(.solid-csd):not(.csd) > grid.horizontal > widget > widget > scrolledwindow > viewport.frame > grid > box.horizontal > #combobox.linked,
window.background:not(.solid-csd):not(.csd) > grid.horizontal > widget > widget > scrolledwindow > viewport.frame > grid > box.horizontal > grid.horizontal > box.horizontal {
  background: #FFFFFF;
}

window.background:not(.solid-csd):not(.csd) > grid.horizontal > widget > widget toolbar.small-button {
  border: none;
}

window.background:not(.solid-csd):not(.csd) > notebook:not(.frame) {
  border: 1px solid rgba(0, 0, 0, 0.12);
  border-left: none;
  border-right: none;
  background-color: #FFFFFF;
  box-shadow: none;
}

window.background:not(.solid-csd):not(.csd) > notebook:not(.frame) > stack {
  border: none;
  box-shadow: none;
  background-color: #FFFFFF;
}

window.background:not(.solid-csd):not(.csd) > notebook:not(.frame) > header {
  box-shadow: none;
  margin: 0;
  border: none;
  background-color: transparent;
}

window.background:not(.solid-csd):not(.csd) > notebook:not(.frame) > header > tabs > tab {
  margin: 3px 0 0;
}

#gtk-combobox-popup-window scrolledwindow.frame {
  border: none;
}

#gtk-combobox-popup-window treeview.view:selected, #gtk-combobox-popup-window treeview.view:hover {
  background-image: image(#1A73E8);
}

#gtk-combobox-popup-window treeview.view:selected, #gtk-combobox-popup-window treeview.view:selected label, #gtk-combobox-popup-window treeview.view:hover, #gtk-combobox-popup-window treeview.view:hover label {
  color: white;
}

stack > scrolledwindow > viewport > box > box > box > frame.view, stack > scrolledwindow > viewport > box > box > box > frame.view > border,
stack > scrolledwindow > viewport > box > stack > box > revealer > box > box > frame.view,
stack > scrolledwindow > viewport > box > stack > box > revealer > box > box > frame.view > border,
stack > scrolledwindow > viewport > box > stack > box > stack > box > box > frame.view,
stack > scrolledwindow > viewport > box > stack > box > stack > box > box > frame.view > border,
stack > scrolledwindow > viewport > box > revealer > box > stack > box > box > frame.view,
stack > scrolledwindow > viewport > box > revealer > box > stack > box > box > frame.view > border {
  border-radius: 12px;
}

stack > scrolledwindow > viewport > box > box > box > frame.view > box > box > list,
stack > scrolledwindow > viewport > box > stack > box > revealer > box > box > frame.view > box > box > list,
stack > scrolledwindow > viewport > box > stack > box > stack > box > box > frame.view > box > box > list,
stack > scrolledwindow > viewport > box > revealer > box > stack > box > box > frame.view > box > box > list {
  background-color: transparent;
}

stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:first-child > list, stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:first-child > list > row,
stack > scrolledwindow > viewport > box > stack > box > revealer > box > box > frame.view > box > box:first-child > list,
stack > scrolledwindow > viewport > box > stack > box > revealer > box > box > frame.view > box > box:first-child > list > row,
stack > scrolledwindow > viewport > box > stack > box > stack > box > box > frame.view > box > box:first-child > list,
stack > scrolledwindow > viewport > box > stack > box > stack > box > box > frame.view > box > box:first-child > list > row,
stack > scrolledwindow > viewport > box > revealer > box > stack > box > box > frame.view > box > box:first-child > list,
stack > scrolledwindow > viewport > box > revealer > box > stack > box > box > frame.view > box > box:first-child > list > row {
  border-radius: 12px 12px 0 0;
}

stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:last-child > list, stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:last-child > list > row,
stack > scrolledwindow > viewport > box > stack > box > revealer > box > box > frame.view > box > box:last-child > list,
stack > scrolledwindow > viewport > box > stack > box > revealer > box > box > frame.view > box > box:last-child > list > row,
stack > scrolledwindow > viewport > box > stack > box > stack > box > box > frame.view > box > box:last-child > list,
stack > scrolledwindow > viewport > box > stack > box > stack > box > box > frame.view > box > box:last-child > list > row,
stack > scrolledwindow > viewport > box > revealer > box > stack > box > box > frame.view > box > box:last-child > list,
stack > scrolledwindow > viewport > box > revealer > box > stack > box > box > frame.view > box > box:last-child > list > row {
  border-radius: 0 0 12px 12px;
}

stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:only-child > list, stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:only-child > list > row,
stack > scrolledwindow > viewport > box > stack > box > revealer > box > box > frame.view > box > box:only-child > list,
stack > scrolledwindow > viewport > box > stack > box > revealer > box > box > frame.view > box > box:only-child > list > row,
stack > scrolledwindow > viewport > box > stack > box > stack > box > box > frame.view > box > box:only-child > list,
stack > scrolledwindow > viewport > box > stack > box > stack > box > box > frame.view > box > box:only-child > list > row,
stack > scrolledwindow > viewport > box > revealer > box > stack > box > box > frame.view > box > box:only-child > list,
stack > scrolledwindow > viewport > box > revealer > box > stack > box > box > frame.view > box > box:only-child > list > row {
  border-radius: 12px;
}

stack > scrolledwindow > viewport > box > box > box > frame.view, stack > scrolledwindow > viewport > box > box > box > frame.view > border,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > border,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > border {
  border-radius: 12px;
}

stack > scrolledwindow > viewport > box > box > box > frame.view > box > box > list,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > box > list,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > box > list {
  background-color: transparent;
}

stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:first-child > list, stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:first-child > list > row,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > box:first-child > list,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > box:first-child > list > row,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > box:first-child > list,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > box:first-child > list > row {
  border-radius: 12px 12px 0 0;
}

stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:last-child > list, stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:last-child > list > row,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > box:last-child > list,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > box:last-child > list > row,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > box:last-child > list,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > box:last-child > list > row {
  border-radius: 0 0 12px 12px;
}

stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:only-child > list, stack > scrolledwindow > viewport > box > box > box > frame.view > box > box:only-child > list > row,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > box:only-child > list,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > box:only-child > list > row,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > box:only-child > list,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > box:only-child > list > row {
  border-radius: 12px;
}

stack > scrolledwindow > viewport > box > box > box > frame.view > box > revealer > box > box > list,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > revealer > box > box > list,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > revealer > box > box > list {
  background-color: transparent;
}

stack > scrolledwindow > viewport > box > box > box > frame.view > box > revealer:first-child > box > box > list, stack > scrolledwindow > viewport > box > box > box > frame.view > box > revealer:first-child > box > box > list > row,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > revealer:first-child > box > box > list,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > revealer:first-child > box > box > list > row,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > revealer:first-child > box > box > list,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > revealer:first-child > box > box > list > row {
  border-radius: 12px 12px 0 0;
}

stack > scrolledwindow > viewport > box > box > box > frame.view > box > revealer:last-child > box > box > list, stack > scrolledwindow > viewport > box > box > box > frame.view > box > revealer:last-child > box > box > list > row,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > revealer:last-child > box > box > list,
stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > revealer:last-child > box > box > list > row,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > revealer:last-child > box > box > list,
stack > scrolledwindow > viewport > box > box > revealer > box > box > frame.view > box > revealer:last-child > box > box > list > row {
  border-radius: 0 0 12px 12px;
}

stack > scrolledwindow > viewport > box > box > widget > overlay > scrolledwindow > viewport > grid > box > frame, stack > scrolledwindow > viewport > box > box > widget > overlay > scrolledwindow > viewport > grid > box > frame > border {
  border-radius: 12px;
}

stack > scrolledwindow > viewport > box > box > widget > overlay > scrolledwindow > viewport > grid > box > frame > list {
  border-radius: 12px;
}

stack > scrolledwindow > viewport > box > box > widget > overlay > scrolledwindow > viewport > grid > box > frame > list > row:first-child {
  border-radius: 12px 12px 0 0;
}

stack > scrolledwindow > viewport > box > box > widget > overlay > scrolledwindow > viewport > grid > box > frame > list > row:last-child {
  border-radius: 0 0 12px 12px;
}

stack > scrolledwindow > viewport > box > stack > box > box > frame.view, stack > scrolledwindow > viewport > box > stack > box > box > frame.view > border {
  border-radius: 12px;
}

stack > scrolledwindow > viewport > box > stack > box > box > frame.view frame.view {
  background-color: transparent;
}

stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > scrolledwindow > viewport.frame > box > list {
  border-radius: 12px;
}

stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > scrolledwindow > viewport.frame > box > list > row:first-child {
  border-radius: 12px 12px 0 0;
}

stack > scrolledwindow > viewport > box > stack > box > box > frame.view > box > scrolledwindow > viewport.frame > box > list > row:last-child {
  border-radius: 0 0 12px 12px;
}

stack > scrolledwindow > viewport > box > widget > box > frame.view, stack > scrolledwindow > viewport > box > widget > box > frame.view > border,
stack > scrolledwindow > viewport > box > widget > box > frame.view > widget > box > box > list {
  border-radius: 12px;
}

stack > scrolledwindow > viewport > box #c_box notebook {
  background-color: transparent;
}

#workspaces button {
  min-width: 20px;
}

window.background:not(.csd):not(.solid-csd) > button:not(:hover):not(:active):not(:checked):not(:disabled):not(.flat) {
  background-color: #FAFAFA;
}

/*********
 * Unity *
 *********/
UnityDecoration {
  -UnityDecoration-extents: 28px 0 0 0;
  -UnityDecoration-input-extents: 8px;
  -UnityDecoration-shadow-offset-x: 0;
  -UnityDecoration-shadow-offset-y: 3px;
  -UnityDecoration-active-shadow-color: rgba(0, 0, 0, 0.48);
  -UnityDecoration-active-shadow-radius: 18px;
  -UnityDecoration-inactive-shadow-color: rgba(0, 0, 0, 0.32);
  -UnityDecoration-inactive-shadow-radius: 6px;
  -UnityDecoration-glow-size: 8px;
  -UnityDecoration-glow-color: #1A73E8;
  -UnityDecoration-title-indent: 4px;
  -UnityDecoration-title-fade: 32px;
  -UnityDecoration-title-alignment: 0.0;
}

UnityDecoration .top {
  padding: 0 2px;
  border-style: none;
  border-radius: 18px 18px 0 0;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
  color: rgba(0, 0, 0, 0.87);
}

UnityDecoration .top:backdrop {
  background-color: #FAFAFA;
  color: rgba(0, 0, 0, 0.6);
}

UnityDecoration .menuitem {
  color: rgba(0, 0, 0, 0.6);
}

UnityDecoration .menuitem:hover {
  box-shadow: inset 0 -2px #1A73E8;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.87);
}

.background:not(.csd) headerbar:not(.titlebar) {
  border-radius: 0;
  box-shadow: 0 2px 2px -2px rgba(0, 0, 0, 0.3), 0 1px 2px -1px rgba(0, 0, 0, 0.24), 0 1px 2px -1px rgba(0, 0, 0, 0.17);
}

.background:not(.csd) headerbar:not(.titlebar).inline-toolbar {
  border-style: none;
}

UnityPanelWidget,
.unity-panel {
  background-color: #F2F2F2;
  color: rgba(0, 0, 0, 0.87);
}

UnityPanelWidget:backdrop,
.unity-panel:backdrop {
  color: rgba(0, 0, 0, 0.6);
}

.unity-panel.menuitem,
.unity-panel .menuitem {
  color: rgba(0, 0, 0, 0.6);
}

.unity-panel.menubar.menuitem:hover,
.unity-panel.menubar .menuitem *:hover {
  box-shadow: inset 0 -2px #1A73E8;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.87);
}

.menu IdoPlaybackMenuItem.menuitem:active {
  -gtk-icon-source: -gtk-icontheme("process-working-symbolic");
  animation: spin 1s linear infinite;
  color: #1A73E8;
}

/**************
 * Mate-Panel *
 **************/
.mate-panel-menu-bar menubar,
#PanelApplet-window-menu-applet-button {
  background-color: transparent;
}

.mate-panel-menu-bar {
  background-color: rgba(242, 242, 242, 0.65);
  color: rgba(0, 0, 0, 0.6);
  font-weight: 500;
  box-shadow: none;
}

.mate-panel-menu-bar button {
  min-height: 16px;
  min-width: 16px;
  padding: 0;
  border-radius: 0;
}

PanelToplevel.horizontal > grid > button {
  min-width: 24px;
}

PanelToplevel.vertical > grid > button {
  min-height: 24px;
}

PanelSeparator {
  color: rgba(0, 0, 0, 0.12);
}

MatePanelAppletFrameDBus {
  border-style: solid;
  border-color: rgba(0, 0, 0, 0.12);
}

.mate-panel-menu-bar.horizontal MatePanelAppletFrameDBus {
  border-width: 0 1px;
}

.mate-panel-menu-bar.vertical MatePanelAppletFrameDBus {
  border-width: 1px 0;
}

.mate-panel-menu-bar menubar {
  box-shadow: none;
}

.mate-panel-menu-bar menubar > menuitem {
  color: rgba(0, 0, 0, 0.6);
}

.mate-panel-menu-bar menubar > menuitem:hover {
  color: rgba(0, 0, 0, 0.87);
}

.mate-panel-menu-bar menubar > menuitem:disabled {
  color: rgba(0, 0, 0, 0.26);
}

.mate-panel-menu-bar.horizontal menubar > menuitem {
  padding: 0 8px;
}

.mate-panel-menu-bar.vertical menubar > menuitem {
  padding: 8px 0;
}

.mate-panel-menu-bar menubar menu > menuitem {
  min-height: 28px;
  padding: 0 6px;
}

.mate-panel-menu-bar #PanelApplet button {
  -GtkWidget-window-dragging: true;
}

.mate-panel-menu-bar #tasklist-button {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 0%, transparent 0%) 0 0 0/0 0 0px;
}

.mate-panel-menu-bar #tasklist-button:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 100%, transparent 0%) 0 0 2/0 0 2px;
}

.mate-panel-menu-bar #tasklist-button image:dir(ltr), .mate-panel-menu-bar #tasklist-button label:dir(rtl) {
  padding-left: 4px;
}

.mate-panel-menu-bar #tasklist-button label:dir(ltr), .mate-panel-menu-bar #tasklist-button image:dir(rtl) {
  padding-right: 4px;
}

.mate-panel-menu-bar.vertical #tasklist-button {
  min-height: 32px;
}

.mate-panel-menu-bar.horizontal #showdesktop-button image {
  min-width: 24px;
  padding: 0 4px;
}

.mate-panel-menu-bar.vertical #showdesktop-button image {
  min-height: 24px;
  padding: 4px 0;
}

PanelApplet.wnck-applet .wnck-pager {
  background-color: transparent;
  color: #1A73E8;
}

PanelApplet.wnck-applet .wnck-pager:hover {
  background-color: alpha(currentColor, 0.08);
}

PanelApplet.wnck-applet .wnck-pager:active {
  background-color: alpha(currentColor, 0.12);
}

PanelApplet.wnck-applet .wnck-pager:selected {
  background-color: #1A73E8;
}

.mate-panel-menu-bar.horizontal #clock-applet-button label {
  padding: 0 8px;
}

.mate-panel-menu-bar.vertical #clock-applet-button label {
  padding: 8px 0;
}

#MatePanelPopupWindow {
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-radius: 13px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

#MatePanelPopupWindow frame > border {
  border-style: none;
}

#MatePanelPopupWindow calendar {
  border-style: none;
}

#MatePanelPopupWindow calendar:not(:selected) {
  background-color: transparent;
}

#MatePanelPopupWindow calendar + box {
  margin-top: -5px;
  padding-top: 5px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

#MatePanelPopupWindow expander > title {
  min-height: 32px;
}

#MatePanelPopupWindow button {
  padding: 4px 16px;
}

#MatePanelPopupWindow > frame > box > box > box > widget {
  color: rgba(0, 0, 0, 0.12);
}

na-tray-applet {
  -NaTrayApplet-icon-padding: 3px;
  -NaTrayApplet-icon-size: 16;
}

.mate-panel-menu-bar {
  -PanelMenuBar-icon-visible: true;
}

.mate-panel-applet-slider {
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-radius: 13px;
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

.mate-panel-applet-slider frame > border {
  border-style: none;
}

#PanelApplet:not(:selected) > box {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
}

#PanelApplet:selected > box {
  background-color: alpha(currentColor, 0.1);
  color: rgba(0, 0, 0, 0.87);
}

#mate-menu {
  border: 1px solid rgba(0, 0, 0, 0.1);
  background-color: #FFFFFF;
}

#mate-menu button {
  min-height: 24px;
  min-width: 24px;
  padding: 4px 0;
  color: rgba(0, 0, 0, 0.87);
  font-weight: normal;
}

#mate-menu button:not(.flat) {
  background-color: alpha(currentColor, 0.1);
}

#mate-menu button image,
#mate-menu button label + label {
  color: rgba(0, 0, 0, 0.6);
}

#mate-menu entry {
  margin: 0 0 4px;
}

#mate-menu entry image {
  margin: 0;
}

#mate-menu entry + button {
  margin: 0 4px 4px;
  padding: 6px;
}

.brisk-menu {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

.brisk-menu entry {
  margin-bottom: -2px;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  border-image: none;
  box-shadow: none;
  background-color: transparent;
}

.brisk-menu entry + box > box:dir(ltr) {
  margin-right: -2px;
  border-right: 1px solid rgba(0, 0, 0, 0.12);
}

.brisk-menu entry + box > box:dir(rtl) {
  margin-left: -2px;
  border-left: 1px solid rgba(0, 0, 0, 0.12);
}

.brisk-menu .categories-list {
  padding-top: 4px;
}

.brisk-menu .categories-list button {
  margin: 0 4px;
}

.brisk-menu .categories-list button:checked {
  color: #1A73E8;
}

.brisk-menu .session-button {
  padding: 12px;
}

.brisk-menu .frame {
  border-style: none;
}

.brisk-menu .apps-list {
  padding: 4px 0;
  background-color: transparent;
}

.brisk-menu .apps-list row {
  padding: 0;
}

.brisk-menu .apps-list row:hover {
  box-shadow: none;
}

.brisk-menu .apps-list button {
  border-radius: 0;
  color: rgba(0, 0, 0, 0.87);
  font-weight: normal;
}

/*********************
 * CAJA File manager *
 *********************/
.caja-navigation-window button.toggle.image-button {
  border-radius: 12px;
}

.caja-pathbar button {
  margin: 0 -1px 0 -2px;
}

.caja-pathbar button.slider-button {
  min-width: 24px;
}

.caja-pathbar button > widget {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  -GtkArrow-arrow-scaling: 1;
}

.caja-side-pane notebook viewport.frame,
.caja-side-pane notebook widget .vertical {
  background-color: #FFFFFF;
}

.caja-side-pane notebook,
.caja-notebook {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.caja-side-pane notebook .frame,
.caja-notebook .frame {
  border-style: none;
}

.caja-canvas-item {
  border-radius: 12px;
}

.caja-desktop.view .entry,
.caja-navigation-window .view .entry {
  border: none;
  border-radius: 12px;
  background-color: rgba(0, 0, 0, 0.04);
  background-image: none;
  color: rgba(0, 0, 0, 0.87);
}

.caja-desktop.view .entry:selected,
.caja-navigation-window .view .entry:selected {
  background-color: alpha(currentColor, 0.06);
}

.caja-desktop.view .entry {
  background-color: #2C2C2C;
  color: white;
  text-shadow: 0 1px 1px rgba(0, 0, 0, 0.2), 0 1px 2px rgba(0, 0, 0, 0.14), 0 1px 3px rgba(0, 0, 0, 0.12);
  caret-color: currentColor;
}

.caja-desktop.view .entry:selected {
  background-color: alpha(currentColor, 0.06);
}

.caja-navigation-window statusbar {
  margin: 0 -10px;
  padding: 0 4px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.caja-notebook frame > border {
  border-style: none;
}

#caja-extra-view-widget {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
}

#caja-extra-view-widget > box > box > label {
  font-weight: bold;
}

/*********
 * Pluma *
 *********/
.pluma-window statusbar {
  margin: 0 -10px;
  padding: 0 4px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.pluma-window statusbar frame > border {
  border-style: none;
}

.pluma-window statusbar frame button.flat {
  padding: 0 4px;
  border-radius: 0;
}

.pluma-window statusbar frame button.flat widget {
  -gtk-icon-source: -gtk-icontheme("pan-down-symbolic");
  -GtkArrow-arrow-scaling: 1;
}

.pluma-print-preview toolbar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

.pluma-window paned.horizontal box.vertical box.horizontal button.flat {
  margin: 1px;
}

.pluma-window paned.horizontal box.vertical .frame {
  border-style: none;
}

.pluma-window paned.horizontal box.vertical notebook.frame {
  margin-top: -1px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.pluma-window paned.horizontal box.vertical notebook.frame box.vertical toolbar.horizontal {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

/*********
 * Atril *
 *********/
.atril-window paned.horizontal box.vertical .frame {
  border-style: none;
}

.atril-window paned.horizontal box.vertical notebook .frame {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

/* mate-screensaver lock dialog */
.lock-dialog {
  border: 1px solid rgba(0, 0, 0, 0.1);
  border-radius: 13px;
  box-shadow: 0 3px 3px -1px rgba(0, 0, 0, 0.2), 0 6px 6px 0 rgba(0, 0, 0, 0.14), 0 1px 11px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

.lock-dialog frame > border {
  border-style: none;
}

.lock-dialog button:not(:disabled) {
  color: #1A73E8;
}

/* multimedia OSD */
MsdOsdWindow.background.osd {
  border-radius: 12px;
  background-color: rgba(52, 52, 52, 0.9);
  color: white;
}

MsdOsdWindow.background.osd .trough {
  border-radius: 0;
  background-color: rgba(255, 255, 255, 0.15);
}

MsdOsdWindow.background.osd .progressbar {
  border-radius: 0;
  background-color: #1A73E8;
}

/******************
 * Budgie Desktop *
 ******************/
.budgie-container {
  background-color: transparent;
}

.budgie-popover {
  border: none;
  border-radius: 12px;
  box-shadow: 0 3px 3px -2px rgba(0, 0, 0, 0.2), 0 3px 3px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
  border-color: #FFFFFF;
}

.budgie-popover > .container {
  padding: 6px;
}

.budgie-popover > .container .container {
  padding: 0;
}

.budgie-popover separator {
  margin: 3px 0;
}

.budgie-popover border {
  border: none;
}

.budgie-popover list {
  background-color: transparent;
}

.budgie-popover entry, .budgie-popover button, .budgie-popover spinbutton, .budgie-popover button.combo {
  border-radius: 5px;
}

.budgie-popover .linked > entry:first-child,
.budgie-popover .linked > button:first-child {
  border-top-left-radius: 5px;
  border-bottom-left-radius: 5px;
}

.budgie-popover .linked > entry:last-child,
.budgie-popover .linked > button:last-child {
  border-top-right-radius: 5px;
  border-bottom-right-radius: 5px;
}

.budgie-popover button.flat:not(.image-button) {
  min-height: 28px;
  padding: 0 8px;
  color: rgba(0, 0, 0, 0.87);
  font-weight: normal;
  border-radius: 5px;
}

.budgie-popover button.flat:not(.image-button):disabled {
  color: rgba(0, 0, 0, 0.38);
}

.budgie-popover row {
  padding: 0;
}

.budgie-popover row:hover {
  box-shadow: none;
}

.budgie-popover row button {
  border-radius: 5px;
}

.budgie-popover calendar:not(.header) {
  border-radius: 5px;
}

.budgie-popover scrolledwindow.sidebar.categories {
  background-color: rgba(0, 0, 0, 0.04);
}

.budgie-popover scrolledwindow.sidebar.categories button.category-button {
  border-radius: 0;
}

.budgie-popover treeview.view.sidebar {
  background: none;
  border-right: none;
  color: rgba(0, 0, 0, 0.87);
  padding: 3px;
}

.budgie-popover treeview.view.sidebar:hover {
  background-color: alpha(currentColor, 0.08);
}

.budgie-popover treeview.view.sidebar:selected {
  background-color: alpha(currentColor, 0.12);
}

.budgie-popover scrolledwindow.sidebar:not(.categories) {
  border-right: none;
  background: none;
}

.budgie-popover scrolledwindow.sidebar:not(.categories) list {
  background-color: rgba(0, 0, 0, 0.04);
  border-radius: 6px;
  padding: 3px;
}

.budgie-popover scrolledwindow.sidebar:not(.categories) list > row.activatable {
  border-radius: 3px;
  padding: 6px 8px;
}

.budgie-popover scrolledwindow.sidebar + separator {
  background-color: transparent;
  min-width: 0;
  min-height: 0;
}

.budgie-popover scrolledwindow.sidebar + separator + scrolledwindow {
  margin-left: 3px;
}

.budgie-popover scrolledwindow.sidebar + separator + scrolledwindow list > row.activatable {
  border-radius: 6px;
}

.budgie-popover.budgie-menu .container {
  padding: 0;
}

.budgie-popover.budgie-menu .sidebar,
.budgie-popover.budgie-menu scrollbar,
.budgie-popover.budgie-menu entry.search {
  background-color: transparent;
}

.budgie-popover.budgie-menu entry.search {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
  border-image: none;
  border-radius: 0;
  box-shadow: none;
  font-size: 120%;
}

.budgie-popover.budgie-menu row.activatable > button.flat {
  min-height: 32px;
  padding: 0 8px;
  border-radius: 0;
}

.budgie-popover.budgie-menu row.activatable > button.flat:checked:disabled {
  background-color: transparent;
}

.budgie-popover.budgie-menu list.left-overlay-menu {
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
  padding: 6px;
  margin: 6px;
  border-radius: 11px;
}

.budgie-popover.budgie-menu list.left-overlay-menu > row.activatable {
  border-radius: 5px;
}

.budgie-popover.budgie-menu list.left-overlay-menu > row.activatable:not(:last-child) {
  margin-bottom: 3px;
}

.budgie-popover.budgie-menu list.left-overlay-menu > row.activatable button.menuitem {
  border-radius: 5px;
}

.budgie-popover.budgie-menu .budgie-menu-footer {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  padding: 6px;
}

.budgie-popover.budgie-menu .budgie-menu-footer button.flat {
  min-height: 16px;
  min-width: 16px;
  padding: 6px;
  border-radius: 5px;
}

.budgie-popover.budgie-menu .budgie-menu-footer button.flat.image-button {
  border-radius: 9999px;
}

.budgie-popover.budgie-menu .budgie-menu-footer button.flat.image-button:not(.last-child) {
  margin-right: 6px;
}

.budgie-popover.user-menu list,
.budgie-popover.user-menu row {
  border: none;
  background: none;
  box-shadow: none;
}

.budgie-popover.user-menu > frame.container > box.vertical row.activatable:first-child {
  margin-bottom: 3px;
  outline-width: 0;
  border-radius: 12px;
}

.budgie-popover.user-menu > frame.container > box.vertical row.activatable:first-child button.indicator-item {
  transition: none;
  animation: none;
}

.budgie-popover.sound-popover .container {
  padding: 0;
}

.budgie-popover.sound-popover separator {
  margin: 3px 0;
}

.budgie-popover.night-light-indicator .container {
  padding: 3px;
}

.budgie-popover.night-light-indicator .view-header {
  margin: 0 6px;
}

.budgie-popover.places-menu .container {
  padding: 3px;
}

.budgie-popover.places-menu .name-button image:dir(ltr) {
  margin-right: 3px;
}

.budgie-popover.places-menu .name-button image:dir(rtl) {
  margin-left: 3px;
}

.budgie-popover.places-menu .unmount-button {
  margin: 2px;
  padding: 0;
}

.budgie-popover.places-menu .places-list:not(.always-expand) {
  margin-top: 3px;
  padding-top: 3px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.budgie-popover.places-menu .alternative-label {
  padding: 3px;
  font-size: 15px;
}

.budgie-popover.workspace-popover flowboxchild {
  padding: 0;
}

.workspace-switcher .workspace-layout {
  border: 0 solid rgba(0, 0, 0, 0.12);
}

.top .workspace-switcher .workspace-layout:dir(ltr), .bottom .workspace-switcher .workspace-layout:dir(ltr) {
  border-left-width: 1px;
}

.top .workspace-switcher .workspace-layout:dir(rtl), .bottom .workspace-switcher .workspace-layout:dir(rtl) {
  border-right-width: 1px;
}

.left .workspace-switcher .workspace-layout, .right .workspace-switcher .workspace-layout {
  border-top-width: 1px;
}

.workspace-switcher .workspace-item,
.workspace-switcher .workspace-add-button {
  border: 0 solid rgba(0, 0, 0, 0.12);
}

.top .workspace-switcher .workspace-item:dir(ltr), .bottom .workspace-switcher .workspace-item:dir(ltr), .top .workspace-switcher .workspace-add-button:dir(ltr), .bottom .workspace-switcher .workspace-add-button:dir(ltr) {
  border-right-width: 1px;
}

.top .workspace-switcher .workspace-item:dir(rtl), .bottom .workspace-switcher .workspace-item:dir(rtl), .top .workspace-switcher .workspace-add-button:dir(rtl), .bottom .workspace-switcher .workspace-add-button:dir(rtl) {
  border-left-width: 1px;
}

.left .workspace-switcher .workspace-item, .right .workspace-switcher .workspace-item, .left .workspace-switcher .workspace-add-button, .right .workspace-switcher .workspace-add-button {
  border-bottom-width: 1px;
}

.workspace-switcher .workspace-item {
  transition: all 75ms cubic-bezier(0, 0, 0.2, 1);
}

.workspace-switcher .workspace-item.current-workspace {
  background-color: alpha(currentColor, 0.1);
}

.workspace-switcher .workspace-add-button:hover {
  box-shadow: none;
}

.workspace-switcher .workspace-add-button:active {
  background-image: none;
}

.workspace-switcher .workspace-add-button:active image {
  margin: 1px 0 -1px;
}

.budgie-panel .workspace-switcher .workspace-icon-button {
  min-height: 24px;
  min-width: 24px;
  padding: 0;
  border-radius: 12px;
}

.budgie-panel {
  transition: background-color 75ms cubic-bezier(0, 0, 0.2, 1);
  background-color: #F2F2F2;
  color: rgba(0, 0, 0, 0.6);
  font-weight: 500;
}

.budgie-panel.transparent {
  background-color: rgba(242, 242, 242, 0.65);
}

.bottom .budgie-panel.dock-mode {
  border-radius: 18px 18px 0 0;
}

.bottom .budgie-panel.dock-mode .icon-tasklist button.launcher:checked, .bottom .budgie-panel.dock-mode .icon-tasklist button.launcher:active {
  color: rgba(0, 0, 0, 0.87);
}

.bottom .budgie-panel.dock-mode .icon-tasklist > box > revealer:first-child > button.launcher {
  border-top-left-radius: 18px;
}

.bottom .budgie-panel.dock-mode .icon-tasklist > box > revealer:last-child > button.launcher {
  border-top-right-radius: 18px;
}

.left .budgie-panel.dock-mode {
  border-radius: 0 18px 18px 0;
}

.left .budgie-panel.dock-mode .icon-tasklist > box > revealer:first-child > button.launcher {
  border-top-right-radius: 18px;
}

.left .budgie-panel.dock-mode .icon-tasklist > box > revealer:last-child > button.launcher {
  border-bottom-right-radius: 18px;
}

.right .budgie-panel.dock-mode {
  border-radius: 18px 0 0 18px;
}

.right .budgie-panel.dock-mode .icon-tasklist > box > revealer:first-child > button.launcher {
  border-top-left-radius: 18px;
}

.right .budgie-panel.dock-mode .icon-tasklist > box > revealer:last-child > button.launcher {
  border-bottom-left-radius: 18px;
}

.budgie-panel button {
  color: rgba(0, 0, 0, 0.6);
  min-height: 24px;
  min-width: 24px;
  padding: 0;
  border-radius: 0;
}

.budgie-panel button:hover {
  color: rgba(0, 0, 0, 0.87);
}

.budgie-panel button:active {
  color: rgba(0, 0, 0, 0.6);
}

.budgie-panel button.raven-trigger {
  color: rgba(0, 0, 0, 0.6);
}

.budgie-panel.horizontal button {
  padding: 0 4px;
}

.budgie-panel.vertical button {
  padding: 4px 0;
}

.budgie-panel separator {
  background-color: rgba(0, 0, 0, 0.26);
}

.budgie-panel .alert {
  color: #1A73E8;
}

.budgie-panel .titlebar:not(headerbar) {
  min-height: 0;
  padding: 0;
  box-shadow: none;
  background-color: transparent;
  color: rgba(0, 0, 0, 0.87);
}

.budgie-panel .titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action) {
  color: rgba(0, 0, 0, 0.6);
}

.budgie-panel .titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):hover, .budgie-panel .titlebar:not(headerbar) button:not(.suggested-action):not(.destructive-action):active {
  color: rgba(0, 0, 0, 0.87);
}

.budgie-panel menubar,
.budgie-panel .menubar {
  color: rgba(0, 0, 0, 0.6);
}

.budgie-panel menubar > menuitem,
.budgie-panel .menubar > menuitem {
  color: rgba(0, 0, 0, 0.6);
}

.budgie-panel menubar > menuitem:hover, .budgie-panel menubar > menuitem:active,
.budgie-panel .menubar > menuitem:hover,
.budgie-panel .menubar > menuitem:active {
  color: rgba(0, 0, 0, 0.87);
}

.budgie-panel menubar separator,
.budgie-panel .menubar separator {
  background-color: rgba(0, 0, 0, 0.12);
}

.budgie-panel #tasklist-button {
  padding: 0 6px;
}

.budgie-panel.vertical #tasklist-button {
  min-height: 32px;
}

.budgie-panel button.flat.launcher {
  padding: 0;
}

.budgie-panel button.flat.launcher:not(:checked) {
  color: rgba(0, 0, 0, 0.38);
}

.budgie-panel button.flat.launcher:not(:checked):hover, .budgie-panel button.flat.launcher:not(:checked):active {
  color: rgba(0, 0, 0, 0.6);
}

.budgie-panel button.flat.launcher:not(:checked):disabled {
  color: rgba(0, 0, 0, 0.26);
}

.top .budgie-panel .unpinned button.flat.launcher:checked, .top .budgie-panel .pinned button.flat.launcher.running:checked {
  border-image: radial-gradient(circle closest-corner at center calc(1px), currentColor 100%, transparent 0%) 2 0 0 0/2px 0 0 0;
}

.bottom .budgie-panel .unpinned button.flat.launcher:checked, .bottom .budgie-panel .pinned button.flat.launcher.running:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 100%, transparent 0%) 0 0 2 0/0 0 2px 0;
}

.left .budgie-panel .unpinned button.flat.launcher:checked, .left .budgie-panel .pinned button.flat.launcher.running:checked {
  border-image: radial-gradient(circle closest-corner at calc(1px) center, currentColor 100%, transparent 0%) 0 0 0 2/0 0 0 2px;
}

.right .budgie-panel .unpinned button.flat.launcher:checked, .right .budgie-panel .pinned button.flat.launcher.running:checked {
  border-image: radial-gradient(circle closest-corner at calc(100% - 1px) center, currentColor 100%, transparent 0%) 0 2 0 0/0 2px 0 0;
}

.budgie-panel .lock-keys image:disabled {
  color: rgba(0, 0, 0, 0.26);
}

.budgie-panel > box > widget > widget > image,
.budgie-panel > box > widget > widget > stack > image,
.budgie-panel > box > widget > widget > box > image {
  margin-left: 6px;
  margin-right: 6px;
}

.budgie-panel > box > widget > widget > box > image + label {
  margin-left: -4px;
}

.budgie-panel > box > widget > widget > box > widget > image {
  margin-left: 6px;
}

.budgie-panel > box > widget > widget > box > stack > widget > label {
  margin-right: 6px;
}

.budgie-panel > box > widget > widget > box > widget > widget > image {
  margin-left: 3px;
  margin-right: 3px;
}

.budgie-panel .budgie-clock-applet > widget > box,
.budgie-panel .budgie-calendar-applet > widget > box {
  padding-left: 3px;
  padding-right: 3px;
}

.top .budgie-panel #tasklist-button, .budgie-panel .top #tasklist-button {
  border-image: radial-gradient(circle closest-corner at center calc(1px), currentColor 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.top .budgie-panel #tasklist-button:checked, .budgie-panel .top #tasklist-button:checked {
  border-image: radial-gradient(circle closest-corner at center calc(1px), currentColor 100%, transparent 0%) 2 0 0 0/2px 0 0 0;
}

.bottom .budgie-panel #tasklist-button, .budgie-panel .bottom #tasklist-button {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.bottom .budgie-panel #tasklist-button:checked, .budgie-panel .bottom #tasklist-button:checked {
  border-image: radial-gradient(circle closest-corner at center calc(100% - 1px), currentColor 100%, transparent 0%) 0 0 2 0/0 0 2px 0;
}

.left .budgie-panel #tasklist-button, .budgie-panel .left #tasklist-button {
  border-image: radial-gradient(circle closest-corner at calc(1px) center, currentColor 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.left .budgie-panel #tasklist-button:checked, .budgie-panel .left #tasklist-button:checked {
  border-image: radial-gradient(circle closest-corner at calc(1px) center, currentColor 100%, transparent 0%) 0 0 0 2/0 0 0 2px;
}

.right .budgie-panel #tasklist-button, .budgie-panel .right #tasklist-button {
  border-image: radial-gradient(circle closest-corner at calc(100% - 1px) center, currentColor 0%, transparent 0%) 0 0 0 0/0 0 0 0;
}

.right .budgie-panel #tasklist-button:checked, .budgie-panel .right #tasklist-button:checked {
  border-image: radial-gradient(circle closest-corner at calc(100% - 1px) center, currentColor 100%, transparent 0%) 0 2 0 0/0 2px 0 0;
}

frame.raven-frame > border {
  border-style: none;
}

.top frame.raven-frame > border {
  margin-bottom: 32px;
}

.bottom frame.raven-frame > border {
  margin-top: 32px;
}

.left frame.raven-frame > border {
  margin-right: 32px;
}

.right frame.raven-frame > border {
  margin-left: 32px;
}

.raven {
  background-color: #FFFFFF;
  box-shadow: 0 8px 6px -5px rgba(0, 0, 0, 0.2), 0 16px 16px 2px rgba(0, 0, 0, 0.14), 0 6px 18px 5px rgba(0, 0, 0, 0.12);
  margin: 8px 6px 6px;
  border-radius: 12px;
}

.raven scrollbar {
  background-color: transparent;
}

.raven stackswitcher.linked {
  margin: 6px 16px;
}

.raven stackswitcher.linked > button:focus {
  box-shadow: none;
}

.raven .raven-header {
  min-height: 36px;
  padding: 3px;
}

.raven .raven-header.top {
  padding: 0;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

.raven .raven-header.top stackswitcher button {
  padding: 0 16px;
  min-height: 36px;
}

.raven .raven-header.bottom {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.raven stack .raven-header {
  margin-top: -6px;
}

.raven stack scrolledwindow .raven-header {
  margin-top: -8px;
}

.raven .raven-background {
  border-style: solid none;
  border-width: 1px;
  border-color: rgba(0, 0, 0, 0.12);
  background-color: #FFFFFF;
}

.raven .raven-background > overlay > widget > image {
  color: rgba(0, 0, 0, 0.12);
}

.raven scrolledwindow.raven-background {
  border-bottom-style: none;
}

.raven .powerstrip button {
  margin: 2px 0 1px;
  padding: 12px;
}

.raven .option-subtitle {
  font-size: smaller;
}

.raven .audio-widget scale.marks-after {
  padding-top: 0;
  padding-bottom: 0;
}

.raven .audio-widget button.flat.expander-button {
  margin-top: 4px;
  margin-bottom: 4px;
}

.raven .audio-widget list {
  background: none;
}

.raven .audio-widget list.devices-list.sound-devices > row.activatable:selected, .raven .audio-widget list.devices-list.sound-devices > row.activatable:checked {
  background-color: rgba(0, 0, 0, 0.06);
  color: rgba(0, 0, 0, 0.87);
}

.raven .audio-widget list.devices-list.sound-devices > row.activatable:selected label, .raven .audio-widget list.devices-list.sound-devices > row.activatable:checked label {
  color: rgba(0, 0, 0, 0.87);
}

.raven .audio-widget list.devices-list.sound-devices > row.activatable label {
  padding-left: 12px;
}

.raven levelbar, .raven levelbar trough, .raven levelbar block {
  border-radius: 9999px;
}

calendar.raven-calendar {
  border-style: none;
  background-color: transparent;
}

calendar.raven-calendar:selected {
  border-radius: 12px;
}

.raven-mpris {
  background-color: #242424;
  color: rgba(255, 255, 255, 0.7);
}

.raven-mpris label {
  min-height: 24px;
}

.raven-mpris button.image-button {
  padding: 12px;
}

image.raven-mpris {
  background-color: rgba(0, 0, 0, 0.12);
  color: rgba(0, 0, 0, 0.6);
  border-radius: 12px;
}

.raven-notifications-view > .raven-background > viewport.frame {
  padding: 0;
}

.raven-notifications-view > .raven-background > viewport.frame > list > row.activatable {
  margin-left: -6px;
  margin-right: -3px;
}

.raven-notifications-view > .raven-background > viewport.frame > list > row.activatable .raven-notifications-group-header {
  padding: 0 12px;
}

.raven-notifications-view > .raven-background > viewport.frame > list > row.activatable list {
  padding: 6px;
  background: none;
}

.raven-notifications-view > .raven-background > viewport.frame > list > row.activatable list > row.activatable {
  border: none;
  padding: 6px 6px 6px 12px;
  margin: 3px;
  border-radius: 12px;
  background-color: rgba(0, 0, 0, 0.04);
}

.raven-notifications-view > .raven-background > viewport.frame > list > row.activatable list > row.activatable:hover, .raven-notifications-view > .raven-background > viewport.frame > list > row.activatable list > row.activatable:selected {
  background-color: rgba(0, 0, 0, 0.12);
}

.raven-notifications-view > .raven-background > viewport.frame > list > row.activatable:selected, .raven-notifications-view > .raven-background > viewport.frame > list > row.activatable:selected:hover, .raven-notifications-view > .raven-background > viewport.frame > list > row.activatable:hover, .raven-notifications-view > .raven-background > viewport.frame > list > row.activatable:active, .raven-notifications-view > .raven-background > viewport.frame > list > row.activatable:focus {
  background: none;
  box-shadow: none;
}

.raven-notifications-group .raven-notifications-group-header {
  padding-left: 6px;
}

.raven-notifications-group list > row {
  border-radius: 12px;
  padding: 6px;
}

.raven-notifications-group list > row .notification-clone {
  padding-left: 6px;
}

.drop-shadow {
  margin: 5px 9px;
  padding: 6px;
  border-radius: 18px;
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

.budgie-notification-window {
  background-color: transparent;
}

.budgie-notification {
  padding: 12px;
}

.budgie-notification .notification-title {
  font-size: 120%;
}

.budgie-notification .notification-body {
  color: rgba(0, 0, 0, 0.6);
}

.budgie-switcher-window {
  background-color: transparent;
}

.budgie-switcher {
  padding: 12px;
}

.budgie-osd-window {
  background-color: transparent;
  color: rgba(255, 255, 255, 0.7);
}

.budgie-osd-window .drop-shadow {
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.1);
  background-color: #212121;
}

.budgie-osd-window image {
  color: rgba(255, 255, 255, 0.7);
}

.budgie-osd-window progressbar trough {
  background-color: rgba(255, 255, 255, 0.15);
}

.budgie-power-dialog {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

.budgie-power-dialog.background, .budgie-power-dialog decoration {
  border-radius: 24px;
}

.budgie-power-dialog .titlebar {
  background: none;
  box-shadow: none;
}

.budgie-power-dialog .drop-shadow {
  border-radius: 24px;
}

.budgie-session-dialog,
.budgie-polkit-dialog,
.budgie-run-dialog {
  box-shadow: inset 0 1px rgba(255, 255, 255, 0.4);
  background-color: #FFFFFF;
}

.budgie-session-dialog > box > grid,
.budgie-polkit-dialog > box > grid,
.budgie-run-dialog > box > grid {
  padding: 24px;
}

.budgie-session-dialog.background.csd, .budgie-session-dialog decoration,
.budgie-polkit-dialog.background.csd,
.budgie-polkit-dialog decoration,
.budgie-run-dialog.background.csd,
.budgie-run-dialog decoration {
  border-radius: 18px;
}

.budgie-session-dialog label:not(:last-child),
.budgie-session-dialog .dialog-title,
.budgie-polkit-dialog label:not(:last-child),
.budgie-polkit-dialog .dialog-title,
.budgie-run-dialog label:not(:last-child),
.budgie-run-dialog .dialog-title {
  font-size: 120%;
}

.budgie-session-dialog .linked.horizontal > button,
.budgie-polkit-dialog .linked.horizontal > button,
.budgie-run-dialog .linked.horizontal > button {
  padding: 8px 16px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
  border-radius: 0;
}

.budgie-session-dialog .linked.horizontal > button:first-child,
.budgie-polkit-dialog .linked.horizontal > button:first-child,
.budgie-run-dialog .linked.horizontal > button:first-child {
  border-bottom-left-radius: 18px;
}

.budgie-session-dialog .linked.horizontal > button:last-child,
.budgie-polkit-dialog .linked.horizontal > button:last-child,
.budgie-run-dialog .linked.horizontal > button:last-child {
  border-bottom-right-radius: 18px;
}

.budgie-polkit-dialog .message {
  color: rgba(0, 0, 0, 0.6);
}

.budgie-polkit-dialog .failure {
  color: #E53935;
}

.budgie-polkit-dialog > box > grid {
  padding-bottom: 0;
}

.budgie-run-dialog entry.search {
  font-size: 120%;
  padding: 6px 14px;
  border-image: none;
  box-shadow: none;
  background-color: transparent;
}

.budgie-run-dialog list .dim-label {
  color: rgba(0, 0, 0, 0.87);
}

.budgie-run-dialog scrolledwindow {
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.budgie-settings-window > box > scrolledwindow {
  background-color: #FAFAFA;
  border-bottom-left-radius: 18px;
}

.budgie-settings-window > box > scrolledwindow list.sidebar {
  background-color: transparent;
}

.budgie-settings-window buttonbox.inline-toolbar {
  border-style: none none solid;
}

.budgie-settings-window buttonbox.inline-toolbar button {
  border-radius: 12px;
}

button.centerbutton:first-child {
  border-radius: 12px 0 0 12px;
}

button.centerbutton:last-child {
  border-radius: 0 12px 12px 0;
}

/**************
 * Xfce4 Apps *
 **************/
.XfceHeading {
  background-color: #FFFFFF;
}

/***************
 * xfce4-panel *
 ***************/
.xfce4-panel.background {
  border: none;
  border-color: transparent;
  background-color: rgba(242, 242, 242, 0.65);
  color: rgba(0, 0, 0, 0.6);
  font-weight: 500;
}

.xfce4-panel.background button, .xfce4-panel.background button.flat {
  color: rgba(0, 0, 0, 0.6);
  min-height: 16px;
  min-width: 16px;
  padding: 0;
  border-radius: 0;
}

.xfce4-panel.background .tasklist button {
  color: rgba(0, 0, 0, 0.6);
  border-image: image(transparent) 0 0 2/0 0 2px;
}

.xfce4-panel.background .tasklist button:checked {
  border-image: image(#1A73E8) 0 0 2/0 0 2px;
}

.xfce4-panel.background .tasklist button image {
  padding: 4px;
}

wnck-pager:hover {
  background-color: alpha(currentColor, 0.08);
}

wnck-pager:active {
  background-color: alpha(currentColor, 0.12);
}

wnck-pager:selected {
  background-color: #1A73E8;
}

XfdesktopIconView.view {
  border-radius: 5px;
  background-color: transparent;
  color: white;
  text-shadow: 0 1px 1px rgba(0, 0, 0, 0.2), 0 1px 2px rgba(0, 0, 0, 0.14), 0 1px 3px rgba(0, 0, 0, 0.12);
}

XfdesktopIconView.view:active, XfdesktopIconView.view:selected, XfdesktopIconView.view:checked {
  box-shadow: none;
}

XfdesktopIconView.view .rubberband {
  border-radius: 0;
}

#XfceNotifyWindow buttonbox {
  padding: 0;
}

#XfceNotifyWindow label#summary {
  font-weight: bold;
}

#xfwm-tabwin {
  padding: 12px;
  border-radius: 12px;
  -XfwmTabwinWidget-icon-size: 64px;
  -XfwmTabwinWidget-preview-size: 64px;
}

/***************
 * Whiskermenu *
 ***************/
window#whiskermenu-window {
  border-radius: 0;
  background-color: #FFFFFF;
  border: none;
}

window#whiskermenu-window entry.search {
  border-radius: 5px;
}

window#whiskermenu-window entry.search:focus {
  background-color: #FFFFFF;
}

window#whiskermenu-window > frame > border {
  border-radius: 18px;
  padding: 6px 8px 6px 9px;
  margin: 6px;
  border: none;
  background-color: rgba(255, 255, 255, 0.97);
  box-shadow: 0 2px 2px -1px rgba(0, 0, 0, 0.2), 0 4px 4px 0 rgba(0, 0, 0, 0.14), 0 1px 6px 0 rgba(0, 0, 0, 0.12), inset 0 1px rgba(255, 255, 255, 0.4);
}

window#whiskermenu-window box.categories > button.radio {
  padding: 3px 6px;
  margin: 1px 0;
  border-radius: 5px;
}

window#whiskermenu-window box.categories > button.radio:hover {
  background-color: rgba(0, 0, 0, 0.12);
}

window#whiskermenu-window box.categories > button.radio:checked, window#whiskermenu-window box.categories > button.radio:active {
  background-color: rgba(0, 0, 0, 0.26);
  color: rgba(0, 0, 0, 0.87);
}

window#whiskermenu-window box.categories > button.radio:checked:hover, window#whiskermenu-window box.categories > button.radio:active:hover {
  background-image: none;
}

window#whiskermenu-window scrolledwindow.frame {
  padding: 3px;
  background-color: #FFFFFF;
  border-radius: 5px;
}

window#whiskermenu-window scrolledwindow.frame treeview.view {
  border-radius: 5px;
}

window#whiskermenu-window scrolledwindow.frame treeview.view:not(:hover):not(:selected) {
  background: none;
}

window#whiskermenu-window scrolledwindow.frame treeview.view:selected:hover {
  background-color: rgba(0, 0, 0, 0.12);
  color: rgba(0, 0, 0, 0.87);
}

window#whiskermenu-window scrolledwindow.frame iconview {
  border-radius: 5px;
}

window#whiskermenu-window scrollbar {
  border: none;
}

window#whiskermenu-window scrollbar, window#whiskermenu-window scrollbar.dragging, window#whiskermenu-window scrollbar.hovering, window#whiskermenu-window scrollbar.overlay-indicator, window#whiskermenu-window scrollbar.overlay-indicator.dragging, window#whiskermenu-window scrollbar.overlay-indicator.hovering {
  background-color: transparent;
}

window#whiskermenu-window .title-area > .commands-area > button.flat.command-button {
  border-radius: 5px;
}

window#whiskermenu-window .title-area > .commands-area > button.flat.command-button:checked, window#whiskermenu-window .title-area > .commands-area > button.flat.command-button:active {
  background-color: rgba(0, 0, 0, 0.26);
  color: rgba(0, 0, 0, 0.87);
}

/**********
 * Thunar *
 **********/
.thunar toolbar {
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

.thunar .standard-view.frame {
  border: none;
}

.thunar paned paned paned > notebook.frame {
  border: none;
  border-radius: 0;
}

.thunar paned paned paned > notebook.frame .standard-view.frame > widget.view {
  border-radius: 0;
  box-shadow: inset 0 0 0 3px rgba(26, 115, 232, 0.25);
}

.thunar .sidebar {
  border: none;
}

.thunar .sidebar .view:not(:selected) {
  background-color: transparent;
}

.thunar statusbar {
  margin: 0 -10px;
  padding: 0 6px;
  border-top: 1px solid rgba(0, 0, 0, 0.12);
}

.thunar > grid.horizontal > paned.horizontal > scrolledwindow.frame.sidebar.shortcuts-pane {
  border-top: none;
}

window.background.csd.thunar > grid.horizontal > paned.horizontal > scrolledwindow.frame.sidebar.shortcuts-pane {
  border-bottom-left-radius: 18px;
}

window.background.csd.thunar > grid.horizontal > paned.horizontal > scrolledwindow.frame.sidebar.shortcuts-pane treeview.view:not(:hover):not(:active):not(:selected) {
  background-color: transparent;
}

/***************
 * xfsm dialog *
 ***************/
dialog.xfsm-logout-dialog {
  box-shadow: none;
  border: none;
  border-radius: 18px;
  background-color: rgba(255, 255, 255, 0.97);
}

/**********************
 * Xfce Notify Window *
 **********************/
#XfceNotifyWindow {
  box-shadow: none;
  border: none;
  border-radius: 18px;
  color: rgba(255, 255, 255, 0.7);
  background-color: rgba(0, 0, 0, 0.75);
  padding: 6px;
}

#XfceNotifyWindow buttonbox {
  padding: 0;
}

#XfceNotifyWindow label#summary {
  font-weight: bold;
}

/************************
 * LightDM GTK+ Greeter *
 ************************/
#panel_window {
  background-color: transparent;
  color: #FFFFFF;
  box-shadow: none;
  border-color: transparent;
}

#panel_window menubar,
#panel_window separator {
  background-color: transparent;
  border: none;
  box-shadow: none;
}

#panel_window separator {
  padding: 0 4px;
}

#panel_window separator:first-child {
  padding: 0 8px;
}

#panel_window menubar > menuitem {
  color: rgba(255, 255, 255, 0.7);
}

#panel_window menubar > menuitem:hover {
  color: white;
}

#panel_window menubar > menuitem:disabled label {
  color: rgba(255, 255, 255, 0.3);
}

#panel_window menu {
  border-radius: 0;
  box-shadow: none;
  border: 1px solid #dedede;
}

#login_window,
#shutdown_dialog,
#restart_dialog {
  margin: 0;
  border-radius: 12px;
  box-shadow: none;
  background-color: #FFFFFF;
}

#login_window menu,
#shutdown_dialog menu,
#restart_dialog menu {
  border-radius: 0;
  box-shadow: none;
  border: 1px solid #dedede;
}

#content_frame {
  padding-bottom: 16px;
}

#buttonbox_frame {
  padding-top: 24px;
}

#buttonbox_frame > box,
#buttonbox_frame > buttonbox {
  margin: -16px;
}

#buttonbox_frame button:not(:disabled) {
  color: #1A73E8;
}

/********
 * Nemo *
 ********/
.nemo-window .primary-toolbar {
  background-color: #FFFFFF;
  border-bottom: 1px solid rgba(0, 0, 0, 0.12);
}

.nemo-window .primary-toolbar entry {
  min-height: 0;
  margin: 0;
}

.nemo-window .primary-toolbar button.text-button {
  padding-left: 8px;
  padding-right: 8px;
  color: rgba(0, 0, 0, 0.6);
}

.nemo-window .primary-toolbar button.text-button:hover, .nemo-window .primary-toolbar button.text-button:active, .nemo-window .primary-toolbar button.text-button:checked {
  color: rgba(0, 0, 0, 0.87);
}

.nemo-window .primary-toolbar button.text-button:disabled {
  color: rgba(0, 0, 0, 0.38);
}

.nemo-window .primary-toolbar button:not(.text-button):not(.image-button) {
  padding-left: 4px;
  padding-right: 4px;
}

.nemo-window scrolledwindow.frame {
  border-style: none;
}

.nemo-window scrolledwindow.frame .view:not(:selected) {
  background-color: transparent;
}

.nemo-window .nemo-inactive-pane .view:not(:selected) {
  background-color: #FAFAFA;
}

.nemo-window .nemo-window-pane widget.entry {
  border-radius: 12px;
  background-color: rgba(0, 0, 0, 0.04);
}

.places-treeview {
  -NemoPlacesTreeView-disk-full-bg-color: rgba(182, 182, 182, 0.961);
  -NemoPlacesTreeView-disk-full-fg-color: #1A73E8;
  -NemoPlacesTreeView-disk-full-bar-width: 2px;
  -NemoPlacesTreeView-disk-full-bar-radius: 0;
  -NemoPlacesTreeView-disk-full-bottom-padding: 1px;
  -NemoPlacesTreeView-disk-full-max-length: 80px;
  padding-top: 3px;
  padding-bottom: 3px;
}

/* GTK NAMED COLORS
   ----------------
   use responsibly! */
/*
widget text/foreground color */
@define-color theme_fg_color rgba(0, 0, 0, 0.87);
/*
text color for entries, views and content in general */
@define-color theme_text_color rgba(0, 0, 0, 0.87);
/*
widget base background color */
@define-color theme_bg_color #F2F2F2;
/*
text widgets and the like base background color */
@define-color theme_base_color #FFFFFF;
/*
base background color of selections */
@define-color theme_selected_bg_color #1A73E8;
/*
text/foreground color of selections */
@define-color theme_selected_fg_color white;
/*
base background color of insensitive widgets */
@define-color insensitive_bg_color #F2F2F2;
/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color rgba(0, 0, 0, 0.38);
/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color #FAFAFA;
/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color rgba(0, 0, 0, 0.87);
/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color rgba(0, 0, 0, 0.87);
/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #F2F2F2;
/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #FFFFFF;
/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #1A73E8;
/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color white;
/*
insensitive color on backdrop windows */
@define-color unfocused_insensitive_color rgba(0, 0, 0, 0.38);
/*
widgets main borders color */
@define-color borders rgba(0, 0, 0, 0.12);
/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders rgba(0, 0, 0, 0.12);
/*
these are pretty self explicative */
@define-color warning_color #FFD600;
@define-color error_color #E53935;
@define-color success_color #0F9D58;
/*
these colors are exported for the window manager and shouldn't be used in applications,
read if you used those and something break with a version upgrade you're on your own... */
@define-color wm_title rgba(0, 0, 0, 0.87);
@define-color wm_unfocused_title rgba(0, 0, 0, 0.6);
@define-color wm_highlight rgba(255, 255, 255, 0.4);
@define-color wm_bg #FFFFFF;
@define-color wm_unfocused_bg #FAFAFA;
/*
FIXME this is really an API */
@define-color content_view_bg #FFFFFF;
@define-color placeholder_text_color #666666;
/* Very contrasty background for text views (@theme_text_color foreground) */
@define-color text_view_bg #FFFFFF;
@define-color budgie_tasklist_indicator_color rgba(0, 0, 0, 0.6);
@define-color budgie_tasklist_indicator_color_active #1A73E8;
@define-color budgie_tasklist_indicator_color_active_window rgba(106, 162, 236, 0.8075);
@define-color budgie_tasklist_indicator_color_attention #FFD600;
@define-color STRAWBERRY_100 #FF9262;
@define-color STRAWBERRY_300 #FF793E;
@define-color STRAWBERRY_500 #F15D22;
@define-color STRAWBERRY_700 #CF3B00;
@define-color STRAWBERRY_900 #AC1800;
@define-color ORANGE_100 #FFDB91;
@define-color ORANGE_300 #FFCA40;
@define-color ORANGE_500 #FAA41A;
@define-color ORANGE_700 #DE8800;
@define-color ORANGE_900 #C26C00;
@define-color BANANA_100 #FFFFA8;
@define-color BANANA_300 #FFFA7D;
@define-color BANANA_500 #FFCE51;
@define-color BANANA_700 #D1A023;
@define-color BANANA_900 #A27100;
@define-color LIME_100 #A2F3BE;
@define-color LIME_300 #8ADBA6;
@define-color LIME_500 #73C48F;
@define-color LIME_700 #479863;
@define-color LIME_900 #1C6D38;
@define-color BLUEBERRY_100 #94A6FF;
@define-color BLUEBERRY_300 #6A7CE0;
@define-color BLUEBERRY_500 #3F51B5;
@define-color BLUEBERRY_700 #213397;
@define-color BLUEBERRY_900 #031579;
@define-color GRAPE_100 #D25DE6;
@define-color GRAPE_300 #B84ACB;
@define-color GRAPE_500 #9C27B0;
@define-color GRAPE_700 #830E97;
@define-color GRAPE_900 #6A007E;
@define-color COCOA_100 #9F9792;
@define-color COCOA_300 #7B736E;
@define-color COCOA_500 #574F4A;
@define-color COCOA_700 #463E39;
@define-color COCOA_900 #342C27;
@define-color SILVER_100 #EEE;
@define-color SILVER_300 #CCC;
@define-color SILVER_500 #AAA;
@define-color SILVER_700 #888;
@define-color SILVER_900 #666;
@define-color SLATE_100 #888;
@define-color SLATE_300 #666;
@define-color SLATE_500 #444;
@define-color SLATE_700 #222;
@define-color SLATE_900 #111;
@define-color BLACK_100 #474341;
@define-color BLACK_300 #403C3A;
@define-color BLACK_500 #393634;
@define-color BLACK_700 #33302F;
@define-color BLACK_900 #2B2928;
